Class: Aws::LexModelsV2::Types::AggregatedUtterancesSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Provides summary information for aggregated utterances. The ListAggregatedUtterances operations combines all instances of the same utterance into a single aggregated summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contains_data_from_deleted_resources ⇒ Boolean

Aggregated utterance data may contain utterances from versions of your bot that have since been deleted. When the aggregated contains this kind of data, this field is set to true.

Returns:

  • (Boolean)


183
184
185
186
187
188
189
190
191
192
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 183

class AggregatedUtterancesSummary < Struct.new(
  :utterance,
  :hit_count,
  :missed_count,
  :utterance_first_recorded_in_aggregation_duration,
  :utterance_last_recorded_in_aggregation_duration,
  :contains_data_from_deleted_resources)
  SENSITIVE = []
  include Aws::Structure
end

#hit_count ⇒ Integer

The number of times that the utterance was detected by Amazon Lex during the time period. When an utterance is detected, it activates an intent or a slot.

Returns:

  • (Integer)


183
184
185
186
187
188
189
190
191
192
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 183

class AggregatedUtterancesSummary < Struct.new(
  :utterance,
  :hit_count,
  :missed_count,
  :utterance_first_recorded_in_aggregation_duration,
  :utterance_last_recorded_in_aggregation_duration,
  :contains_data_from_deleted_resources)
  SENSITIVE = []
  include Aws::Structure
end

#missed_count ⇒ Integer

The number of times that the utterance was missed by Amazon Lex An utterance is missed when it doesn't activate an intent or slot.

Returns:

  • (Integer)


183
184
185
186
187
188
189
190
191
192
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 183

class AggregatedUtterancesSummary < Struct.new(
  :utterance,
  :hit_count,
  :missed_count,
  :utterance_first_recorded_in_aggregation_duration,
  :utterance_last_recorded_in_aggregation_duration,
  :contains_data_from_deleted_resources)
  SENSITIVE = []
  include Aws::Structure
end

#utterance ⇒ String

The text of the utterance. If the utterance was used with the RecognizeUtterance operation, the text is the transcription of the audio utterance.

Returns:

  • (String)


183
184
185
186
187
188
189
190
191
192
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 183

class AggregatedUtterancesSummary < Struct.new(
  :utterance,
  :hit_count,
  :missed_count,
  :utterance_first_recorded_in_aggregation_duration,
  :utterance_last_recorded_in_aggregation_duration,
  :contains_data_from_deleted_resources)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_first_recorded_in_aggregation_duration ⇒ Time

The date and time that the utterance was first recorded in the time window for aggregation. An utterance may have been sent to Amazon Lex before that time, but only utterances within the time window are counted.

Returns:

  • (Time)


183
184
185
186
187
188
189
190
191
192
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 183

class AggregatedUtterancesSummary < Struct.new(
  :utterance,
  :hit_count,
  :missed_count,
  :utterance_first_recorded_in_aggregation_duration,
  :utterance_last_recorded_in_aggregation_duration,
  :contains_data_from_deleted_resources)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_last_recorded_in_aggregation_duration ⇒ Time

The last date and time that an utterance was recorded in the time window for aggregation. An utterance may be sent to Amazon Lex after that time, but only utterances within the time window are counted.

Returns:

  • (Time)


183
184
185
186
187
188
189
190
191
192
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 183

class AggregatedUtterancesSummary < Struct.new(
  :utterance,
  :hit_count,
  :missed_count,
  :utterance_first_recorded_in_aggregation_duration,
  :utterance_last_recorded_in_aggregation_duration,
  :contains_data_from_deleted_resources)
  SENSITIVE = []
  include Aws::Structure
end