Class: Aws::LexModelsV2::Types::AnalyticsIntentMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::AnalyticsIntentMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Contains the metric and the summary statistic you want to calculate, and the order in which to sort the results, for the intents in the bot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The metric for which you want to get intent summary statistics.
-
#order ⇒ String
Specifies whether to sort the results in ascending or descending order.
-
#statistic ⇒ String
The summary statistic to calculate.
Instance Attribute Details
#name ⇒ String
The metric for which you want to get intent summary statistics.
-
Count– The number of times the intent was invoked. -
Success– The number of times the intent succeeded. -
Failure– The number of times the intent failed. -
Switched– The number of times there was a switch to a different intent. -
Dropped– The number of times the user dropped the intent.
438 439 440 441 442 443 444 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 438 class AnalyticsIntentMetric < Struct.new( :name, :statistic, :order) SENSITIVE = [] include Aws::Structure end |
#order ⇒ String
Specifies whether to sort the results in ascending or descending order.
438 439 440 441 442 443 444 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 438 class AnalyticsIntentMetric < Struct.new( :name, :statistic, :order) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The summary statistic to calculate.
-
Sum– The total count for the category you provide inname. -
Average– The total count divided by the number of intents in the category you provide inname. -
Max– The highest count in the category you provide inname.
438 439 440 441 442 443 444 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 438 class AnalyticsIntentMetric < Struct.new( :name, :statistic, :order) SENSITIVE = [] include Aws::Structure end |