Class: Aws::LexModelsV2::Types::AnalyticsIntentMetricResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::AnalyticsIntentMetricResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
An object containing the results for the intent metric you requested.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The metric that you requested.
-
#statistic ⇒ String
The statistic that you requested to calculate.
-
#value ⇒ Float
The value of the summary statistic for the metric that you requested.
Instance Attribute Details
#name ⇒ String
The metric that you requested. See [Key definitions] for more details about these metrics.
-
Count– The number of times the intent was invoked. -
Success– The number of times the intent succeeded. -
Failure– The number of times the intent failed. -
Switched– The number of times there was a switch to a different intent. -
Dropped– The number of times the user dropped the intent.
[1]: docs.aws.amazon.com/lexv2/latest/dg/analytics-key-definitions.html
486 487 488 489 490 491 492 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 486 class AnalyticsIntentMetricResult < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic that you requested to calculate.
-
Sum– The total count for the category you provide inname. -
Average– The total count divided by the number of intents in the category you provide inname. -
Max– The highest count in the category you provide inname.
486 487 488 489 490 491 492 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 486 class AnalyticsIntentMetricResult < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The value of the summary statistic for the metric that you requested.
486 487 488 489 490 491 492 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 486 class AnalyticsIntentMetricResult < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |