Class: Aws::LexModelsV2::Types::AnalyticsSessionMetricResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::AnalyticsSessionMetricResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
An object containing the results for a session metric you requested.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The metric that you requested.
-
#statistic ⇒ String
The summary statistic that you requested to calculate.
-
#value ⇒ Float
The value of the summary statistic for the metric that you requested.
Instance Attribute Details
#name ⇒ String
The metric that you requested.
-
Count– The number of sessions. -
Success– The number of sessions that succeeded. -
Failure– The number of sessions that failed. -
Dropped– The number of sessions that the user dropped. -
Duration– The duration of sessions. -
TurnPersession– The number of turns in the sessions. -
Concurrency– The number of sessions occurring in the same period of time.
1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1142 class AnalyticsSessionMetricResult < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The summary statistic that you requested to calculate.
-
Sum– The total count for the category you provide inname. -
Average– The total count divided by the number of sessions in the category you provide inname. -
Max– The highest count in the category you provide inname.
1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1142 class AnalyticsSessionMetricResult < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The value of the summary statistic for the metric that you requested.
1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1142 class AnalyticsSessionMetricResult < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |