Class: Aws::LexModelsV2::Types::BatchCreateCustomVocabularyItemResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot associated with this custom vocabulary.

Returns:



1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1677

class BatchCreateCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The identifier of the version of the bot associated with this custom vocabulary.

Returns:



1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1677

class BatchCreateCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#errorsArray<Types::FailedCustomVocabularyItem>

A list of custom vocabulary items that failed to create during the operation. The reason for the error is contained within each error object.

Returns:



1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1677

class BatchCreateCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale where this custom vocabulary is used. The string must match one of the supported locales. For more information, see [ Supported Languages ][1].

[1]: docs.aws.amazon.com/lexv2/latest/dg/how-languages.html

Returns:



1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1677

class BatchCreateCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<Types::CustomVocabularyItem>

A list of custom vocabulary items that were successfully created during the operation.

Returns:



1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1677

class BatchCreateCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end