Class: Aws::LexModelsV2::Types::BatchDeleteCustomVocabularyItemResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot associated with this custom vocabulary.

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1803

class BatchDeleteCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The identifier of the version of the bot associated with this custom vocabulary.

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1803

class BatchDeleteCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#errorsArray<Types::FailedCustomVocabularyItem>

A list of custom vocabulary items that failed to delete during the operation. The reason for the error is contained within each error object.



1803
1804
1805
1806
1807
1808
1809
1810
1811
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1803

class BatchDeleteCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale where this custom vocabulary is used. The string must match one of the supported locales. For more information, see Supported languages (docs.aws.amazon.com/lexv2/latest/dg/how-languages.html).

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1803

class BatchDeleteCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<Types::CustomVocabularyItem>

A list of custom vocabulary items that were successfully deleted during the operation.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1803

class BatchDeleteCustomVocabularyItemResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :errors,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end