Class: Aws::LexModelsV2::Types::BedrockKnowledgeStoreConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BedrockKnowledgeStoreConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Contains details about the configuration of a Amazon Bedrock knowledge base.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bedrock_knowledge_base_arn ⇒ String
The base ARN of the knowledge base used.
-
#exact_response ⇒ Boolean
Specifies whether to return an exact response, or to return an answer generated by the model, using the fields you specify from the database.
-
#exact_response_fields ⇒ Types::BedrockKnowledgeStoreExactResponseFields
Contains the names of the fields used for an exact response to the user.
Instance Attribute Details
#bedrock_knowledge_base_arn ⇒ String
The base ARN of the knowledge base used.
1930 1931 1932 1933 1934 1935 1936 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1930 class BedrockKnowledgeStoreConfiguration < Struct.new( :bedrock_knowledge_base_arn, :exact_response, :exact_response_fields) SENSITIVE = [] include Aws::Structure end |
#exact_response ⇒ Boolean
Specifies whether to return an exact response, or to return an answer generated by the model, using the fields you specify from the database.
1930 1931 1932 1933 1934 1935 1936 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1930 class BedrockKnowledgeStoreConfiguration < Struct.new( :bedrock_knowledge_base_arn, :exact_response, :exact_response_fields) SENSITIVE = [] include Aws::Structure end |
#exact_response_fields ⇒ Types::BedrockKnowledgeStoreExactResponseFields
Contains the names of the fields used for an exact response to the user.
1930 1931 1932 1933 1934 1935 1936 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1930 class BedrockKnowledgeStoreConfiguration < Struct.new( :bedrock_knowledge_base_arn, :exact_response, :exact_response_fields) SENSITIVE = [] include Aws::Structure end |