Class: Aws::LexModelsV2::Types::BotAliasSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BotAliasSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Summary information about bot aliases returned from the
- ListBotAliases][1
-
operation.
[1]: docs.aws.amazon.com/lexv2/latest/APIReference/API_ListBotAliases.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_alias_id ⇒ String
The unique identifier assigned to the bot alias.
-
#bot_alias_name ⇒ String
The name of the bot alias.
-
#bot_alias_status ⇒ String
The current state of the bot alias.
-
#bot_version ⇒ String
The version of the bot that the bot alias references.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot alias was created.
-
#description ⇒ String
The description of the bot alias.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot alias was last updated.
Instance Attribute Details
#bot_alias_id ⇒ String
The unique identifier assigned to the bot alias. You can use this ID to get detailed information about the alias using the
- DescribeBotAlias][1
-
operation.
[1]: docs.aws.amazon.com/lexv2/latest/APIReference/API_DescribeBotAlias.html
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2115 class BotAliasSummary < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_status, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#bot_alias_name ⇒ String
The name of the bot alias.
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2115 class BotAliasSummary < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_status, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#bot_alias_status ⇒ String
The current state of the bot alias. If the status is ‘Available`, the alias is ready for use.
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2115 class BotAliasSummary < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_status, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that the bot alias references.
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2115 class BotAliasSummary < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_status, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot alias was created.
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2115 class BotAliasSummary < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_status, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the bot alias.
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2115 class BotAliasSummary < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_status, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot alias was last updated.
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2115 class BotAliasSummary < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_status, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |