Class: Aws::LexModelsV2::Types::BotAnalyzerHistorySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains summary information about a historical bot analysis execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_analyzer_request_idString

The unique identifier for the analysis request.

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
2125
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2119

class BotAnalyzerHistorySummary < Struct.new(
  :bot_analyzer_status,
  :creation_date_time,
  :bot_analyzer_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_analyzer_statusString

The status of the historical analysis execution.

Valid Values: ‘Processing | Available | Failed | Stopping | Stopped`

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
2125
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2119

class BotAnalyzerHistorySummary < Struct.new(
  :bot_analyzer_status,
  :creation_date_time,
  :bot_analyzer_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the analysis was initiated.

Returns:

  • (Time)


2119
2120
2121
2122
2123
2124
2125
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2119

class BotAnalyzerHistorySummary < Struct.new(
  :bot_analyzer_status,
  :creation_date_time,
  :bot_analyzer_request_id)
  SENSITIVE = []
  include Aws::Structure
end