Class: Aws::LexModelsV2::Types::BotAnalyzerRecommendation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains a recommendation for bot optimization identified by the Bot Analyzer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#issue_descriptionString

A detailed description of the identified configuration issue.

Returns:



2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2151

class BotAnalyzerRecommendation < Struct.new(
  :issue_location,
  :priority,
  :issue_description,
  :proposed_fix)
  SENSITIVE = []
  include Aws::Structure
end

#issue_locationTypes::IssueLocation

The location information for the identified issue within the bot configuration.

Returns:



2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2151

class BotAnalyzerRecommendation < Struct.new(
  :issue_location,
  :priority,
  :issue_description,
  :proposed_fix)
  SENSITIVE = []
  include Aws::Structure
end

#priorityString

The priority level of the recommendation.

Valid Values: ‘High | Medium | Low`

Returns:



2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2151

class BotAnalyzerRecommendation < Struct.new(
  :issue_location,
  :priority,
  :issue_description,
  :proposed_fix)
  SENSITIVE = []
  include Aws::Structure
end

#proposed_fixString

The recommended solution to address the identified issue.

Returns:



2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2151

class BotAnalyzerRecommendation < Struct.new(
  :issue_location,
  :priority,
  :issue_description,
  :proposed_fix)
  SENSITIVE = []
  include Aws::Structure
end