Class: Aws::LexModelsV2::Types::BotExportSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Provides the identity of a the bot that was exported.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot assigned by Amazon Lex.

Returns:

  • (String)


2173
2174
2175
2176
2177
2178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2173

class BotExportSpecification < Struct.new(
  :bot_id,
  :bot_version)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that was exported. This will be either DRAFT or the version number.

Returns:

  • (String)


2173
2174
2175
2176
2177
2178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2173

class BotExportSpecification < Struct.new(
  :bot_id,
  :bot_version)
  SENSITIVE = []
  include Aws::Structure
end