Class: Aws::LexModelsV2::Types::BotImportSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BotImportSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Provides the bot parameters required for importing a bot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_name ⇒ String
The name that Amazon Lex should use for the bot.
-
#bot_tags ⇒ Hash<String,String>
A list of tags to add to the bot.
-
#data_privacy ⇒ Types::DataPrivacy
By default, data stored by Amazon Lex is encrypted.
-
#error_log_settings ⇒ Types::ErrorLogSettings
Allows you to configure destinations where error logs will be published during the bot import process.
-
#idle_session_ttl_in_seconds ⇒ Integer
The time, in seconds, that Amazon Lex should keep information about a user’s conversation with the bot.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used to build and run the bot.
-
#test_bot_alias_tags ⇒ Hash<String,String>
A list of tags to add to the test alias for a bot.
Instance Attribute Details
#bot_name ⇒ String
The name that Amazon Lex should use for the bot.
2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2255 class BotImportSpecification < Struct.new( :bot_name, :role_arn, :data_privacy, :error_log_settings, :idle_session_ttl_in_seconds, :bot_tags, :test_bot_alias_tags) SENSITIVE = [] include Aws::Structure end |
#bot_tags ⇒ Hash<String,String>
A list of tags to add to the bot. You can only add tags when you import a bot. You can’t use the UpdateBot operation to update tags. To update tags, use the TagResource operation.
2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2255 class BotImportSpecification < Struct.new( :bot_name, :role_arn, :data_privacy, :error_log_settings, :idle_session_ttl_in_seconds, :bot_tags, :test_bot_alias_tags) SENSITIVE = [] include Aws::Structure end |
#data_privacy ⇒ Types::DataPrivacy
By default, data stored by Amazon Lex is encrypted. The DataPrivacy structure provides settings that determine how Amazon Lex handles special cases of securing the data for your bot.
2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2255 class BotImportSpecification < Struct.new( :bot_name, :role_arn, :data_privacy, :error_log_settings, :idle_session_ttl_in_seconds, :bot_tags, :test_bot_alias_tags) SENSITIVE = [] include Aws::Structure end |
#error_log_settings ⇒ Types::ErrorLogSettings
Allows you to configure destinations where error logs will be published during the bot import process.
2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2255 class BotImportSpecification < Struct.new( :bot_name, :role_arn, :data_privacy, :error_log_settings, :idle_session_ttl_in_seconds, :bot_tags, :test_bot_alias_tags) SENSITIVE = [] include Aws::Structure end |
#idle_session_ttl_in_seconds ⇒ Integer
The time, in seconds, that Amazon Lex should keep information about a user’s conversation with the bot.
A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout.
You can specify between 60 (1 minute) and 86,400 (24 hours) seconds.
2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2255 class BotImportSpecification < Struct.new( :bot_name, :role_arn, :data_privacy, :error_log_settings, :idle_session_ttl_in_seconds, :bot_tags, :test_bot_alias_tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used to build and run the bot.
2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2255 class BotImportSpecification < Struct.new( :bot_name, :role_arn, :data_privacy, :error_log_settings, :idle_session_ttl_in_seconds, :bot_tags, :test_bot_alias_tags) SENSITIVE = [] include Aws::Structure end |
#test_bot_alias_tags ⇒ Hash<String,String>
A list of tags to add to the test alias for a bot. You can only add tags when you import a bot. You can’t use the UpdateAlias operation to update tags. To update tags on the test alias, use the TagResource operation.
2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2255 class BotImportSpecification < Struct.new( :bot_name, :role_arn, :data_privacy, :error_log_settings, :idle_session_ttl_in_seconds, :bot_tags, :test_bot_alias_tags) SENSITIVE = [] include Aws::Structure end |