Class: Aws::LexModelsV2::Types::BotMember

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

A bot that is a member of a network of bots.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_member_alias_id ⇒ String

The alias ID of a bot that is a member of this network of bots.

Returns:

  • (String)


2587
2588
2589
2590
2591
2592
2593
2594
2595
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2587

class BotMember < Struct.new(
  :bot_member_id,
  :bot_member_name,
  :bot_member_alias_id,
  :bot_member_alias_name,
  :bot_member_version)
  SENSITIVE = []
  include Aws::Structure
end

#bot_member_alias_name ⇒ String

The alias name of a bot that is a member of this network of bots.

Returns:

  • (String)


2587
2588
2589
2590
2591
2592
2593
2594
2595
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2587

class BotMember < Struct.new(
  :bot_member_id,
  :bot_member_name,
  :bot_member_alias_id,
  :bot_member_alias_name,
  :bot_member_version)
  SENSITIVE = []
  include Aws::Structure
end

#bot_member_id ⇒ String

The unique ID of a bot that is a member of this network of bots.

Returns:

  • (String)


2587
2588
2589
2590
2591
2592
2593
2594
2595
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2587

class BotMember < Struct.new(
  :bot_member_id,
  :bot_member_name,
  :bot_member_alias_id,
  :bot_member_alias_name,
  :bot_member_version)
  SENSITIVE = []
  include Aws::Structure
end

#bot_member_name ⇒ String

The unique name of a bot that is a member of this network of bots.

Returns:

  • (String)


2587
2588
2589
2590
2591
2592
2593
2594
2595
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2587

class BotMember < Struct.new(
  :bot_member_id,
  :bot_member_name,
  :bot_member_alias_id,
  :bot_member_alias_name,
  :bot_member_version)
  SENSITIVE = []
  include Aws::Structure
end

#bot_member_version ⇒ String

The version of a bot that is a member of this network of bots.

Returns:

  • (String)


2587
2588
2589
2590
2591
2592
2593
2594
2595
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2587

class BotMember < Struct.new(
  :bot_member_id,
  :bot_member_name,
  :bot_member_alias_id,
  :bot_member_alias_name,
  :bot_member_version)
  SENSITIVE = []
  include Aws::Structure
end