Class: Aws::LexModelsV2::Types::BotRecommendationResultStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

A statistical summary of the bot recommendation results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#intents ⇒ Types::IntentStatistics

Statistical information about about the intents associated with the bot recommendation results.



2611
2612
2613
2614
2615
2616
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2611

class BotRecommendationResultStatistics < Struct.new(
  :intents,
  :slot_types)
  SENSITIVE = []
  include Aws::Structure
end

#slot_types ⇒ Types::SlotTypeStatistics

Statistical information about the slot types associated with the bot recommendation results.



2611
2612
2613
2614
2615
2616
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2611

class BotRecommendationResultStatistics < Struct.new(
  :intents,
  :slot_types)
  SENSITIVE = []
  include Aws::Structure
end