Class: Aws::LexModelsV2::Types::BotSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Summary information about a bot returned by the ListBots operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier assigned to the bot. Use this ID to get detailed information about the bot with the DescribeBot operation.

Returns:

  • (String)


2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2771

class BotSummary < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :bot_status,
  :latest_bot_version,
  :last_updated_date_time,
  :bot_type)
  SENSITIVE = []
  include Aws::Structure
end

#bot_name ⇒ String

The name of the bot.

Returns:

  • (String)


2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2771

class BotSummary < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :bot_status,
  :latest_bot_version,
  :last_updated_date_time,
  :bot_type)
  SENSITIVE = []
  include Aws::Structure
end

#bot_status ⇒ String

The current status of the bot. When the status is Available the bot is ready for use.

Returns:

  • (String)


2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2771

class BotSummary < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :bot_status,
  :latest_bot_version,
  :last_updated_date_time,
  :bot_type)
  SENSITIVE = []
  include Aws::Structure
end

#bot_type ⇒ String

The type of the bot.

Returns:

  • (String)


2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2771

class BotSummary < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :bot_status,
  :latest_bot_version,
  :last_updated_date_time,
  :bot_type)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the bot.

Returns:

  • (String)


2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2771

class BotSummary < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :bot_status,
  :latest_bot_version,
  :last_updated_date_time,
  :bot_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time that the bot was last updated.

Returns:

  • (Time)


2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2771

class BotSummary < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :bot_status,
  :latest_bot_version,
  :last_updated_date_time,
  :bot_type)
  SENSITIVE = []
  include Aws::Structure
end

#latest_bot_version ⇒ String

The latest numerical version in use for the bot.

Returns:

  • (String)


2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2771

class BotSummary < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :bot_status,
  :latest_bot_version,
  :last_updated_date_time,
  :bot_type)
  SENSITIVE = []
  include Aws::Structure
end