Class: Aws::LexModelsV2::Types::BotVersionReplicaSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains summary information for all the version replication statuses applicable for Global resiliency.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_version ⇒ String

The bot version for the summary information for all the version replication statuses.

Returns:

  • (String)


2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2839

class BotVersionReplicaSummary < Struct.new(
  :bot_version,
  :bot_version_replication_status,
  :creation_date_time,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version_replication_status ⇒ String

The version replication status for all the replicated bots.

Returns:

  • (String)


2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2839

class BotVersionReplicaSummary < Struct.new(
  :bot_version,
  :bot_version_replication_status,
  :creation_date_time,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The creation date and time of the replication status for all the replicated bots.

Returns:

  • (Time)


2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2839

class BotVersionReplicaSummary < Struct.new(
  :bot_version,
  :bot_version_replication_status,
  :creation_date_time,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasons ⇒ Array<String>

The reasons for replication failure for all the replicated bots.

Returns:

  • (Array<String>)


2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2839

class BotVersionReplicaSummary < Struct.new(
  :bot_version,
  :bot_version_replication_status,
  :creation_date_time,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end