Class: Aws::LexModelsV2::Types::BotVersionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BotVersionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Summary information about a bot version returned by the
- ListBotVersions][1
-
operation.
[1]: docs.aws.amazon.com/lexv2/latest/APIReference/API_ListBotVersions.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_name ⇒ String
The name of the bot associated with the version.
-
#bot_status ⇒ String
The status of the bot.
-
#bot_version ⇒ String
The numeric version of the bot, or
DRAFTto indicate that this is the version of the bot that can be updated.. -
#creation_date_time ⇒ Time
A timestamp of the date and time that the version was created.
-
#description ⇒ String
The description of the version.
Instance Attribute Details
#bot_name ⇒ String
The name of the bot associated with the version.
2834 2835 2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2834 class BotVersionSummary < Struct.new( :bot_name, :bot_version, :description, :bot_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#bot_status ⇒ String
The status of the bot. When the status is available, the version of the bot is ready for use.
2834 2835 2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2834 class BotVersionSummary < Struct.new( :bot_name, :bot_version, :description, :bot_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The numeric version of the bot, or DRAFT to indicate that this is the version of the bot that can be updated..
2834 2835 2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2834 class BotVersionSummary < Struct.new( :bot_name, :bot_version, :description, :bot_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the version was created.
2834 2835 2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2834 class BotVersionSummary < Struct.new( :bot_name, :bot_version, :description, :bot_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the version.
2834 2835 2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2834 class BotVersionSummary < Struct.new( :bot_name, :bot_version, :description, :bot_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |