Class: Aws::LexModelsV2::Types::BuildBotLocaleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BuildBotLocaleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot to build.
-
#bot_version ⇒ String
The version of the bot to build.
-
#locale_id ⇒ String
The identifier of the language and locale that the bot will be used in.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot to build. The identifier is returned in the response from the [CreateBot] operation.
[1]: docs.aws.amazon.com/lexv2/latest/APIReference/API_CreateBot.html
2930 2931 2932 2933 2934 2935 2936 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2930 class BuildBotLocaleRequest < Struct.new( :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot to build. This can only be the draft version of the bot.
2930 2931 2932 2933 2934 2935 2936 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2930 class BuildBotLocaleRequest < Struct.new( :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale that the bot will be used in. The string must match one of the supported locales. All of the intents, slot types, and slots used in the bot must have the same locale. For more information, see [Supported languages].
2930 2931 2932 2933 2934 2935 2936 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2930 class BuildBotLocaleRequest < Struct.new( :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |