Class: Aws::LexModelsV2::Types::BuildBotLocaleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the specified bot.

Returns:

  • (String)


2906
2907
2908
2909
2910
2911
2912
2913
2914
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2906

class BuildBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status,
  :last_build_submitted_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_locale_statusString

The bot’s build status. When the status is ReadyExpressTesting you can test the bot using the utterances defined for the intents and slot types. When the status is Built, the bot is ready for use and can be tested using any utterance.

Returns:

  • (String)


2906
2907
2908
2909
2910
2911
2912
2913
2914
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2906

class BuildBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status,
  :last_build_submitted_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that was built. This is only the draft version of the bot.

Returns:

  • (String)


2906
2907
2908
2909
2910
2911
2912
2913
2914
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2906

class BuildBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status,
  :last_build_submitted_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_build_submitted_date_timeTime

A timestamp indicating the date and time that the bot was last built for this locale.

Returns:

  • (Time)


2906
2907
2908
2909
2910
2911
2912
2913
2914
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2906

class BuildBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status,
  :last_build_submitted_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The language and locale specified of where the bot can be used.

Returns:

  • (String)


2906
2907
2908
2909
2910
2911
2912
2913
2914
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2906

class BuildBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status,
  :last_build_submitted_date_time)
  SENSITIVE = []
  include Aws::Structure
end