Class: Aws::LexModelsV2::Types::ConversationLevelIntentClassificationResultItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The item listing the evaluation of intent level success or failure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#intent_name ⇒ String

The intent name used in the evaluation of intent level success or failure.

Returns:

  • (String)


3275
3276
3277
3278
3279
3280
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3275

class ConversationLevelIntentClassificationResultItem < Struct.new(
  :intent_name,
  :match_result)
  SENSITIVE = []
  include Aws::Structure
end

#match_result ⇒ String

The number of times the specific intent is used in the evaluation of intent level success or failure.

Returns:

  • (String)


3275
3276
3277
3278
3279
3280
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3275

class ConversationLevelIntentClassificationResultItem < Struct.new(
  :intent_name,
  :match_result)
  SENSITIVE = []
  include Aws::Structure
end