Class: Aws::LexModelsV2::Types::CreateBotLocaleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_filler_settings ⇒ Types::AudioFillerSettings

Audio filler settings to configure for the new bot locale. When enabled, Amazon Lex plays a brief background audio filler during speech-to-speech interactions to mask processing delays. Requires unifiedSpeechSettings (speech-to-speech) to be configured on the bot locale.



3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The identifier of the bot to create the locale for.

Returns:

  • (String)


3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot to create the locale for. This can only be the draft version of the bot.

Returns:

  • (String)


3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the bot locale. Use this to help identify the bot locale in lists.

Returns:

  • (String)


3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#generative_ai_settings ⇒ Types::GenerativeAISettings

Contains specifications about the generative AI capabilities from Amazon Bedrock that you can turn on for your bot.



3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale that the bot will be used in. The string must match one of the supported locales. All of the intents, slot types, and slots used in the bot must have the same locale. For more information, see Supported languages.

Returns:

  • (String)


3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nlu_intent_confidence_threshold ⇒ Float

Determines the threshold where Amazon Lex will insert the AMAZON.FallbackIntent, AMAZON.KendraSearchIntent, or both when returning alternative intents. AMAZON.FallbackIntent and AMAZON.KendraSearchIntent are only inserted if they are configured for the bot.

For example, suppose a bot is configured with the confidence threshold of 0.80 and the AMAZON.FallbackIntent. Amazon Lex returns three alternative intents with the following confidence scores: IntentA (0.70), IntentB (0.60), IntentC (0.50). The response from the RecognizeText operation would be:

  • AMAZON.FallbackIntent

  • IntentA

  • IntentB

  • IntentC

Returns:

  • (Float)


3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#speaker_diarization_settings ⇒ Types::SpeakerDiarizationSettings

The speaker diarization settings to configure for the new bot locale. When enabled, Amazon Lex restricts speech detection to the primary (loudest) speaker during streaming audio conversations.



3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#speech_detection_sensitivity ⇒ String

The sensitivity level for voice activity detection (VAD) in the bot locale. This setting helps optimize speech recognition accuracy by adjusting how the system responds to background noise during voice interactions.

Returns:

  • (String)


3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings

Speech-to-text settings to configure for the new bot locale.



3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#unified_speech_settings ⇒ Types::UnifiedSpeechSettings

Unified speech settings to configure for the new bot locale.



3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#voice_settings ⇒ Types::VoiceSettings

The Amazon Polly voice ID that Amazon Lex uses for voice interaction with the user.



3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3686

class CreateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end