Class: Aws::LexModelsV2::Types::CreateBotLocaleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::CreateBotLocaleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The specified bot identifier.
-
#bot_locale_status ⇒ String
The status of the bot.
-
#bot_version ⇒ String
The specified bot version.
-
#creation_date_time ⇒ Time
A timestamp specifying the date and time that the bot locale was created.
-
#description ⇒ String
The specified description of the bot locale.
-
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains specifications about the generative AI capabilities from Amazon Bedrock that you can turn on for your bot.
-
#locale_id ⇒ String
The specified locale identifier.
-
#locale_name ⇒ String
The specified locale name.
-
#nlu_intent_confidence_threshold ⇒ Float
The specified confidence threshold for inserting the
AMAZON.FallbackIntentandAMAZON.KendraSearchIntentintents. -
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) that was specified for the bot locale.
-
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The speech-to-text settings configured for the created bot locale.
-
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The unified speech settings configured for the created bot locale.
-
#voice_settings ⇒ Types::VoiceSettings
The Amazon Polly voice ID that Amazon Lex uses for voice interaction with the user.
Instance Attribute Details
#bot_id ⇒ String
The specified bot identifier.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_locale_status ⇒ String
The status of the bot.
When the status is Creating the bot locale is being configured. When the status is Building Amazon Lex is building the bot for testing and use.
If the status of the bot is ReadyExpressTesting, you can test the bot using the exact utterances specified in the bots’ intents. When the bot is ready for full testing or to run, the status is Built.
If there was a problem with building the bot, the status is Failed. If the bot was saved but not built, the status is NotBuilt.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The specified bot version.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp specifying the date and time that the bot locale was created.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The specified description of the bot locale.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains specifications about the generative AI capabilities from Amazon Bedrock that you can turn on for your bot.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The specified locale identifier.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#locale_name ⇒ String
The specified locale name.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#nlu_intent_confidence_threshold ⇒ Float
The specified confidence threshold for inserting the AMAZON.FallbackIntent and AMAZON.KendraSearchIntent intents.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) that was specified for the bot locale.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The speech-to-text settings configured for the created bot locale.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The unified speech settings configured for the created bot locale.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#voice_settings ⇒ Types::VoiceSettings
The Amazon Polly voice ID that Amazon Lex uses for voice interaction with the user.
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3693 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |