Class: Aws::LexModelsV2::Types::CreateBotReplicaResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique bot ID of the replicated bot generated.

Returns:

  • (String)


3845
3846
3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3845

class CreateBotReplicaResponse < Struct.new(
  :bot_id,
  :replica_region,
  :source_region,
  :creation_date_time,
  :bot_replica_status)
  SENSITIVE = []
  include Aws::Structure
end

#bot_replica_status ⇒ String

The operational status of the replicated bot generated.

Returns:

  • (String)


3845
3846
3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3845

class CreateBotReplicaResponse < Struct.new(
  :bot_id,
  :replica_region,
  :source_region,
  :creation_date_time,
  :bot_replica_status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The creation date and time of the replicated bot generated.

Returns:

  • (Time)


3845
3846
3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3845

class CreateBotReplicaResponse < Struct.new(
  :bot_id,
  :replica_region,
  :source_region,
  :creation_date_time,
  :bot_replica_status)
  SENSITIVE = []
  include Aws::Structure
end

#replica_region ⇒ String

The region of the replicated bot generated.

Returns:

  • (String)


3845
3846
3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3845

class CreateBotReplicaResponse < Struct.new(
  :bot_id,
  :replica_region,
  :source_region,
  :creation_date_time,
  :bot_replica_status)
  SENSITIVE = []
  include Aws::Structure
end

#source_region ⇒ String

The source region for the source bot used for the replicated bot generated.

Returns:

  • (String)


3845
3846
3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3845

class CreateBotReplicaResponse < Struct.new(
  :bot_id,
  :replica_region,
  :source_region,
  :creation_date_time,
  :bot_replica_status)
  SENSITIVE = []
  include Aws::Structure
end