Class: Aws::LexModelsV2::Types::CreateBotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_membersArray<Types::BotMember>

The list of bot members in a network to be created.

Returns:



3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_nameString

The name of the bot. The bot name must be unique in the account that creates the bot.

Returns:

  • (String)


3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_tagsHash<String,String>

A list of tags to add to the bot. You can only add tags when you create a bot. You can’t use the ‘UpdateBot` operation to update tags. To update tags, use the `TagResource` operation.

Returns:

  • (Hash<String,String>)


3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_typeString

The type of a bot to create.

Returns:

  • (String)


3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#data_privacyTypes::DataPrivacy

Provides information on additional privacy protections Amazon Lex should use with the bot’s data.

Returns:



3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the bot. It appears in lists to help you identify a particular bot.

Returns:

  • (String)


3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#error_log_settingsTypes::ErrorLogSettings

Specifies the configuration for error logging during bot creation.



3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idle_session_ttl_in_secondsInteger

The time, in seconds, that Amazon Lex should keep information about a user’s conversation with the bot.

A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout.

You can specify between 60 (1 minute) and 86,400 (24 hours) seconds.

Returns:

  • (Integer)


3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that has permission to access the bot.

Returns:

  • (String)


3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#test_bot_alias_tagsHash<String,String>

A list of tags to add to the test alias for a bot. You can only add tags when you create a bot. You can’t use the ‘UpdateAlias` operation to update tags. To update tags on the test alias, use the `TagResource` operation.

Returns:

  • (Hash<String,String>)


3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3894

class CreateBotRequest < Struct.new(
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end