Class: Aws::LexModelsV2::Types::CreateBotResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

A unique identifier for a particular bot. You use this to identify the bot when you call other Amazon Lex API operations.

Returns:

  • (String)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_members ⇒ Array<Types::BotMember>

The list of bots in a network that was created.

Returns:



3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_name ⇒ String

The name specified for the bot.

Returns:

  • (String)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_status ⇒ String

Shows the current status of the bot. The bot is first in the Creating status. Once the bot is read for use, it changes to the Available status. After the bot is created, you can use the DRAFT version of the bot.

Returns:

  • (String)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_tags ⇒ Hash<String,String>

A list of tags associated with the bot.

Returns:

  • (Hash<String,String>)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_type ⇒ String

The type of a bot that was created.

Returns:

  • (String)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

A timestamp indicating the date and time that the bot was created.

Returns:

  • (Time)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#data_privacy ⇒ Types::DataPrivacy

The data privacy settings specified for the bot.

Returns:



3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description specified for the bot.

Returns:

  • (String)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#error_log_settings ⇒ Types::ErrorLogSettings

Specifies configuration settings for delivering error logs to Cloudwatch Logs in an Amazon Lex bot response.



3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idle_session_ttl_in_seconds ⇒ Integer

The session idle time specified for the bot.

Returns:

  • (Integer)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The IAM role specified for the bot.

Returns:

  • (String)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#test_bot_alias_tags ⇒ Hash<String,String>

A list of tags associated with the test alias for the bot.

Returns:

  • (Hash<String,String>)


3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3987

class CreateBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :bot_tags,
  :test_bot_alias_tags,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end