Class: Aws::LexModelsV2::Types::CreateBotVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The bot identifier specified in the request.

Returns:

  • (String)


4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4060

class CreateBotVersionResponse < Struct.new(
  :bot_id,
  :description,
  :bot_version,
  :bot_version_locale_specification,
  :bot_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_status ⇒ String

When you send a request to create or update a bot, Amazon Lex sets the status response element to Creating. After Amazon Lex builds the bot, it sets status to Available. If Amazon Lex can't build the bot, it sets status to Failed.

Returns:

  • (String)


4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4060

class CreateBotVersionResponse < Struct.new(
  :bot_id,
  :description,
  :bot_version,
  :bot_version_locale_specification,
  :bot_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version number assigned to the version.

Returns:

  • (String)


4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4060

class CreateBotVersionResponse < Struct.new(
  :bot_id,
  :description,
  :bot_version,
  :bot_version_locale_specification,
  :bot_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version_locale_specification ⇒ Hash<String,Types::BotVersionLocaleDetails>

The source versions used for each locale in the new version.

Returns:



4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4060

class CreateBotVersionResponse < Struct.new(
  :bot_id,
  :description,
  :bot_version,
  :bot_version_locale_specification,
  :bot_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

A timestamp of the date and time that the version was created.

Returns:

  • (Time)


4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4060

class CreateBotVersionResponse < Struct.new(
  :bot_id,
  :description,
  :bot_version,
  :bot_version_locale_specification,
  :bot_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the version specified in the request.

Returns:

  • (String)


4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4060

class CreateBotVersionResponse < Struct.new(
  :bot_id,
  :description,
  :bot_version,
  :bot_version_locale_specification,
  :bot_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end