Class: Aws::LexModelsV2::Types::CreateExportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:file_password]

Instance Attribute Summary collapse

Instance Attribute Details

#file_format ⇒ String

The file format of the bot or bot locale definition files.

Returns:

  • (String)


4088
4089
4090
4091
4092
4093
4094
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4088

class CreateExportRequest < Struct.new(
  :resource_specification,
  :file_format,
  :file_password)
  SENSITIVE = [:file_password]
  include Aws::Structure
end

#file_password ⇒ String

An password to use to encrypt the exported archive. Using a password is optional, but you should encrypt the archive to protect the data in transit between Amazon Lex and your local computer.

Returns:

  • (String)


4088
4089
4090
4091
4092
4093
4094
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4088

class CreateExportRequest < Struct.new(
  :resource_specification,
  :file_format,
  :file_password)
  SENSITIVE = [:file_password]
  include Aws::Structure
end

#resource_specification ⇒ Types::ExportResourceSpecification

Specifies the type of resource to export, either a bot or a bot locale. You can only specify one type of resource to export.



4088
4089
4090
4091
4092
4093
4094
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4088

class CreateExportRequest < Struct.new(
  :resource_specification,
  :file_format,
  :file_password)
  SENSITIVE = [:file_password]
  include Aws::Structure
end