Class: Aws::LexModelsV2::Types::CreateIntentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the intent.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the intent.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

A timestamp of the date and time that the intent was created.

Returns:

  • (Time)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description specified for the intent.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dialog_code_hook ⇒ Types::DialogCodeHookSettings

The dialog Lambda function specified for the intent.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings

The fulfillment Lambda function specified for the intent.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#initial_response_setting ⇒ Types::InitialResponseSetting

Configuration settings for the response that is sent to the user at the beginning of a conversation, before eliciting slot values.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#input_contexts ⇒ Array<Types::InputContext>

The list of input contexts specified for the intent.

Returns:



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_closing_setting ⇒ Types::IntentClosingSetting

The closing setting specified for the intent.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting

The confirmation setting specified for the intent.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_display_name ⇒ String

The display name specified for the intent.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

A unique identifier for the intent.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_name ⇒ String

The name specified for the intent.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_configuration ⇒ Types::KendraConfiguration

Configuration for searching a Amazon Kendra index specified for the intent.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The locale that the intent is specified to use.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#output_contexts ⇒ Array<Types::OutputContext>

The list of output contexts specified for the intent.

Returns:



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#parent_intent_signature ⇒ String

The signature of the parent intent specified for the intent.

Returns:

  • (String)


4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration

Qinconnect intent configuration details for the create intent response.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration

Details about the the configuration of the built-in Amazon.QnAIntent.



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sample_utterances ⇒ Array<Types::SampleUtterance>

The sample utterances specified for the intent.

Returns:



4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4391

class CreateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end