Class: Aws::LexModelsV2::Types::CreateSlotTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::CreateSlotTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier for the bot associated with the slot type.
-
#bot_version ⇒ String
The version of the bot associated with the slot type.
-
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the slot type was created.
-
#description ⇒ String
The description specified for the slot type.
-
#external_source_setting ⇒ Types::ExternalSourceSetting
The type of external information used to create the slot type.
-
#locale_id ⇒ String
The specified language and local specified for the slot type.
-
#parent_slot_type_signature ⇒ String
The signature of the base slot type specified for the slot type.
-
#slot_type_id ⇒ String
The unique identifier assigned to the slot type.
-
#slot_type_name ⇒ String
The name specified for the slot type.
-
#slot_type_values ⇒ Array<Types::SlotTypeValue>
The list of values that the slot type can assume.
-
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
The strategy that Amazon Lex uses to select a value from the list of possible values.
Instance Attribute Details
#bot_id ⇒ String
The identifier for the bot associated with the slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the slot type was created.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description specified for the slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#external_source_setting ⇒ Types::ExternalSourceSetting
The type of external information used to create the slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The specified language and local specified for the slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#parent_slot_type_signature ⇒ String
The signature of the base slot type specified for the slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_id ⇒ String
The unique identifier assigned to the slot type. Use this to identify the slot type in the UpdateSlotType and DeleteSlotType operations.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_name ⇒ String
The name specified for the slot type.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_values ⇒ Array<Types::SlotTypeValue>
The list of values that the slot type can assume.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
The strategy that Amazon Lex uses to select a value from the list of possible values.
4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4773 class CreateSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |