Class: Aws::LexModelsV2::Types::CustomVocabularyItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The unique custom vocabulary item from the custom vocabulary list.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_as ⇒ String

The DisplayAs value for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (String)


5060
5061
5062
5063
5064
5065
5066
5067
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5060

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end

#item_id ⇒ String

The unique item identifer for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (String)


5060
5061
5062
5063
5064
5065
5066
5067
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5060

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end

#phrase ⇒ String

The unique phrase for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (String)


5060
5061
5062
5063
5064
5065
5066
5067
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5060

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end

#weight ⇒ Integer

The weight assigned for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (Integer)


5060
5061
5062
5063
5064
5065
5066
5067
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5060

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end