Class: Aws::LexModelsV2::Types::DTMFSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DTMFSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Specifies the DTMF input specifications.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deletion_character ⇒ String
The DTMF character that clears the accumulated DTMF digits and immediately ends the input.
-
#end_character ⇒ String
The DTMF character that immediately ends input.
-
#end_timeout_ms ⇒ Integer
How long the bot should wait after the last DTMF character input before assuming that the input has concluded.
-
#max_length ⇒ Integer
The maximum number of DTMF digits allowed in an utterance.
Instance Attribute Details
#deletion_character ⇒ String
The DTMF character that clears the accumulated DTMF digits and immediately ends the input.
5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5000 class DTMFSpecification < Struct.new( :max_length, :end_timeout_ms, :deletion_character, :end_character) SENSITIVE = [] include Aws::Structure end |
#end_character ⇒ String
The DTMF character that immediately ends input. If the user does not press this character, the input ends after the end timeout.
5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5000 class DTMFSpecification < Struct.new( :max_length, :end_timeout_ms, :deletion_character, :end_character) SENSITIVE = [] include Aws::Structure end |
#end_timeout_ms ⇒ Integer
How long the bot should wait after the last DTMF character input before assuming that the input has concluded.
5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5000 class DTMFSpecification < Struct.new( :max_length, :end_timeout_ms, :deletion_character, :end_character) SENSITIVE = [] include Aws::Structure end |
#max_length ⇒ Integer
The maximum number of DTMF digits allowed in an utterance.
5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5000 class DTMFSpecification < Struct.new( :max_length, :end_timeout_ms, :deletion_character, :end_character) SENSITIVE = [] include Aws::Structure end |