Class: Aws::LexModelsV2::Types::DataSourceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains details about the configuration of the knowledge store used for the AMAZON.QnAIntent. You must have already created the knowledge store and indexed the documents within it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bedrock_knowledge_store_configurationTypes::BedrockKnowledgeStoreConfiguration

Contains details about the configuration of the Amazon Bedrock knowledge base used for the AMAZON.QnAIntent. To set up a knowledge base, follow the steps at [Building a knowledge base].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base.html



5090
5091
5092
5093
5094
5095
5096
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5090

class DataSourceConfiguration < Struct.new(
  :opensearch_configuration,
  :kendra_configuration,
  :bedrock_knowledge_store_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_configurationTypes::QnAKendraConfiguration

Contains details about the configuration of the Amazon Kendra index used for the AMAZON.QnAIntent. To create a Amazon Kendra index, follow the steps at [Creating an index].

[1]: docs.aws.amazon.com/kendra/latest/dg/create-index.html



5090
5091
5092
5093
5094
5095
5096
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5090

class DataSourceConfiguration < Struct.new(
  :opensearch_configuration,
  :kendra_configuration,
  :bedrock_knowledge_store_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#opensearch_configurationTypes::OpensearchConfiguration

Contains details about the configuration of the Amazon OpenSearch Service database used for the AMAZON.QnAIntent. To create a domain, follow the steps at [Creating and managing Amazon OpenSearch Service domains].

[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/createupdatedomains.html



5090
5091
5092
5093
5094
5095
5096
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5090

class DataSourceConfiguration < Struct.new(
  :opensearch_configuration,
  :kendra_configuration,
  :bedrock_knowledge_store_configuration)
  SENSITIVE = []
  include Aws::Structure
end