Class: Aws::LexModelsV2::Types::DefaultConditionalBranch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

A set of actions that Amazon Lex should run if none of the other conditions are met.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_stepTypes::DialogState

The next step in the conversation.

Returns:



5154
5155
5156
5157
5158
5159
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5154

class DefaultConditionalBranch < Struct.new(
  :next_step,
  :response)
  SENSITIVE = []
  include Aws::Structure
end

#responseTypes::ResponseSpecification

Specifies a list of message groups that Amazon Lex uses to respond the user input.



5154
5155
5156
5157
5158
5159
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5154

class DefaultConditionalBranch < Struct.new(
  :next_step,
  :response)
  SENSITIVE = []
  include Aws::Structure
end