Class: Aws::LexModelsV2::Types::DeleteBotAnalyzerRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DeleteBotAnalyzerRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_analyzer_request_id ⇒ String
The unique identifier of the analysis request whose recommendations should be deleted.
-
#bot_id ⇒ String
The unique identifier of the bot.
Instance Attribute Details
#bot_analyzer_request_id ⇒ String
The unique identifier of the analysis request whose recommendations should be deleted.
5224 5225 5226 5227 5228 5229 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5224 class DeleteBotAnalyzerRecommendationRequest < Struct.new( :bot_id, :bot_analyzer_request_id) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot.
5224 5225 5226 5227 5228 5229 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5224 class DeleteBotAnalyzerRecommendationRequest < Struct.new( :bot_id, :bot_analyzer_request_id) SENSITIVE = [] include Aws::Structure end |