Class: Aws::LexModelsV2::Types::DeleteBotLocaleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot that contains the locale.

Returns:

  • (String)


5347
5348
5349
5350
5351
5352
5353
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5347

class DeleteBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the locale.

Returns:

  • (String)


5347
5348
5349
5350
5351
5352
5353
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5347

class DeleteBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale that will be deleted. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


5347
5348
5349
5350
5351
5352
5353
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5347

class DeleteBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end