Class: Aws::LexModelsV2::Types::DeleteBotLocaleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot that contained the deleted locale.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283

class DeleteBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status)
  SENSITIVE = []
  include Aws::Structure
end

#bot_locale_statusString

The status of deleting the bot locale. The locale first enters the Deleting status. Once the locale is deleted it no longer appears in the list of locales for the bot.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283

class DeleteBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that contained the deleted locale.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283

class DeleteBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The language and locale of the deleted locale.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283

class DeleteBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_locale_status)
  SENSITIVE = []
  include Aws::Structure
end