Class: Aws::LexModelsV2::Types::DeleteBotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot to delete.

Returns:

  • (String)


5439
5440
5441
5442
5443
5444
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5439

class DeleteBotRequest < Struct.new(
  :bot_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_check ⇒ Boolean

By default, Amazon Lex checks if any other resource, such as an alias or bot network, is using the bot version before it is deleted and throws a ResourceInUseException exception if the bot is being used by another resource. Set this parameter to true to skip this check and remove the bot even if it is being used by another resource.

Returns:

  • (Boolean)


5439
5440
5441
5442
5443
5444
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5439

class DeleteBotRequest < Struct.new(
  :bot_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end