Class: Aws::LexModelsV2::Types::DeleteCustomVocabularyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The unique identifier of the bot to remove the custom vocabulary from.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5510

class DeleteCustomVocabularyRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot to remove the custom vocabulary from.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5510

class DeleteCustomVocabularyRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The locale identifier for the locale that contains the custom vocabulary to remove.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5510

class DeleteCustomVocabularyRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end