Class: Aws::LexModelsV2::Types::DeleteIntentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the intent.

Returns:

  • (String)


5664
5665
5666
5667
5668
5669
5670
5671
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5664

class DeleteIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the intent.

Returns:

  • (String)


5664
5665
5666
5667
5668
5669
5670
5671
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5664

class DeleteIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The unique identifier of the intent to delete.

Returns:

  • (String)


5664
5665
5666
5667
5668
5669
5670
5671
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5664

class DeleteIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale where the bot will be deleted. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


5664
5665
5666
5667
5668
5669
5670
5671
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5664

class DeleteIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end