Class: Aws::LexModelsV2::Types::DeleteResourcePolicyStatementResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arn ⇒ String

The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy statement was removed from.

Returns:

  • (String)


5758
5759
5760
5761
5762
5763
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5758

class DeleteResourcePolicyStatementResponse < Struct.new(
  :resource_arn,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#revision_id ⇒ String

The current revision of the resource policy. Use the revision ID to make sure that you are updating the most current version of a resource policy when you add a policy statement to a resource, delete a resource, or update a resource.

Returns:

  • (String)


5758
5759
5760
5761
5762
5763
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5758

class DeleteResourcePolicyStatementResponse < Struct.new(
  :resource_arn,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end