Class: Aws::LexModelsV2::Types::DeleteSlotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the slot to delete.

Returns:

  • (String)


5793
5794
5795
5796
5797
5798
5799
5800
5801
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5793

class DeleteSlotRequest < Struct.new(
  :slot_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the slot to delete.

Returns:

  • (String)


5793
5794
5795
5796
5797
5798
5799
5800
5801
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5793

class DeleteSlotRequest < Struct.new(
  :slot_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The identifier of the intent associated with the slot.

Returns:

  • (String)


5793
5794
5795
5796
5797
5798
5799
5800
5801
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5793

class DeleteSlotRequest < Struct.new(
  :slot_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale that the slot will be deleted from. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


5793
5794
5795
5796
5797
5798
5799
5800
5801
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5793

class DeleteSlotRequest < Struct.new(
  :slot_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id)
  SENSITIVE = []
  include Aws::Structure
end

#slot_id ⇒ String

The identifier of the slot to delete.

Returns:

  • (String)


5793
5794
5795
5796
5797
5798
5799
5800
5801
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5793

class DeleteSlotRequest < Struct.new(
  :slot_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id)
  SENSITIVE = []
  include Aws::Structure
end