Class: Aws::LexModelsV2::Types::DeleteSlotTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the slot type.

Returns:

  • (String)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5834

class DeleteSlotTypeRequest < Struct.new(
  :slot_type_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the slot type.

Returns:

  • (String)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5834

class DeleteSlotTypeRequest < Struct.new(
  :slot_type_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale that the slot type will be deleted from. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5834

class DeleteSlotTypeRequest < Struct.new(
  :slot_type_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_check ⇒ Boolean

By default, the DeleteSlotType operations throws a ResourceInUseException exception if you try to delete a slot type used by a slot. Set the skipResourceInUseCheck parameter to true to skip this check and remove the slot type even if a slot uses it.

Returns:

  • (Boolean)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5834

class DeleteSlotTypeRequest < Struct.new(
  :slot_type_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_id ⇒ String

The identifier of the slot type to delete.

Returns:

  • (String)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5834

class DeleteSlotTypeRequest < Struct.new(
  :slot_type_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end