Class: Aws::LexModelsV2::Types::DeleteUtterancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot that contains the utterances.



5883
5884
5885
5886
5887
5888
5889
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5883

class DeleteUtterancesRequest < Struct.new(
  :bot_id,
  :locale_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale where the utterances were collected. The string must match one of the supported locales. For more information, see Supported languages.



5883
5884
5885
5886
5887
5888
5889
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5883

class DeleteUtterancesRequest < Struct.new(
  :bot_id,
  :locale_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_id ⇒ String

The unique identifier of the session with the user. The ID is returned in the response from the RecognizeText and RecognizeUtterance operations.



5883
5884
5885
5886
5887
5888
5889
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5883

class DeleteUtterancesRequest < Struct.new(
  :bot_id,
  :locale_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end