Class: Aws::LexModelsV2::Types::DescribeBotAnalyzerRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_analyzer_request_id ⇒ String

The unique identifier of the analysis request.

Returns:

  • (String)


6009
6010
6011
6012
6013
6014
6015
6016
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6009

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The unique identifier of the bot.

Returns:

  • (String)


6009
6010
6011
6012
6013
6014
6015
6016
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6009

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of recommendations to return in the response. The default is 5.

Returns:

  • (Integer)


6009
6010
6011
6012
6013
6014
6015
6016
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6009

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from a previous request was truncated, the nextToken value is used to retrieve the next page of recommendations.

Returns:

  • (String)


6009
6010
6011
6012
6013
6014
6015
6016
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6009

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end