Class: Aws::LexModelsV2::Types::DescribeBotLocaleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the locale.

Returns:

  • (String)


6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6085

class DescribeBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the locale.

Returns:

  • (String)


6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6085

class DescribeBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The unique identifier of the locale to describe. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6085

class DescribeBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end