Class: Aws::LexModelsV2::Types::DescribeBotRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot associated with the bot recommendation.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244

class DescribeBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_id ⇒ String

The identifier of the bot recommendation to describe.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244

class DescribeBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the bot recommendation.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244

class DescribeBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the bot recommendation to describe. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244

class DescribeBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end