Class: Aws::LexModelsV2::Types::DescribeBotRecommendationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the bot recommendation.

Returns:

  • (String)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_id ⇒ String

The identifier of the bot recommendation being described.

Returns:

  • (String)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_results ⇒ Types::BotRecommendationResults

The object representing the URL of the bot definition, the URL of the associated transcript and a statistical summary of the bot recommendation results.



6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_status ⇒ String

The status of the bot recommendation. If the status is Failed, then the reasons for the failure are listed in the failureReasons field.

Returns:

  • (String)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the bot recommendation.

Returns:

  • (String)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The date and time that the bot recommendation was created.

Returns:

  • (Time)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_setting ⇒ Types::EncryptionSetting

The object representing the passwords that were used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.



6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasons ⇒ Array<String>

If botRecommendationStatus is Failed, Amazon Lex explains why.

Returns:

  • (Array<String>)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time that the bot recommendation was last updated.

Returns:

  • (Time)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the bot recommendation to describe.

Returns:

  • (String)


6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_source_setting ⇒ Types::TranscriptSourceSetting

The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.



6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6306

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end