Class: Aws::LexModelsV2::Types::DescribeBotResourceGenerationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot for which to return the generation details.

Returns:

  • (String)


6409
6410
6411
6412
6413
6414
6415
6416
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6409

class DescribeBotResourceGenerationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot for which to return the generation details.

Returns:

  • (String)


6409
6410
6411
6412
6413
6414
6415
6416
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6409

class DescribeBotResourceGenerationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_id)
  SENSITIVE = []
  include Aws::Structure
end

#generation_id ⇒ String

The unique identifier of the generation request for which to return the generation details.

Returns:

  • (String)


6409
6410
6411
6412
6413
6414
6415
6416
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6409

class DescribeBotResourceGenerationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The locale of the bot for which to return the generation details.

Returns:

  • (String)


6409
6410
6411
6412
6413
6414
6415
6416
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6409

class DescribeBotResourceGenerationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_id)
  SENSITIVE = []
  include Aws::Structure
end