Class: Aws::LexModelsV2::Types::DescribeBotResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot.

Returns:

  • (String)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_members ⇒ Array<Types::BotMember>

The list of bots in the network that was described.

Returns:



6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_name ⇒ String

The name of the bot.

Returns:

  • (String)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_status ⇒ String

The current status of the bot. When the status is Available the bot is ready to be used in conversations with users.

Returns:

  • (String)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_type ⇒ String

The type of the bot that was described.

Returns:

  • (String)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

A timestamp of the date and time that the bot was created.

Returns:

  • (Time)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#data_privacy ⇒ Types::DataPrivacy

Settings for managing data privacy of the bot and its conversations with users.

Returns:



6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the bot.

Returns:

  • (String)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#error_log_settings ⇒ Types::ErrorLogSettings

Contains the configuration for error logging that specifies where and how bot errors are recorded, including destinations like CloudWatch Logs.



6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasons ⇒ Array<String>

If the botStatus is Failed, this contains a list of reasons that the bot couldn't be built.

Returns:

  • (Array<String>)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idle_session_ttl_in_seconds ⇒ Integer

The maximum time in seconds that Amazon Lex retains the data gathered in a conversation.

Returns:

  • (Integer)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

A timestamp of the date and time that the bot was last updated.

Returns:

  • (Time)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) of an IAM role that has permission to access the bot.

Returns:

  • (String)


6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6543

class DescribeBotResponse < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :creation_date_time,
  :last_updated_date_time,
  :bot_type,
  :bot_members,
  :failure_reasons,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end