Class: Aws::LexModelsV2::Types::DescribeBotVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot containing the version to return metadata for.

Returns:

  • (String)


6572
6573
6574
6575
6576
6577
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6572

class DescribeBotVersionRequest < Struct.new(
  :bot_id,
  :bot_version)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot to return metadata for.

Returns:

  • (String)


6572
6573
6574
6575
6576
6577
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6572

class DescribeBotVersionRequest < Struct.new(
  :bot_id,
  :bot_version)
  SENSITIVE = []
  include Aws::Structure
end