Class: Aws::LexModelsV2::Types::DescribeBotVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot that contains the version.

Returns:

  • (String)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#bot_members ⇒ Array<Types::BotMember>

The members of bot network in the version that was described.

Returns:



6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#bot_name ⇒ String

The name of the bot that contains the version.

Returns:

  • (String)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#bot_status ⇒ String

The current status of the bot. When the status is Available, the bot version is ready for use.

Returns:

  • (String)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#bot_type ⇒ String

The type of the bot in the version that was described.

Returns:

  • (String)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that was described.

Returns:

  • (String)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

A timestamp of the date and time that the bot version was created.

Returns:

  • (Time)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#data_privacy ⇒ Types::DataPrivacy

Data privacy settings for the bot version.

Returns:



6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description specified for the bot.

Returns:

  • (String)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasons ⇒ Array<String>

If the botStatus is Failed, this contains a list of reasons that the version couldn't be built.

Returns:

  • (Array<String>)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#idle_session_ttl_in_seconds ⇒ Integer

The number of seconds that a session with the bot remains active before it is discarded by Amazon Lex.

Returns:

  • (Integer)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#parent_bot_networks ⇒ Array<Types::ParentBotNetwork>

A list of the networks to which the bot version you described belongs.

Returns:



6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) of an IAM role that has permission to access the bot version.

Returns:

  • (String)


6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6638

class DescribeBotVersionResponse < Struct.new(
  :bot_id,
  :bot_name,
  :bot_version,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_status,
  :failure_reasons,
  :creation_date_time,
  :parent_bot_networks,
  :bot_type,
  :bot_members)
  SENSITIVE = []
  include Aws::Structure
end