Class: Aws::LexModelsV2::Types::DescribeImportResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The date and time that the import was created.

Returns:

  • (Time)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasons ⇒ Array<String>

If the importStatus field is Failed, this provides one or more reasons for the failure.

Returns:

  • (Array<String>)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#import_id ⇒ String

The unique identifier of the described import.

Returns:

  • (String)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#import_status ⇒ String

The status of the import process. When the status is Completed the resource is imported and ready for use.

Returns:

  • (String)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#imported_resource_id ⇒ String

The unique identifier that Amazon Lex assigned to the resource created by the import.

Returns:

  • (String)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#imported_resource_name ⇒ String

The name of the imported resource.

Returns:

  • (String)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time that the import was last updated.

Returns:

  • (Time)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#merge_strategy ⇒ String

The strategy used when there was a name conflict between the imported resource and an existing resource. When the merge strategy is FailOnConflict existing resources are not overwritten and the import fails.

Returns:

  • (String)


6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#resource_specification ⇒ Types::ImportResourceSpecification

The specifications of the imported bot, bot locale, or custom vocabulary.



6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6840

class DescribeImportResponse < Struct.new(
  :import_id,
  :resource_specification,
  :imported_resource_id,
  :imported_resource_name,
  :merge_strategy,
  :import_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end