Class: Aws::LexModelsV2::Types::DescribeIntentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the intent.

Returns:

  • (String)


6878
6879
6880
6881
6882
6883
6884
6885
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6878

class DescribeIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the intent.

Returns:

  • (String)


6878
6879
6880
6881
6882
6883
6884
6885
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6878

class DescribeIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The identifier of the intent to describe.

Returns:

  • (String)


6878
6879
6880
6881
6882
6883
6884
6885
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6878

class DescribeIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the intent to describe. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


6878
6879
6880
6881
6882
6883
6884
6885
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6878

class DescribeIntentRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end