Class: Aws::LexModelsV2::Types::DescribeSlotResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot associated with the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

A timestamp of the date and time that the slot was created.

Returns:

  • (Time)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description specified for the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The identifier of the intent associated with the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

A timestamp of the date and time that the slot was last updated.

Returns:

  • (Time)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The language and locale specified for the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#multiple_values_setting ⇒ Types::MultipleValuesSetting

Indicates whether the slot accepts multiple values in a single utterance.

If the multipleValuesSetting is not set, the default value is false.



7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#obfuscation_setting ⇒ Types::ObfuscationSetting

Whether slot values are shown in Amazon CloudWatch logs. If the value is None, the actual value of the slot is shown in logs.



7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_id ⇒ String

The unique identifier generated for the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_name ⇒ String

The name specified for the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_id ⇒ String

The identifier of the slot type that determines the values entered into the slot.

Returns:

  • (String)


7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#sub_slot_setting ⇒ Types::SubSlotSetting

Specifications for the constituent sub slots and the expression for the composite slot.



7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting

Prompts that Amazon Lex uses to elicit a value for the slot.



7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7161

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end