Class: Aws::LexModelsV2::Types::DescribeSlotTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeSlotTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot associated with the slot type.
-
#bot_version ⇒ String
The version of the bot associated with the slot type.
-
#locale_id ⇒ String
The identifier of the language and locale of the slot type to describe.
-
#slot_type_id ⇒ String
The identifier of the slot type.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot associated with the slot type.
7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7204 class DescribeSlotTypeRequest < Struct.new( :slot_type_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the slot type.
7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7204 class DescribeSlotTypeRequest < Struct.new( :slot_type_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the slot type to describe. The string must match one of the supported locales. For more information, see Supported languages.
7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7204 class DescribeSlotTypeRequest < Struct.new( :slot_type_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#slot_type_id ⇒ String
The identifier of the slot type.
7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7204 class DescribeSlotTypeRequest < Struct.new( :slot_type_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |