Class: Aws::LexModelsV2::Types::DescribeSlotTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeSlotTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot associated with the slot type.
-
#bot_version ⇒ String
The version of the bot associated with the slot type.
-
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the slot type was created.
-
#description ⇒ String
The description specified for the slot type.
-
#external_source_setting ⇒ Types::ExternalSourceSetting
Provides information about the external source of the slot type’s definition.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the slot type was last updated.
-
#locale_id ⇒ String
The language and locale specified for the slot type.
-
#parent_slot_type_signature ⇒ String
The built in slot type used as a parent to this slot type.
-
#slot_type_id ⇒ String
The unique identifier for the slot type.
-
#slot_type_name ⇒ String
The name specified for the slot type.
-
#slot_type_values ⇒ Array<Types::SlotTypeValue>
The values that the slot type can take.
-
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
The strategy that Amazon Lex uses to choose a value from a list of possible values.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot associated with the slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the slot type was created.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description specified for the slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#external_source_setting ⇒ Types::ExternalSourceSetting
Provides information about the external source of the slot type’s definition.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the slot type was last updated.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and locale specified for the slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#parent_slot_type_signature ⇒ String
The built in slot type used as a parent to this slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_id ⇒ String
The unique identifier for the slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_name ⇒ String
The name specified for the slot type.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_values ⇒ Array<Types::SlotTypeValue>
The values that the slot type can take. Includes any synonyms for the slot type values.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
The strategy that Amazon Lex uses to choose a value from a list of possible values.
7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7169 class DescribeSlotTypeResponse < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |