Class: Aws::LexModelsV2::Types::DescribeTestExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_mode ⇒ String

Indicates whether we use streaming or non-streaming APIs are used for the test set execution. For streaming, StartConversation Amazon Lex Runtime API is used. Whereas for non-streaming, RecognizeUtterance and RecognizeText Amazon Lex Runtime API is used.

Returns:

  • (String)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The execution creation date and time for the test set execution.

Returns:

  • (Time)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasons ⇒ Array<String>

Reasons for the failure of the test set execution.

Returns:

  • (Array<String>)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time of the last update for the execution.

Returns:

  • (Time)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#target ⇒ Types::TestExecutionTarget

The target bot for the test set execution details.



7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#test_execution_id ⇒ String

The execution Id for the test set execution.

Returns:

  • (String)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#test_execution_modality ⇒ String

Indicates whether test set is audio or text.

Returns:

  • (String)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#test_execution_status ⇒ String

The test execution status for the test execution.

Returns:

  • (String)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_id ⇒ String

The test set Id for the test set execution.

Returns:

  • (String)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_name ⇒ String

The test set name of the test set execution.

Returns:

  • (String)


7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7347

class DescribeTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :last_updated_date_time,
  :test_execution_status,
  :test_set_id,
  :test_set_name,
  :target,
  :api_mode,
  :test_execution_modality,
  :failure_reasons)
  SENSITIVE = []
  include Aws::Structure
end