Class: Aws::LexModelsV2::Types::DescribeTestSetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The creation date and time for the test set data.

Returns:

  • (Time)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the test set.

Returns:

  • (String)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time for the last update of the test set data.

Returns:

  • (Time)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#modality ⇒ String

Indicates whether the test set is audio or text data.

Returns:

  • (String)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#num_turns ⇒ Integer

The total number of agent and user turn in the test set.

Returns:

  • (Integer)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.

Returns:

  • (String)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the test set.

Returns:

  • (String)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#storage_location ⇒ Types::TestSetStorageLocation

The Amazon S3 storage location for the test set data.



7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_id ⇒ String

The test set Id for the test set response.

Returns:

  • (String)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_name ⇒ String

The test set name of the test set.

Returns:

  • (String)


7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7560

class DescribeTestSetResponse < Struct.new(
  :test_set_id,
  :test_set_name,
  :description,
  :modality,
  :status,
  :role_arn,
  :num_turns,
  :storage_location,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end