Class: Aws::LexModelsV2::Types::EncryptionSetting

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The object representing the passwords that were used to encrypt the data related to the bot recommendation, as well as the KMS key ARN used to encrypt the associated metadata.

Constant Summary collapse

SENSITIVE =
[:bot_locale_export_password, :associated_transcripts_password]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_transcripts_password ⇒ String

The password used to encrypt the associated transcript file.

Returns:

  • (String)


7740
7741
7742
7743
7744
7745
7746
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7740

class EncryptionSetting < Struct.new(
  :kms_key_arn,
  :bot_locale_export_password,
  :associated_transcripts_password)
  SENSITIVE = [:bot_locale_export_password, :associated_transcripts_password]
  include Aws::Structure
end

#bot_locale_export_password ⇒ String

The password used to encrypt the recommended bot recommendation file.

Returns:

  • (String)


7740
7741
7742
7743
7744
7745
7746
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7740

class EncryptionSetting < Struct.new(
  :kms_key_arn,
  :bot_locale_export_password,
  :associated_transcripts_password)
  SENSITIVE = [:bot_locale_export_password, :associated_transcripts_password]
  include Aws::Structure
end

#kms_key_arn ⇒ String

The KMS key ARN used to encrypt the metadata associated with the bot recommendation.

Returns:

  • (String)


7740
7741
7742
7743
7744
7745
7746
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7740

class EncryptionSetting < Struct.new(
  :kms_key_arn,
  :bot_locale_export_password,
  :associated_transcripts_password)
  SENSITIVE = [:bot_locale_export_password, :associated_transcripts_password]
  include Aws::Structure
end