Class: Aws::LexModelsV2::Types::ErrorLogSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Settings parameters for the error logs, whether it is enabled or disabled.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabled ⇒ Boolean

Settings parameters for the error logs, when it is enabled.

Returns:

  • (Boolean)


7757
7758
7759
7760
7761
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7757

class ErrorLogSettings < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end