Class: Aws::LexModelsV2::Types::ExportSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Provides summary information about an export in an export list.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The date and time that the export was created.

Returns:

  • (Time)


7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7915

class ExportSummary < Struct.new(
  :export_id,
  :resource_specification,
  :file_format,
  :export_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_id ⇒ String

The unique identifier that Amazon Lex assigned to the export.

Returns:

  • (String)


7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7915

class ExportSummary < Struct.new(
  :export_id,
  :resource_specification,
  :file_format,
  :export_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_status ⇒ String

The status of the export. When the status is Completed the export is ready to download.

Returns:

  • (String)


7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7915

class ExportSummary < Struct.new(
  :export_id,
  :resource_specification,
  :file_format,
  :export_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#file_format ⇒ String

The file format used in the export files.

Returns:

  • (String)


7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7915

class ExportSummary < Struct.new(
  :export_id,
  :resource_specification,
  :file_format,
  :export_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time that the export was last updated.

Returns:

  • (Time)


7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7915

class ExportSummary < Struct.new(
  :export_id,
  :resource_specification,
  :file_format,
  :export_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#resource_specification ⇒ Types::ExportResourceSpecification

Information about the bot or bot locale that was exported.



7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7915

class ExportSummary < Struct.new(
  :export_id,
  :resource_specification,
  :file_format,
  :export_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end