Class: Aws::LexModelsV2::Types::FulfillmentStartResponseSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Provides settings for a message that is sent to the user when a fulfillment Lambda function starts running.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_interruptBoolean

Determines whether the user can interrupt the start message while it is playing.

Returns:

  • (Boolean)


8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8003

class FulfillmentStartResponseSpecification < Struct.new(
  :delay_in_seconds,
  :message_groups,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end

#delay_in_secondsInteger

The delay between when the Lambda fulfillment function starts running and the start message is played. If the Lambda function returns before the delay is over, the start message isn’t played.

Returns:

  • (Integer)


8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8003

class FulfillmentStartResponseSpecification < Struct.new(
  :delay_in_seconds,
  :message_groups,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end

#message_groupsArray<Types::MessageGroup>

1 - 5 message groups that contain start messages. Amazon Lex chooses one of the messages to play to the user.

Returns:



8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8003

class FulfillmentStartResponseSpecification < Struct.new(
  :delay_in_seconds,
  :message_groups,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end