Class: Aws::LexModelsV2::Types::GenerateBotElementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::GenerateBotElementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The bot unique Id for the bot request to generate utterances.
-
#bot_version ⇒ String
The bot version for the bot request to generate utterances.
-
#intent_id ⇒ String
The intent unique Id for the bot request to generate utterances.
-
#locale_id ⇒ String
The unique locale Id for the bot request to generate utterances.
Instance Attribute Details
#bot_id ⇒ String
The bot unique Id for the bot request to generate utterances.
8120 8121 8122 8123 8124 8125 8126 8127 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8120 class GenerateBotElementRequest < Struct.new( :intent_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The bot version for the bot request to generate utterances.
8120 8121 8122 8123 8124 8125 8126 8127 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8120 class GenerateBotElementRequest < Struct.new( :intent_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The intent unique Id for the bot request to generate utterances.
8120 8121 8122 8123 8124 8125 8126 8127 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8120 class GenerateBotElementRequest < Struct.new( :intent_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The unique locale Id for the bot request to generate utterances.
8120 8121 8122 8123 8124 8125 8126 8127 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8120 class GenerateBotElementRequest < Struct.new( :intent_id, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |