Class: Aws::LexModelsV2::Types::GenerateBotElementResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique bot Id for the bot which received the response.

Returns:

  • (String)


8151
8152
8153
8154
8155
8156
8157
8158
8159
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8151

class GenerateBotElementResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sample_utterances)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The unique bot version for the bot which received the response.

Returns:

  • (String)


8151
8152
8153
8154
8155
8156
8157
8158
8159
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8151

class GenerateBotElementResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sample_utterances)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The unique intent Id for the bot which received the response.

Returns:

  • (String)


8151
8152
8153
8154
8155
8156
8157
8158
8159
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8151

class GenerateBotElementResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sample_utterances)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The unique locale Id for the bot which received the response.

Returns:

  • (String)


8151
8152
8153
8154
8155
8156
8157
8158
8159
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8151

class GenerateBotElementResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sample_utterances)
  SENSITIVE = []
  include Aws::Structure
end

#sample_utterances ⇒ Array<Types::SampleUtterance>

The sample utterances for the bot which received the response.

Returns:



8151
8152
8153
8154
8155
8156
8157
8158
8159
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8151

class GenerateBotElementResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sample_utterances)
  SENSITIVE = []
  include Aws::Structure
end