Class: Aws::LexModelsV2::Types::GenerationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains information about a generation request made for the bot locale.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The date and time at which the generation request was made.

Returns:

  • (Time)


8209
8210
8211
8212
8213
8214
8215
8216
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8209

class GenerationSummary < Struct.new(
  :generation_id,
  :generation_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#generation_id ⇒ String

The unique identifier of the generation request.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8209

class GenerationSummary < Struct.new(
  :generation_id,
  :generation_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#generation_status ⇒ String

The status of the generation request.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8209

class GenerationSummary < Struct.new(
  :generation_id,
  :generation_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time at which the generation request was last updated.

Returns:

  • (Time)


8209
8210
8211
8212
8213
8214
8215
8216
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8209

class GenerationSummary < Struct.new(
  :generation_id,
  :generation_status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end