Class: Aws::LexModelsV2::Types::IntentLevelSlotResolutionTestResults

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Indicates the success or failure of slots at the intent level.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#items ⇒ Array<Types::IntentLevelSlotResolutionTestResultItem>

Indicates the items for the slot level resolution for the intents.



8859
8860
8861
8862
8863
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8859

class IntentLevelSlotResolutionTestResults < Struct.new(
  :items)
  SENSITIVE = []
  include Aws::Structure
end