Class: Aws::LexModelsV2::Types::IntentOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Override settings to configure the intent state.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ String

The name of the intent. Only required when you're switching intents.

Returns:

  • (String)


8880
8881
8882
8883
8884
8885
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8880

class IntentOverride < Struct.new(
  :name,
  :slots)
  SENSITIVE = []
  include Aws::Structure
end

#slots ⇒ Hash<String,Types::SlotValueOverride>

A map of all of the slot value overrides for the intent. The name of the slot maps to the value of the slot. Slots that are not included in the map aren't overridden.

Returns:



8880
8881
8882
8883
8884
8885
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8880

class IntentOverride < Struct.new(
  :name,
  :slots)
  SENSITIVE = []
  include Aws::Structure
end