Class: Aws::LexModelsV2::Types::IntentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::IntentSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Summary information about an intent returned by the ListIntents operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the intent.
-
#input_contexts ⇒ Array<Types::InputContext>
The input contexts that must be active for this intent to be considered for recognition.
-
#intent_display_name ⇒ String
The display name of the intent.
-
#intent_id ⇒ String
The unique identifier assigned to the intent.
-
#intent_name ⇒ String
The name of the intent.
-
#last_updated_date_time ⇒ Time
The timestamp of the date and time that the intent was last updated.
-
#output_contexts ⇒ Array<Types::OutputContext>
The output contexts that are activated when this intent is fulfilled.
-
#parent_intent_signature ⇒ String
If this intent is derived from a built-in intent, the name of the parent intent.
Instance Attribute Details
#description ⇒ String
The description of the intent.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#input_contexts ⇒ Array<Types::InputContext>
The input contexts that must be active for this intent to be considered for recognition.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#intent_display_name ⇒ String
The display name of the intent.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The unique identifier assigned to the intent. Use this ID to get detailed information about the intent with the DescribeIntent operation.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#intent_name ⇒ String
The name of the intent.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The timestamp of the date and time that the intent was last updated.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#output_contexts ⇒ Array<Types::OutputContext>
The output contexts that are activated when this intent is fulfilled.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#parent_intent_signature ⇒ String
If this intent is derived from a built-in intent, the name of the parent intent.
8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8862 class IntentSummary < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :input_contexts, :output_contexts, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |