Class: Aws::LexModelsV2::Types::ListBotAliasReplicasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The request for the unique bot ID of the replicated bot created from the source bot alias.

Returns:

  • (String)


9275
9276
9277
9278
9279
9280
9281
9282
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9275

class ListBotAliasReplicasRequest < Struct.new(
  :bot_id,
  :replica_region,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The request for maximum results to list the replicated bots created from the source bot alias.

Returns:

  • (Integer)


9275
9276
9277
9278
9279
9280
9281
9282
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9275

class ListBotAliasReplicasRequest < Struct.new(
  :bot_id,
  :replica_region,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The request for the next token for the replicated bot created from the source bot alias.

Returns:

  • (String)


9275
9276
9277
9278
9279
9280
9281
9282
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9275

class ListBotAliasReplicasRequest < Struct.new(
  :bot_id,
  :replica_region,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#replica_region ⇒ String

The request for the secondary region of the replicated bot created from the source bot alias.

Returns:

  • (String)


9275
9276
9277
9278
9279
9280
9281
9282
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9275

class ListBotAliasReplicasRequest < Struct.new(
  :bot_id,
  :replica_region,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end