Class: Aws::LexModelsV2::Types::ListBotAliasReplicasResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_replica_summaries ⇒ Array<Types::BotAliasReplicaSummary>

The summary information of the replicated bot created from the source bot alias.

Returns:



9311
9312
9313
9314
9315
9316
9317
9318
9319
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9311

class ListBotAliasReplicasResponse < Struct.new(
  :bot_id,
  :source_region,
  :replica_region,
  :bot_alias_replica_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The unique bot ID of the replicated bot created from the source bot alias.

Returns:

  • (String)


9311
9312
9313
9314
9315
9316
9317
9318
9319
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9311

class ListBotAliasReplicasResponse < Struct.new(
  :bot_id,
  :source_region,
  :replica_region,
  :bot_alias_replica_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The next token for the replicated bots created from the source bot alias.

Returns:

  • (String)


9311
9312
9313
9314
9315
9316
9317
9318
9319
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9311

class ListBotAliasReplicasResponse < Struct.new(
  :bot_id,
  :source_region,
  :replica_region,
  :bot_alias_replica_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#replica_region ⇒ String

The secondary region of the replicated bot created from the source bot alias.

Returns:

  • (String)


9311
9312
9313
9314
9315
9316
9317
9318
9319
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9311

class ListBotAliasReplicasResponse < Struct.new(
  :bot_id,
  :source_region,
  :replica_region,
  :bot_alias_replica_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_region ⇒ String

The source region of the replicated bot created from the source bot alias.

Returns:

  • (String)


9311
9312
9313
9314
9315
9316
9317
9318
9319
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9311

class ListBotAliasReplicasResponse < Struct.new(
  :bot_id,
  :source_region,
  :replica_region,
  :bot_alias_replica_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end