Class: Aws::LexModelsV2::Types::ListBotAliasesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_summaries ⇒ Array<Types::BotAliasSummary>

Summary information for the bot aliases that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more aliases available, the nextToken field contains a token to get the next page of results.

Returns:



9369
9370
9371
9372
9373
9374
9375
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9369

class ListBotAliasesResponse < Struct.new(
  :bot_alias_summaries,
  :next_token,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The identifier of the bot associated with the aliases.

Returns:

  • (String)


9369
9370
9371
9372
9373
9374
9375
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9369

class ListBotAliasesResponse < Struct.new(
  :bot_alias_summaries,
  :next_token,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token that indicates whether there are more results to return in a response to the ListBotAliases operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBotAliases operation request to get the next page of results.

Returns:

  • (String)


9369
9370
9371
9372
9373
9374
9375
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9369

class ListBotAliasesResponse < Struct.new(
  :bot_alias_summaries,
  :next_token,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end