Class: Aws::LexModelsV2::Types::ListBotLocalesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot to list locales for.

Returns:

  • (String)


9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9482

class ListBotLocalesRequest < Struct.new(
  :bot_id,
  :bot_version,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot to list locales for.

Returns:

  • (String)


9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9482

class ListBotLocalesRequest < Struct.new(
  :bot_id,
  :bot_version,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::BotLocaleFilter>

Provides the specification for a filter used to limit the response to only those locales that match the filter specification. You can only specify one filter and one value to filter on.

Returns:



9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9482

class ListBotLocalesRequest < Struct.new(
  :bot_id,
  :bot_version,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of aliases to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9482

class ListBotLocalesRequest < Struct.new(
  :bot_id,
  :bot_version,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListBotLocales operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token as the nextToken parameter to return the next page of results.

Returns:

  • (String)


9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9482

class ListBotLocalesRequest < Struct.new(
  :bot_id,
  :bot_version,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ Types::BotLocaleSortBy

Specifies sorting parameters for the list of locales. You can sort by locale name in ascending or descending order.



9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9482

class ListBotLocalesRequest < Struct.new(
  :bot_id,
  :bot_version,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end