Class: Aws::LexModelsV2::Types::ListBotRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot that contains the bot recommendation list.

Returns:

  • (String)


9556
9557
9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9556

class ListBotRecommendationsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the bot recommendation list.

Returns:

  • (String)


9556
9557
9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9556

class ListBotRecommendationsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the bot recommendation list.

Returns:

  • (String)


9556
9557
9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9556

class ListBotRecommendationsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of bot recommendations to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


9556
9557
9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9556

class ListBotRecommendationsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListBotRecommendation operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


9556
9557
9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9556

class ListBotRecommendationsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end