Class: Aws::LexModelsV2::Types::ListBotRecommendationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot that contains the bot recommendation list.

Returns:

  • (String)


9598
9599
9600
9601
9602
9603
9604
9605
9606
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9598

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_summaries ⇒ Array<Types::BotRecommendationSummary>

Summary information for the bot recommendations that meet the filter specified in this request. The length of the list is specified in the maxResults parameter of the request. If there are more bot recommendations available, the nextToken field contains a token to get the next page of results.



9598
9599
9600
9601
9602
9603
9604
9605
9606
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9598

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the bot recommendation list.

Returns:

  • (String)


9598
9599
9600
9601
9602
9603
9604
9605
9606
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9598

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the bot recommendation list.

Returns:

  • (String)


9598
9599
9600
9601
9602
9603
9604
9605
9606
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9598

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token that indicates whether there are more results to return in a response to the ListBotRecommendations operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBotRecommendations operation request to get the next page of results.

Returns:

  • (String)


9598
9599
9600
9601
9602
9603
9604
9605
9606
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9598

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end