Class: Aws::LexModelsV2::Types::ListBotResourceGenerationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot for which the generation requests were made.

Returns:

  • (String)


9711
9712
9713
9714
9715
9716
9717
9718
9719
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotResourceGenerationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot for which the generation requests were made.

Returns:

  • (String)


9711
9712
9713
9714
9715
9716
9717
9718
9719
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotResourceGenerationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#generation_summaries ⇒ Array<Types::GenerationSummary>

A list of objects, each containing information about a generation request for the bot locale.

Returns:



9711
9712
9713
9714
9715
9716
9717
9718
9719
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotResourceGenerationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The locale of the bot for which the generation requests were made.

Returns:

  • (String)


9711
9712
9713
9714
9715
9716
9717
9718
9719
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotResourceGenerationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the total number of results is greater than the number specified in the maxResults, the response returns a token in the nextToken field. Use this token when making a request to return the next batch of results.

Returns:

  • (String)


9711
9712
9713
9714
9715
9716
9717
9718
9719
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotResourceGenerationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end