Class: Aws::LexModelsV2::Types::ListBotVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot to list versions for.

Returns:

  • (String)


9844
9845
9846
9847
9848
9849
9850
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9844

class ListBotVersionsResponse < Struct.new(
  :bot_id,
  :bot_version_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version_summaries ⇒ Array<Types::BotVersionSummary>

Summary information for the bot versions that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more versions available, the nextToken field contains a token to get the next page of results.

Returns:



9844
9845
9846
9847
9848
9849
9850
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9844

class ListBotVersionsResponse < Struct.new(
  :bot_id,
  :bot_version_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token that indicates whether there are more results to return in a response to the ListBotVersions operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBotAliases operation request to get the next page of results.

Returns:

  • (String)


9844
9845
9846
9847
9848
9849
9850
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9844

class ListBotVersionsResponse < Struct.new(
  :bot_id,
  :bot_version_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end