Class: Aws::LexModelsV2::Types::ListBuiltInIntentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#locale_id ⇒ String

The identifier of the language and locale of the intents to list. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


9947
9948
9949
9950
9951
9952
9953
9954
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9947

class ListBuiltInIntentsRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of built-in intents to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


9947
9948
9949
9950
9951
9952
9953
9954
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9947

class ListBuiltInIntentsRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListBuiltInIntents operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


9947
9948
9949
9950
9951
9952
9953
9954
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9947

class ListBuiltInIntentsRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ Types::BuiltInIntentSortBy

Specifies sorting parameters for the list of built-in intents. You can specify that the list be sorted by the built-in intent signature in either ascending or descending order.



9947
9948
9949
9950
9951
9952
9953
9954
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9947

class ListBuiltInIntentsRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end