Class: Aws::LexModelsV2::Types::ListBuiltInSlotTypesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#locale_id ⇒ String

The identifier of the language and locale of the slot types to list. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


10017
10018
10019
10020
10021
10022
10023
10024
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10017

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of built-in slot types to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


10017
10018
10019
10020
10021
10022
10023
10024
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10017

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListBuiltInSlotTypes operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


10017
10018
10019
10020
10021
10022
10023
10024
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10017

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ Types::BuiltInSlotTypeSortBy

Determines the sort order for the response from the ListBuiltInSlotTypes operation. You can choose to sort by the slot type signature in either ascending or descending order.



10017
10018
10019
10020
10021
10022
10023
10024
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10017

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end