Class: Aws::LexModelsV2::Types::ListCustomVocabularyItemsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot associated with this custom vocabulary.

Returns:

  • (String)


10122
10123
10124
10125
10126
10127
10128
10129
10130
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10122

class ListCustomVocabularyItemsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :custom_vocabulary_items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The identifier of the version of the bot associated with this custom vocabulary.

Returns:

  • (String)


10122
10123
10124
10125
10126
10127
10128
10129
10130
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10122

class ListCustomVocabularyItemsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :custom_vocabulary_items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#custom_vocabulary_items ⇒ Array<Types::CustomVocabularyItem>

The custom vocabulary items from the list custom vocabulary response.

Returns:



10122
10123
10124
10125
10126
10127
10128
10129
10130
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10122

class ListCustomVocabularyItemsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :custom_vocabulary_items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale where this custom vocabulary is used. The string must match one of the supported locales. For more information, see Supported Languages .

Returns:

  • (String)


10122
10123
10124
10125
10126
10127
10128
10129
10130
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10122

class ListCustomVocabularyItemsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :custom_vocabulary_items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The nextToken identifier to the list custom vocabulary response.

Returns:

  • (String)


10122
10123
10124
10125
10126
10127
10128
10129
10130
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10122

class ListCustomVocabularyItemsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :custom_vocabulary_items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end