Class: Aws::LexModelsV2::Types::ListIntentMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bin_by ⇒ Array<Types::AnalyticsBinBySpecification>

A list of objects, each of which contains specifications for organizing the results by time.



10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The identifier for the bot for which you want to retrieve intent metrics.

Returns:

  • (String)


10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_time ⇒ Time

The date and time that marks the end of the range of time for which you want to see intent metrics.

Returns:

  • (Time)


10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::AnalyticsIntentFilter>

A list of objects, each of which describes a condition by which you want to filter the results.

Returns:



10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#group_by ⇒ Array<Types::AnalyticsIntentGroupBySpecification>

A list of objects, each of which specifies how to group the results. You can group by the following criteria:

  • IntentName – The name of the intent.

  • IntentEndState – The final state of the intent. The possible end states are detailed in Key definitions in the user guide.



10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned.

Returns:

  • (Integer)


10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#metrics ⇒ Array<Types::AnalyticsIntentMetric>

A list of objects, each of which contains a metric you want to list, the statistic for the metric you want to return, and the order by which to organize the results.

Returns:



10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListIntentMetrics operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListIntentMetrics request to return the next page of results. For a complete set of results, call the ListIntentMetrics operation until the nextToken returned in the response is null.

Returns:

  • (String)


10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_time ⇒ Time

The timestamp that marks the beginning of the range of time for which you want to see intent metrics.

Returns:

  • (Time)


10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10386

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end