Class: Aws::LexModelsV2::Types::ListIntentMetricsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier for the bot for which you retrieved intent metrics.

Returns:

  • (String)


10421
10422
10423
10424
10425
10426
10427
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10421

class ListIntentMetricsResponse < Struct.new(
  :bot_id,
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListIntentMetrics operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListIntentMetrics request to return the next page of results. For a complete set of results, call the ListIntentMetrics operation until the nextToken returned in the response is null.

Returns:

  • (String)


10421
10422
10423
10424
10425
10426
10427
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10421

class ListIntentMetricsResponse < Struct.new(
  :bot_id,
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#results ⇒ Array<Types::AnalyticsIntentResult>

The results for the intent metrics.

Returns:



10421
10422
10423
10424
10425
10426
10427
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10421

class ListIntentMetricsResponse < Struct.new(
  :bot_id,
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end