Class: Aws::LexModelsV2::Types::ListIntentPathsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListIntentPathsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier for the bot for which you want to retrieve intent path metrics.
-
#end_date_time ⇒ Time
The date and time that marks the end of the range of time for which you want to see intent path metrics.
-
#filters ⇒ Array<Types::AnalyticsPathFilter>
A list of objects, each describes a condition by which you want to filter the results.
-
#intent_path ⇒ String
The intent path for which you want to retrieve metrics.
-
#start_date_time ⇒ Time
The date and time that marks the beginning of the range of time for which you want to see intent path metrics.
Instance Attribute Details
#bot_id ⇒ String
The identifier for the bot for which you want to retrieve intent path metrics.
10462 10463 10464 10465 10466 10467 10468 10469 10470 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10462 class ListIntentPathsRequest < Struct.new( :bot_id, :start_date_time, :end_date_time, :intent_path, :filters) SENSITIVE = [] include Aws::Structure end |
#end_date_time ⇒ Time
The date and time that marks the end of the range of time for which you want to see intent path metrics.
10462 10463 10464 10465 10466 10467 10468 10469 10470 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10462 class ListIntentPathsRequest < Struct.new( :bot_id, :start_date_time, :end_date_time, :intent_path, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::AnalyticsPathFilter>
A list of objects, each describes a condition by which you want to filter the results.
10462 10463 10464 10465 10466 10467 10468 10469 10470 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10462 class ListIntentPathsRequest < Struct.new( :bot_id, :start_date_time, :end_date_time, :intent_path, :filters) SENSITIVE = [] include Aws::Structure end |
#intent_path ⇒ String
The intent path for which you want to retrieve metrics. Use a forward slash to separate intents in the path. For example:
-
/BookCar
-
/BookCar/BookHotel
-
/BookHotel/BookCar
10462 10463 10464 10465 10466 10467 10468 10469 10470 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10462 class ListIntentPathsRequest < Struct.new( :bot_id, :start_date_time, :end_date_time, :intent_path, :filters) SENSITIVE = [] include Aws::Structure end |
#start_date_time ⇒ Time
The date and time that marks the beginning of the range of time for which you want to see intent path metrics.
10462 10463 10464 10465 10466 10467 10468 10469 10470 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10462 class ListIntentPathsRequest < Struct.new( :bot_id, :start_date_time, :end_date_time, :intent_path, :filters) SENSITIVE = [] include Aws::Structure end |