Class: Aws::LexModelsV2::Types::ListIntentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListIntentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot that contains the intent.
-
#bot_version ⇒ String
The version of the bot that contains the intent.
-
#filters ⇒ Array<Types::IntentFilter>
Provides the specification of a filter used to limit the intents in the response to only those that match the filter specification.
-
#locale_id ⇒ String
The identifier of the language and locale of the intents to list.
-
#max_results ⇒ Integer
The maximum number of intents to return in each page of results.
-
#next_token ⇒ String
If the response from the
ListIntentsoperation contains more results than specified in themaxResultsparameter, a token is returned in the response. -
#sort_by ⇒ Types::IntentSortBy
Determines the sort order for the response from the
ListIntentsoperation.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot that contains the intent.
10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10638 class ListIntentsRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the intent.
10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10638 class ListIntentsRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::IntentFilter>
Provides the specification of a filter used to limit the intents in the response to only those that match the filter specification. You can only specify one filter and only one string to filter on.
10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10638 class ListIntentsRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the intents to list. The string must match one of the supported locales. For more information, see Supported languages.
10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10638 class ListIntentsRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of intents to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.
10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10638 class ListIntentsRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response from the ListIntents operation contains more
results than specified in the maxResults parameter, a token is
returned in the response.
Use the returned token in the nextToken parameter of a
ListIntents request to return the next page of results. For a
complete set of results, call the ListIntents operation until the
nextToken returned in the response is null.
10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10638 class ListIntentsRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ Types::IntentSortBy
Determines the sort order for the response from the ListIntents
operation. You can choose to sort by the intent name or last updated
date in either ascending or descending order.
10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10638 class ListIntentsRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |