Class: Aws::LexModelsV2::Types::ListIntentsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot that contains the intent.

Returns:

  • (String)


10679
10680
10681
10682
10683
10684
10685
10686
10687
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10679

class ListIntentsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the intent.

Returns:

  • (String)


10679
10680
10681
10682
10683
10684
10685
10686
10687
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10679

class ListIntentsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#intent_summaries ⇒ Array<Types::IntentSummary>

Summary information for the intents that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more intents available, the nextToken field contains a token to get the next page of results.

Returns:



10679
10680
10681
10682
10683
10684
10685
10686
10687
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10679

class ListIntentsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The language and locale of the intents in the list.

Returns:

  • (String)


10679
10680
10681
10682
10683
10684
10685
10686
10687
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10679

class ListIntentsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token that indicates whether there are more results to return in a response to the ListIntents operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListIntents operation request to get the next page of results.

Returns:

  • (String)


10679
10680
10681
10682
10683
10684
10685
10686
10687
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10679

class ListIntentsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end