Class: Aws::LexModelsV2::Types::ListRecommendedIntentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot associated with the recommended intents.

Returns:

  • (String)


10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10723

class ListRecommendedIntentsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_id ⇒ String

The identifier of the bot recommendation that contains the recommended intents.

Returns:

  • (String)


10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10723

class ListRecommendedIntentsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the recommended intents.

Returns:

  • (String)


10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10723

class ListRecommendedIntentsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the recommended intents.

Returns:

  • (String)


10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10723

class ListRecommendedIntentsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of bot recommendations to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10723

class ListRecommendedIntentsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListRecommendedIntents operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10723

class ListRecommendedIntentsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end