Class: Aws::LexModelsV2::Types::ListSessionAnalyticsDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier for the bot for which you want to retrieve session analytics.

Returns:

  • (String)


10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10831

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_time ⇒ Time

The date and time that marks the end of the range of time for which you want to see session analytics.

Returns:

  • (Time)


10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10831

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::AnalyticsSessionFilter>

A list of objects, each of which describes a condition by which you want to filter the results.

Returns:



10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10831

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned.

Returns:

  • (Integer)


10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10831

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListSessionAnalyticsData operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListSessionAnalyticsData request to return the next page of results. For a complete set of results, call the ListSessionAnalyticsData operation until the nextToken returned in the response is null.

Returns:

  • (String)


10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10831

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ Types::SessionDataSortBy

An object specifying the measure and method by which to sort the session analytics data.



10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10831

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_time ⇒ Time

The date and time that marks the beginning of the range of time for which you want to see session analytics.

Returns:

  • (Time)


10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10831

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end