Class: Aws::LexModelsV2::Types::ListSessionMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bin_by ⇒ Array<Types::AnalyticsBinBySpecification>

A list of objects, each of which contains specifications for organizing the results by time.



10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The identifier for the bot for which you want to retrieve session metrics.

Returns:

  • (String)


10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_time ⇒ Time

The date and time that marks the end of the range of time for which you want to see session metrics.

Returns:

  • (Time)


10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::AnalyticsSessionFilter>

A list of objects, each of which describes a condition by which you want to filter the results.

Returns:



10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#group_by ⇒ Array<Types::AnalyticsSessionGroupBySpecification>

A list of objects, each of which specifies how to group the results. You can group by the following criteria:

  • ConversationEndState – The final state of the conversation. The possible end states are detailed in Key definitions in the user guide.

  • LocaleId – The unique identifier of the bot locale.



10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned.

Returns:

  • (Integer)


10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#metrics ⇒ Array<Types::AnalyticsSessionMetric>

A list of objects, each of which contains a metric you want to list, the statistic for the metric you want to return, and the method by which to organize the results.

Returns:



10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListSessionMetrics operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListSessionMetrics request to return the next page of results. For a complete set of results, call the ListSessionMetrics operation until the nextToken returned in the response is null.

Returns:

  • (String)


10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_time ⇒ Time

The date and time that marks the beginning of the range of time for which you want to see session metrics.

Returns:

  • (Time)


10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10938

class ListSessionMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end