Class: Aws::LexModelsV2::Types::ListSlotTypesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot that contains the slot types.

Returns:

  • (String)


11067
11068
11069
11070
11071
11072
11073
11074
11075
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11067

class ListSlotTypesResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :slot_type_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the slot types.

Returns:

  • (String)


11067
11068
11069
11070
11071
11072
11073
11074
11075
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11067

class ListSlotTypesResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :slot_type_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The language and local of the slot types in the list.

Returns:

  • (String)


11067
11068
11069
11070
11071
11072
11073
11074
11075
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11067

class ListSlotTypesResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :slot_type_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token that indicates whether there are more results to return in a response to the ListSlotTypes operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListSlotTypes operation request to get the next page of results.

Returns:

  • (String)


11067
11068
11069
11070
11071
11072
11073
11074
11075
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11067

class ListSlotTypesResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :slot_type_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_summaries ⇒ Array<Types::SlotTypeSummary>

Summary information for the slot types that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more slot types available, the nextToken field contains a token to get the next page of results.

Returns:



11067
11068
11069
11070
11071
11072
11073
11074
11075
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11067

class ListSlotTypesResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :slot_type_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end