Class: Aws::LexModelsV2::Types::ListSlotsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot that contains the slot.

Returns:

  • (String)


11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the slot.

Returns:

  • (String)


11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::SlotFilter>

Provides the specification of a filter used to limit the slots in the response to only those that match the filter specification. You can only specify one filter and only one string to filter on.

Returns:



11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The unique identifier of the intent that contains the slot.

Returns:

  • (String)


11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the slots to list. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of slots to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListSlots operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ Types::SlotSortBy

Determines the sort order for the response from the ListSlots operation. You can choose to sort by the slot name or last updated date in either ascending or descending order.

Returns:



11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11126

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end