Class: Aws::LexModelsV2::Types::ListSlotsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot that contains the slots.

Returns:

  • (String)


11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11172

class ListSlotsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :slot_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the slots.

Returns:

  • (String)


11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11172

class ListSlotsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :slot_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The identifier of the intent that contains the slots.

Returns:

  • (String)


11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11172

class ListSlotsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :slot_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The language and locale of the slots in the list.

Returns:

  • (String)


11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11172

class ListSlotsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :slot_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token that indicates whether there are more results to return in a response to the ListSlots operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListSlots operation request to get the next page of results.

Returns:

  • (String)


11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11172

class ListSlotsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :slot_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#slot_summaries ⇒ Array<Types::SlotSummary>

Summary information for the slots that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more slots available, the nextToken field contains a token to get the next page of results.

Returns:



11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11172

class ListSlotsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :slot_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end