Class: Aws::LexModelsV2::Types::ListTestExecutionResultItemsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListTestExecutionResultItemsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListTestExecutionResultItemsoperation. -
#test_execution_results ⇒ Types::TestExecutionResultItems
The list of results from the test execution.
Instance Attribute Details
#next_token ⇒ String
A token that indicates whether there are more results to return in a
response to the ListTestExecutionResultItems operation. If the
nextToken field is present, you send the contents as the
nextToken parameter of a ListTestExecutionResultItems operation
request to get the next page of results.
11255 11256 11257 11258 11259 11260 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11255 class ListTestExecutionResultItemsResponse < Struct.new( :test_execution_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_execution_results ⇒ Types::TestExecutionResultItems
The list of results from the test execution.
11255 11256 11257 11258 11259 11260 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11255 class ListTestExecutionResultItemsResponse < Struct.new( :test_execution_results, :next_token) SENSITIVE = [] include Aws::Structure end |