Class: Aws::LexModelsV2::Types::ListTestExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListTestExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of test executions to return in each page.
-
#next_token ⇒ String
If the response from the ListTestExecutions operation contains more results than specified in the maxResults parameter, a token is returned in the response.
-
#sort_by ⇒ Types::TestExecutionSortBy
The sort order of the test set executions.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of test executions to return in each page. If there are fewer results than the max page size, only the actual number of results are returned.
11179 11180 11181 11182 11183 11184 11185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11179 class ListTestExecutionsRequest < Struct.new( :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response from the ListTestExecutions operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.
11179 11180 11181 11182 11183 11184 11185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11179 class ListTestExecutionsRequest < Struct.new( :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ Types::TestExecutionSortBy
The sort order of the test set executions.
11179 11180 11181 11182 11183 11184 11185 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11179 class ListTestExecutionsRequest < Struct.new( :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |