Class: Aws::LexModelsV2::Types::ListTestSetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of test sets to return in each page. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


11377
11378
11379
11380
11381
11382
11383
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11377

class ListTestSetsRequest < Struct.new(
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListTestSets operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


11377
11378
11379
11380
11381
11382
11383
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11377

class ListTestSetsRequest < Struct.new(
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ Types::TestSetSortBy

The sort order for the list of test sets.



11377
11378
11379
11380
11381
11382
11383
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11377

class ListTestSetsRequest < Struct.new(
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end