Class: Aws::LexModelsV2::Types::ListUtteranceAnalyticsDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier for the bot for which you want to retrieve utterance analytics.

Returns:

  • (String)


11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11450

class ListUtteranceAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_time ⇒ Time

The date and time that marks the end of the range of time for which you want to see utterance analytics.

Returns:

  • (Time)


11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11450

class ListUtteranceAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::AnalyticsUtteranceFilter>

A list of objects, each of which describes a condition by which you want to filter the results.



11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11450

class ListUtteranceAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned.

Returns:

  • (Integer)


11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11450

class ListUtteranceAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListUtteranceAnalyticsData operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListUtteranceAnalyticsData request to return the next page of results. For a complete set of results, call the ListUtteranceAnalyticsData operation until the nextToken returned in the response is null.

Returns:

  • (String)


11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11450

class ListUtteranceAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ Types::UtteranceDataSortBy

An object specifying the measure and method by which to sort the utterance analytics data.



11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11450

class ListUtteranceAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_time ⇒ Time

The date and time that marks the beginning of the range of time for which you want to see utterance analytics.

Returns:

  • (Time)


11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11450

class ListUtteranceAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end