Class: Aws::LexModelsV2::Types::ListUtteranceMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributes ⇒ Array<Types::AnalyticsUtteranceAttribute>

A list containing attributes related to the utterance that you want the response to return. The following attributes are possible:

  • LastUsedIntent – The last used intent at the time of the utterance.

^



11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bin_by ⇒ Array<Types::AnalyticsBinBySpecification>

A list of objects, each of which contains specifications for organizing the results by time.



11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The identifier for the bot for which you want to retrieve utterance metrics.

Returns:

  • (String)


11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_time ⇒ Time

The date and time that marks the end of the range of time for which you want to see utterance metrics.

Returns:

  • (Time)


11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::AnalyticsUtteranceFilter>

A list of objects, each of which describes a condition by which you want to filter the results.



11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#group_by ⇒ Array<Types::AnalyticsUtteranceGroupBySpecification>

A list of objects, each of which specifies how to group the results. You can group by the following criteria:

  • UtteranceText – The transcription of the utterance.

  • UtteranceState – The state of the utterance. The possible states are detailed in Key definitions in the user guide.



11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned.

Returns:

  • (Integer)


11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#metrics ⇒ Array<Types::AnalyticsUtteranceMetric>

A list of objects, each of which contains a metric you want to list, the statistic for the metric you want to return, and the method by which to organize the results.



11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListUtteranceMetrics operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListUtteranceMetrics request to return the next page of results. For a complete set of results, call the ListUtteranceMetrics operation until the nextToken returned in the response is null.

Returns:

  • (String)


11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_time ⇒ Time

The date and time that marks the beginning of the range of time for which you want to see utterance metrics.

Returns:

  • (Time)


11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11567

class ListUtteranceMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :attributes,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end