Class: Aws::LexModelsV2::Types::ListUtteranceMetricsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier for the bot for which you retrieved utterance metrics.

Returns:

  • (String)


11604
11605
11606
11607
11608
11609
11610
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11604

class ListUtteranceMetricsResponse < Struct.new(
  :bot_id,
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response from the ListUtteranceMetrics operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListUtteranceMetrics request to return the next page of results. For a complete set of results, call the ListUtteranceMetrics operation until the nextToken returned in the response is null.

Returns:

  • (String)


11604
11605
11606
11607
11608
11609
11610
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11604

class ListUtteranceMetricsResponse < Struct.new(
  :bot_id,
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#results ⇒ Array<Types::AnalyticsUtteranceResult>

The results for the utterance metrics.



11604
11605
11606
11607
11608
11609
11610
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11604

class ListUtteranceMetricsResponse < Struct.new(
  :bot_id,
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end