Class: Aws::LexModelsV2::Types::Message

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The object that provides message text and its type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_payload ⇒ Types::CustomPayload

A message in a custom format defined by the client application.



11633
11634
11635
11636
11637
11638
11639
11640
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11633

class Message < Struct.new(
  :plain_text_message,
  :custom_payload,
  :ssml_message,
  :image_response_card)
  SENSITIVE = []
  include Aws::Structure
end

#image_response_card ⇒ Types::ImageResponseCard

A message that defines a response card that the client application can show to the user.



11633
11634
11635
11636
11637
11638
11639
11640
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11633

class Message < Struct.new(
  :plain_text_message,
  :custom_payload,
  :ssml_message,
  :image_response_card)
  SENSITIVE = []
  include Aws::Structure
end

#plain_text_message ⇒ Types::PlainTextMessage

A message in plain text format.



11633
11634
11635
11636
11637
11638
11639
11640
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11633

class Message < Struct.new(
  :plain_text_message,
  :custom_payload,
  :ssml_message,
  :image_response_card)
  SENSITIVE = []
  include Aws::Structure
end

#ssml_message ⇒ Types::SSMLMessage

A message in Speech Synthesis Markup Language (SSML).

Returns:



11633
11634
11635
11636
11637
11638
11639
11640
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11633

class Message < Struct.new(
  :plain_text_message,
  :custom_payload,
  :ssml_message,
  :image_response_card)
  SENSITIVE = []
  include Aws::Structure
end