Class: Aws::LexModelsV2::Types::MessageGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::MessageGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Provides one or more messages that Amazon Lex should send to the user.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ Types::Message
The primary message that Amazon Lex should send to the user.
-
#variations ⇒ Array<Types::Message>
Message variations to send to the user.
Instance Attribute Details
#message ⇒ Types::Message
The primary message that Amazon Lex should send to the user.
11632 11633 11634 11635 11636 11637 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11632 class MessageGroup < Struct.new( :message, :variations) SENSITIVE = [] include Aws::Structure end |
#variations ⇒ Array<Types::Message>
Message variations to send to the user. When variations are defined, Amazon Lex chooses the primary message or one of the variations to send to the user.
11632 11633 11634 11635 11636 11637 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11632 class MessageGroup < Struct.new( :message, :variations) SENSITIVE = [] include Aws::Structure end |