Class: Aws::LexModelsV2::Types::OpensearchConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains details about the configuration of the Amazon OpenSearch Service database used for the AMAZON.QnAIntent.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_endpointString

The endpoint of the Amazon OpenSearch Service domain.



11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11435

class OpensearchConfiguration < Struct.new(
  :domain_endpoint,
  :index_name,
  :exact_response,
  :exact_response_fields,
  :include_fields)
  SENSITIVE = []
  include Aws::Structure
end

#exact_responseBoolean

Specifies whether to return an exact response or to return an answer generated by the model using the fields you specify from the database.



11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11435

class OpensearchConfiguration < Struct.new(
  :domain_endpoint,
  :index_name,
  :exact_response,
  :exact_response_fields,
  :include_fields)
  SENSITIVE = []
  include Aws::Structure
end

#exact_response_fieldsTypes::ExactResponseFields

Contains the names of the fields used for an exact response to the user.



11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11435

class OpensearchConfiguration < Struct.new(
  :domain_endpoint,
  :index_name,
  :exact_response,
  :exact_response_fields,
  :include_fields)
  SENSITIVE = []
  include Aws::Structure
end

#include_fieldsArray<String>

Contains a list of fields from the Amazon OpenSearch Service that the model can use to generate the answer to the query.



11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11435

class OpensearchConfiguration < Struct.new(
  :domain_endpoint,
  :index_name,
  :exact_response,
  :exact_response_fields,
  :include_fields)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the Amazon OpenSearch Service index.



11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11435

class OpensearchConfiguration < Struct.new(
  :domain_endpoint,
  :index_name,
  :exact_response,
  :exact_response_fields,
  :include_fields)
  SENSITIVE = []
  include Aws::Structure
end