Class: Aws::LexModelsV2::Types::PostFulfillmentStatusSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::PostFulfillmentStatusSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Provides a setting that determines whether the post-fulfillment response is sent to the user. For more information, see
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the fulfillment code hook throws an exception or returns with the ‘State` field of the `Intent` object set to `Failed`.
-
#failure_next_step ⇒ Types::DialogState
Specifies the next step the bot runs after the fulfillment code hook throws an exception or returns with the ‘State` field of the `Intent` object set to `Failed`.
-
#failure_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
-
#success_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the fulfillment code hook finishes successfully.
-
#success_next_step ⇒ Types::DialogState
Specifies the next step in the conversation that Amazon Lex invokes when the fulfillment code hook completes successfully.
-
#success_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
-
#timeout_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate if the fulfillment code hook times out.
-
#timeout_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the fulfillment code hook times out.
-
#timeout_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
Instance Attribute Details
#failure_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the fulfillment code hook throws an exception or returns with the ‘State` field of the `Intent` object set to `Failed`.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#failure_next_step ⇒ Types::DialogState
Specifies the next step the bot runs after the fulfillment code hook throws an exception or returns with the ‘State` field of the `Intent` object set to `Failed`.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#failure_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#success_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the fulfillment code hook finishes successfully.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#success_next_step ⇒ Types::DialogState
Specifies the next step in the conversation that Amazon Lex invokes when the fulfillment code hook completes successfully.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#success_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#timeout_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate if the fulfillment code hook times out.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#timeout_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the fulfillment code hook times out.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#timeout_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12025 class PostFulfillmentStatusSpecification < Struct.new( :success_response, :failure_response, :timeout_response, :success_next_step, :success_conditional, :failure_next_step, :failure_conditional, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |