Class: Aws::LexModelsV2::Types::Principal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The IAM principal that you allowing or denying access to an Amazon Lex action. You must provide a service or an arn, but not both in the same statement. For more information, see AWS JSON policy elements: Principal .

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the principal.



12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12097

class Principal < Struct.new(
  :service,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#service ⇒ String

The name of the Amazon Web Services service that should allowed or denied access to an Amazon Lex action.



12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12097

class Principal < Struct.new(
  :service,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end