Class: Aws::LexModelsV2::Types::PromptAttemptSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Specifies the settings on a prompt attempt.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_interrupt ⇒ Boolean

Indicates whether the user can interrupt a speech prompt attempt from the bot.

Returns:

  • (Boolean)


12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12125

class PromptAttemptSpecification < Struct.new(
  :allow_interrupt,
  :allowed_input_types,
  :audio_and_dtmf_input_specification,
  :text_input_specification)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_input_types ⇒ Types::AllowedInputTypes

Indicates the allowed input types of the prompt attempt.



12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12125

class PromptAttemptSpecification < Struct.new(
  :allow_interrupt,
  :allowed_input_types,
  :audio_and_dtmf_input_specification,
  :text_input_specification)
  SENSITIVE = []
  include Aws::Structure
end

#audio_and_dtmf_input_specification ⇒ Types::AudioAndDTMFInputSpecification

Specifies the settings on audio and DTMF input.



12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12125

class PromptAttemptSpecification < Struct.new(
  :allow_interrupt,
  :allowed_input_types,
  :audio_and_dtmf_input_specification,
  :text_input_specification)
  SENSITIVE = []
  include Aws::Structure
end

#text_input_specification ⇒ Types::TextInputSpecification

Specifies the settings on text input.



12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12125

class PromptAttemptSpecification < Struct.new(
  :allow_interrupt,
  :allowed_input_types,
  :audio_and_dtmf_input_specification,
  :text_input_specification)
  SENSITIVE = []
  include Aws::Structure
end