Class: Aws::LexModelsV2::Types::PromptSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Specifies a list of message groups that Amazon Lex sends to a user to elicit a response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_interrupt ⇒ Boolean

Indicates whether the user can interrupt a speech prompt from the bot.

Returns:

  • (Boolean)


12163
12164
12165
12166
12167
12168
12169
12170
12171
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12163

class PromptSpecification < Struct.new(
  :message_groups,
  :max_retries,
  :allow_interrupt,
  :message_selection_strategy,
  :prompt_attempts_specification)
  SENSITIVE = []
  include Aws::Structure
end

#max_retries ⇒ Integer

The maximum number of times the bot tries to elicit a response from the user using this prompt.

Returns:

  • (Integer)


12163
12164
12165
12166
12167
12168
12169
12170
12171
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12163

class PromptSpecification < Struct.new(
  :message_groups,
  :max_retries,
  :allow_interrupt,
  :message_selection_strategy,
  :prompt_attempts_specification)
  SENSITIVE = []
  include Aws::Structure
end

#message_groups ⇒ Array<Types::MessageGroup>

A collection of messages that Amazon Lex can send to the user. Amazon Lex chooses the actual message to send at runtime.

Returns:



12163
12164
12165
12166
12167
12168
12169
12170
12171
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12163

class PromptSpecification < Struct.new(
  :message_groups,
  :max_retries,
  :allow_interrupt,
  :message_selection_strategy,
  :prompt_attempts_specification)
  SENSITIVE = []
  include Aws::Structure
end

#message_selection_strategy ⇒ String

Indicates how a message is selected from a message group among retries.

Returns:

  • (String)


12163
12164
12165
12166
12167
12168
12169
12170
12171
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12163

class PromptSpecification < Struct.new(
  :message_groups,
  :max_retries,
  :allow_interrupt,
  :message_selection_strategy,
  :prompt_attempts_specification)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_attempts_specification ⇒ Hash<String,Types::PromptAttemptSpecification>

Specifies the advanced settings on each attempt of the prompt.

Returns:



12163
12164
12165
12166
12167
12168
12169
12170
12171
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12163

class PromptSpecification < Struct.new(
  :message_groups,
  :max_retries,
  :allow_interrupt,
  :message_selection_strategy,
  :prompt_attempts_specification)
  SENSITIVE = []
  include Aws::Structure
end