Class: Aws::LexModelsV2::Types::QInConnectAssistantConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::QInConnectAssistantConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
The configuration details of the Qinconnect assistant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assistant_arn ⇒ String
The assistant Arn details of the Qinconnect assistant configuration.
Instance Attribute Details
#assistant_arn ⇒ String
The assistant Arn details of the Qinconnect assistant configuration.
12079 12080 12081 12082 12083 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12079 class QInConnectAssistantConfiguration < Struct.new( :assistant_arn) SENSITIVE = [] include Aws::Structure end |