Class: Aws::LexModelsV2::Types::QnAKendraConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains details about the configuration of the Amazon Kendra index used for the AMAZON.QnAIntent.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#exact_response ⇒ Boolean

Specifies whether to return an exact response from the Amazon Kendra index or to let the Amazon Bedrock model you select generate a response based on the results. To use this feature, you must first add FAQ questions to your index by following the steps at Adding frequently asked questions (FAQs) to an index.

Returns:

  • (Boolean)


12259
12260
12261
12262
12263
12264
12265
12266
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12259

class QnAKendraConfiguration < Struct.new(
  :kendra_index,
  :query_filter_string_enabled,
  :query_filter_string,
  :exact_response)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_index ⇒ String

The ARN of the Amazon Kendra index to use.

Returns:

  • (String)


12259
12260
12261
12262
12263
12264
12265
12266
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12259

class QnAKendraConfiguration < Struct.new(
  :kendra_index,
  :query_filter_string_enabled,
  :query_filter_string,
  :exact_response)
  SENSITIVE = []
  include Aws::Structure
end

#query_filter_string ⇒ String

Contains the Amazon Kendra filter string to use if enabled. For more information on the Amazon Kendra search filter JSON format, see Using document attributes to filter search results.

Returns:

  • (String)


12259
12260
12261
12262
12263
12264
12265
12266
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12259

class QnAKendraConfiguration < Struct.new(
  :kendra_index,
  :query_filter_string_enabled,
  :query_filter_string,
  :exact_response)
  SENSITIVE = []
  include Aws::Structure
end

#query_filter_string_enabled ⇒ Boolean

Specifies whether to enable an Amazon Kendra filter string or not.

Returns:

  • (Boolean)


12259
12260
12261
12262
12263
12264
12265
12266
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12259

class QnAKendraConfiguration < Struct.new(
  :kendra_index,
  :query_filter_string_enabled,
  :query_filter_string,
  :exact_response)
  SENSITIVE = []
  include Aws::Structure
end