Class: Aws::LexModelsV2::Types::ResponseSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Specifies a list of message groups that Amazon Lex uses to respond the user input.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_interrupt ⇒ Boolean

Indicates whether the user can interrupt a speech response from Amazon Lex.

Returns:

  • (Boolean)


12368
12369
12370
12371
12372
12373
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12368

class ResponseSpecification < Struct.new(
  :message_groups,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end

#message_groups ⇒ Array<Types::MessageGroup>

A collection of responses that Amazon Lex can send to the user. Amazon Lex chooses the actual response to send at runtime.

Returns:



12368
12369
12370
12371
12372
12373
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12368

class ResponseSpecification < Struct.new(
  :message_groups,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end