Class: Aws::LexModelsV2::Types::RuntimeHintDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Provides an array of phrases that should be given preference when resolving values for a slot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#runtime_hint_values ⇒ Array<Types::RuntimeHintValue>

One or more strings that Amazon Lex should look for in the input to the bot. Each phrase is given preference when deciding on slot values.

Returns:



12395
12396
12397
12398
12399
12400
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12395

class RuntimeHintDetails < Struct.new(
  :runtime_hint_values,
  :sub_slot_hints)
  SENSITIVE = []
  include Aws::Structure
end

#sub_slot_hints ⇒ Hash<String,Types::RuntimeHintDetails>

A map of constituent sub slot names inside a composite slot in the intent and the phrases that should be added for each sub slot. Inside each composite slot hints, this structure provides a mechanism to add granular sub slot phrases. Only sub slot hints are supported for composite slots. The intent name, composite slot name and the constituent sub slot names must exist.

Returns:



12395
12396
12397
12398
12399
12400
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12395

class RuntimeHintDetails < Struct.new(
  :runtime_hint_values,
  :sub_slot_hints)
  SENSITIVE = []
  include Aws::Structure
end