Class: Aws::LexModelsV2::Types::RuntimeHintValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Provides the phrase that Amazon Lex should look for in the user’s input to the bot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#phraseString

The phrase that Amazon Lex should look for in the user’s input to the bot.

Returns:

  • (String)


12310
12311
12312
12313
12314
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12310

class RuntimeHintValue < Struct.new(
  :phrase)
  SENSITIVE = []
  include Aws::Structure
end