Class: Aws::LexModelsV2::Types::RuntimeHints
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::RuntimeHints
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
You can provide Amazon Lex with hints to the phrases that a customer is likely to use for a slot. When a slot with hints is resolved, the phrases in the runtime hints are preferred in the resolution. You can provide hints for a maximum of 100 intents. You can provide a maximum of 100 slots.
Before you can use runtime hints with an existing bot, you must first rebuild the bot.
For more information, see [Using runtime hints to improve recognition of slot values].
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#slot_hints ⇒ Hash<String,Hash<String,Types::RuntimeHintDetails>>
A list of the slots in the intent that should have runtime hints added, and the phrases that should be added for each slot.
Instance Attribute Details
#slot_hints ⇒ Hash<String,Hash<String,Types::RuntimeHintDetails>>
A list of the slots in the intent that should have runtime hints added, and the phrases that should be added for each slot.
The first level of the slotHints map is the name of the intent. The second level is the name of the slot within the intent. For more information, see [Using hints to improve accuracy].
The intent name and slot name must exist.
12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12349 class RuntimeHints < Struct.new( :slot_hints) SENSITIVE = [] include Aws::Structure end |