Class: Aws::LexModelsV2::Types::S3BucketLogDestination
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::S3BucketLogDestination
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Specifies an Amazon S3 bucket for logging audio conversations
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Web Services Key Management Service (KMS) key for encrypting audio log files stored in an S3 bucket.
-
#log_prefix ⇒ String
The S3 prefix to assign to audio log files.
-
#s3_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon S3 bucket where audio log files are stored.
Instance Attribute Details
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Web Services Key Management Service (KMS) key for encrypting audio log files stored in an S3 bucket.
12397 12398 12399 12400 12401 12402 12403 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12397 class S3BucketLogDestination < Struct.new( :kms_key_arn, :s3_bucket_arn, :log_prefix) SENSITIVE = [] include Aws::Structure end |
#log_prefix ⇒ String
The S3 prefix to assign to audio log files.
12397 12398 12399 12400 12401 12402 12403 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12397 class S3BucketLogDestination < Struct.new( :kms_key_arn, :s3_bucket_arn, :log_prefix) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon S3 bucket where audio log files are stored.
12397 12398 12399 12400 12401 12402 12403 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12397 class S3BucketLogDestination < Struct.new( :kms_key_arn, :s3_bucket_arn, :log_prefix) SENSITIVE = [] include Aws::Structure end |