Class: Aws::LexModelsV2::Types::S3BucketTranscriptSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_arnString

The ARN of the KMS key that customer use to encrypt their Amazon S3 bucket. Only use this field if your bucket is encrypted using a customer managed KMS key.

Returns:

  • (String)


12518
12519
12520
12521
12522
12523
12524
12525
12526
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12518

class S3BucketTranscriptSource < Struct.new(
  :s3_bucket_name,
  :path_format,
  :transcript_format,
  :transcript_filter,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#path_formatTypes::PathFormat

The object that contains a path format that will be applied when Amazon Lex reads the transcript file in the bucket you provide. Specify this object if you only want Lex to read a subset of files in your Amazon S3 bucket.

Returns:



12518
12519
12520
12521
12522
12523
12524
12525
12526
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12518

class S3BucketTranscriptSource < Struct.new(
  :s3_bucket_name,
  :path_format,
  :transcript_format,
  :transcript_filter,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_nameString

The name of the bucket containing the transcript and the associated metadata.

Returns:

  • (String)


12518
12519
12520
12521
12522
12523
12524
12525
12526
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12518

class S3BucketTranscriptSource < Struct.new(
  :s3_bucket_name,
  :path_format,
  :transcript_format,
  :transcript_filter,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_filterTypes::TranscriptFilter

The object that contains the filter which will be applied when Amazon Lex reads through the Amazon S3 bucket. Specify this object if you want Amazon Lex to read only a subset of the Amazon S3 bucket based on the filter you provide.



12518
12519
12520
12521
12522
12523
12524
12525
12526
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12518

class S3BucketTranscriptSource < Struct.new(
  :s3_bucket_name,
  :path_format,
  :transcript_format,
  :transcript_filter,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_formatString

The format of the transcript content. Currently, Genie only supports the Amazon Lex transcript format.

Returns:

  • (String)


12518
12519
12520
12521
12522
12523
12524
12525
12526
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12518

class S3BucketTranscriptSource < Struct.new(
  :s3_bucket_name,
  :path_format,
  :transcript_format,
  :transcript_filter,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end