Class: Aws::LexModelsV2::Types::SampleUtteranceGenerationSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains specifications for the sample utterance generation feature.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bedrock_model_specification ⇒ Types::BedrockModelSpecification

Contains information about the Amazon Bedrock model used to interpret the prompt used in descriptive bot building.



12595
12596
12597
12598
12599
12600
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12595

class SampleUtteranceGenerationSpecification < Struct.new(
  :enabled,
  :bedrock_model_specification)
  SENSITIVE = []
  include Aws::Structure
end

#enabled ⇒ Boolean

Specifies whether to enable sample utterance generation or not.

Returns:

  • (Boolean)


12595
12596
12597
12598
12599
12600
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12595

class SampleUtteranceGenerationSpecification < Struct.new(
  :enabled,
  :bedrock_model_specification)
  SENSITIVE = []
  include Aws::Structure
end