Class: Aws::LexModelsV2::Types::SearchAssociatedTranscriptsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot associated with the transcripts that you are searching.

Returns:

  • (String)


12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_id ⇒ String

The unique identifier of the bot recommendation associated with the transcripts to search.

Returns:

  • (String)


12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot containing the transcripts that you are searching.

Returns:

  • (String)


12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::AssociatedTranscriptFilter>

A list of filter objects.



12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the transcripts to search. The string must match one of the supported locales. For more information, see Supported languages

Returns:

  • (String)


12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of bot recommendations to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end

#next_index ⇒ Integer

If the response from the SearchAssociatedTranscriptsRequest operation contains more results than specified in the maxResults parameter, an index is returned in the response. Use that index in the nextIndex parameter to return the next page of results.

Returns:

  • (Integer)


12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end

#search_order ⇒ String

How SearchResults are ordered. Valid values are Ascending or Descending. The default is Descending.

Returns:

  • (String)


12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12665

class SearchAssociatedTranscriptsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :search_order,
  :filters,
  :max_results,
  :next_index)
  SENSITIVE = []
  include Aws::Structure
end