Class: Aws::LexModelsV2::Types::SessionSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

An object containing information about a specific session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_id ⇒ String

The identifier of the alias of the bot that the session was held with.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that the session was held with.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#channel ⇒ String

The channel that is integrated with the bot that the session was held with.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_duration_seconds ⇒ Integer

The duration of the conversation in seconds. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.

Returns:

  • (Integer)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_end_state ⇒ String

The final state of the conversation. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_end_time ⇒ Time

The date and time when the conversation ended. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.

Returns:

  • (Time)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_start_time ⇒ Time

The date and time when the conversation began. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.

Returns:

  • (Time)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#invoked_intent_samples ⇒ Array<Types::InvokedIntentSample>

A list of objects containing the name of an intent that was invoked.

Returns:



12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The locale of the bot that the session was held with.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#mode ⇒ String

The mode of the session. The possible values are as follows:

  • Speech – The session was spoken.

  • Text – The session was written.

  • DTMF – The session used a touch-tone keypad (Dual Tone Multi-Frequency).

  • MultiMode – The session used multiple modes.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_turns ⇒ Integer

The number of turns that the session took.

Returns:

  • (Integer)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#originating_request_id ⇒ String

The identifier of the first request in a session.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_id ⇒ String

The identifier of the session.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12867

class SessionSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :channel,
  :session_id,
  :conversation_start_time,
  :conversation_end_time,
  :conversation_duration_seconds,
  :conversation_end_state,
  :mode,
  :number_of_turns,
  :invoked_intent_samples,
  :originating_request_id)
  SENSITIVE = []
  include Aws::Structure
end