Class: Aws::LexModelsV2::Types::SlotResolutionSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::SlotResolutionSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Contains information about whether assisted slot resolution is turned on for the slot or not.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#slot_resolution_strategy ⇒ String
Specifies whether assisted slot resolution is turned on for the slot or not.
Instance Attribute Details
#slot_resolution_strategy ⇒ String
Specifies whether assisted slot resolution is turned on for the slot or not. If the value is EnhancedFallback, assisted slot resolution is activated when Amazon Lex defaults to the AMAZON.FallbackIntent. If the value is Default, assisted slot resolution is turned off.
12952 12953 12954 12955 12956 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12952 class SlotResolutionSetting < Struct.new( :slot_resolution_strategy) SENSITIVE = [] include Aws::Structure end |