Class: Aws::LexModelsV2::Types::SlotTypeSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Provides summary information about a slot type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

The description of the slot type.

Returns:

  • (String)


13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13282

class SlotTypeSummary < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :parent_slot_type_signature,
  :last_updated_date_time,
  :slot_type_category)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

A timestamp of the date and time that the slot type was last updated.

Returns:

  • (Time)


13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13282

class SlotTypeSummary < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :parent_slot_type_signature,
  :last_updated_date_time,
  :slot_type_category)
  SENSITIVE = []
  include Aws::Structure
end

#parent_slot_type_signature ⇒ String

If the slot type is derived from a built-on slot type, the name of the parent slot type.

Returns:

  • (String)


13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13282

class SlotTypeSummary < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :parent_slot_type_signature,
  :last_updated_date_time,
  :slot_type_category)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_category ⇒ String

Indicates the type of the slot type.

Returns:

  • (String)


13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13282

class SlotTypeSummary < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :parent_slot_type_signature,
  :last_updated_date_time,
  :slot_type_category)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_id ⇒ String

The unique identifier assigned to the slot type.

Returns:

  • (String)


13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13282

class SlotTypeSummary < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :parent_slot_type_signature,
  :last_updated_date_time,
  :slot_type_category)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_name ⇒ String

The name of the slot type.

Returns:

  • (String)


13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13282

class SlotTypeSummary < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :parent_slot_type_signature,
  :last_updated_date_time,
  :slot_type_category)
  SENSITIVE = []
  include Aws::Structure
end