Class: Aws::LexModelsV2::Types::SlotValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::SlotValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
The value to set in a slot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interpreted_value ⇒ String
The value that Amazon Lex determines for the slot.
Instance Attribute Details
#interpreted_value ⇒ String
The value that Amazon Lex determines for the slot. The actual value depends on the setting of the value selection strategy for the bot. You can choose to use the value entered by the user, or you can have Amazon Lex choose the first value in the resolvedValues list.
13222 13223 13224 13225 13226 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13222 class SlotValue < Struct.new( :interpreted_value) SENSITIVE = [] include Aws::Structure end |