Method: Aws::LexModelsV2::Types::SlotValueElicitationSetting#slot_resolution_setting

Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

#slot_resolution_settingTypes::SlotResolutionSetting

An object containing information about whether assisted slot resolution is turned on for the slot or not.



13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13015

class SlotValueElicitationSetting < Struct.new(
  :default_value_specification,
  :slot_constraint,
  :prompt_specification,
  :sample_utterances,
  :wait_and_continue_specification,
  :slot_capture_setting,
  :slot_resolution_setting)
  SENSITIVE = []
  include Aws::Structure
end