Class: Aws::LexModelsV2::Types::SlotValueOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The slot values that Amazon Lex uses when it sets slot values in a dialog step.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#shape ⇒ String

When the shape value is List, it indicates that the values field contains a list of slot values. When the value is Scalar, it indicates that the value field contains a single value.



13405
13406
13407
13408
13409
13410
13411
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13405

class SlotValueOverride < Struct.new(
  :shape,
  :value,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ Types::SlotValue

The current value of the slot.



13405
13406
13407
13408
13409
13410
13411
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13405

class SlotValueOverride < Struct.new(
  :shape,
  :value,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#values ⇒ Array<Types::SlotValueOverride>

A list of one or more values that the user provided for the slot. For example, for a slot that elicits pizza toppings, the values might be "pepperoni" and "pineapple."



13405
13406
13407
13408
13409
13410
13411
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13405

class SlotValueOverride < Struct.new(
  :shape,
  :value,
  :values)
  SENSITIVE = []
  include Aws::Structure
end