Class: Aws::LexModelsV2::Types::SpeechFoundationModel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Configuration for a foundation model used for speech synthesis and recognition capabilities.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#model_arnString

The Amazon Resource Name (ARN) of the foundation model used for speech processing.

Returns:

  • (String)


13161
13162
13163
13164
13165
13166
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13161

class SpeechFoundationModel < Struct.new(
  :model_arn,
  :voice_id)
  SENSITIVE = []
  include Aws::Structure
end

#voice_idString

The identifier of the voice to use for speech synthesis with the foundation model.

Returns:

  • (String)


13161
13162
13163
13164
13165
13166
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13161

class SpeechFoundationModel < Struct.new(
  :model_arn,
  :voice_id)
  SENSITIVE = []
  include Aws::Structure
end