Class: Aws::LexModelsV2::Types::StartBotAnalyzerResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_analyzer_request_id ⇒ String

A unique identifier for this analysis request. Use this identifier to check the status and retrieve results.



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13643

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_analyzer_status ⇒ String

The current status of the analysis. The initial status is Processing.

Valid Values: Processing | Available | Failed | Stopping | Stopped



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13643

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The unique identifier of the bot being analyzed.



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13643

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot being analyzed.



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13643

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The date and time when the analysis was initiated.



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13643

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The locale identifier of the bot locale being analyzed.



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13643

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end