Class: Aws::LexModelsV2::Types::StartBotRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot containing the bot recommendation.

Returns:

  • (String)


13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13685

class StartBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot containing the bot recommendation.

Returns:

  • (String)


13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13685

class StartBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_setting ⇒ Types::EncryptionSetting

The object representing the passwords that will be used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.



13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13685

class StartBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the bot recommendation to start. The string must match one of the supported locales. For more information, see Supported languages

Returns:

  • (String)


13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13685

class StartBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_source_setting ⇒ Types::TranscriptSourceSetting

The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.



13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13685

class StartBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end