Class: Aws::LexModelsV2::Types::StartBotResourceGenerationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot for which the generation request was made.

Returns:

  • (String)


13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13818

class StartBotResourceGenerationResponse < Struct.new(
  :generation_input_prompt,
  :generation_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot for which the generation request was made.

Returns:

  • (String)


13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13818

class StartBotResourceGenerationResponse < Struct.new(
  :generation_input_prompt,
  :generation_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The date and time at which the generation request was made.

Returns:

  • (Time)


13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13818

class StartBotResourceGenerationResponse < Struct.new(
  :generation_input_prompt,
  :generation_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#generation_id ⇒ String

The unique identifier of the generation request.

Returns:

  • (String)


13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13818

class StartBotResourceGenerationResponse < Struct.new(
  :generation_input_prompt,
  :generation_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#generation_input_prompt ⇒ String

The prompt that was used generate intents and slot types for the bot locale.

Returns:

  • (String)


13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13818

class StartBotResourceGenerationResponse < Struct.new(
  :generation_input_prompt,
  :generation_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#generation_status ⇒ String

The status of the generation request.

Returns:

  • (String)


13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13818

class StartBotResourceGenerationResponse < Struct.new(
  :generation_input_prompt,
  :generation_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The locale of the bot for which the generation request was made.

Returns:

  • (String)


13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13818

class StartBotResourceGenerationResponse < Struct.new(
  :generation_input_prompt,
  :generation_id,
  :bot_id,
  :bot_version,
  :locale_id,
  :generation_status,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end