Class: Aws::LexModelsV2::Types::StartTestExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_mode ⇒ String

Indicates whether we use streaming or non-streaming APIs for the test set execution. For streaming, StartConversation Amazon Lex Runtime API is used. Whereas for non-streaming, RecognizeUtterance and RecognizeText Amazon Lex Runtime API are used.

Returns:

  • (String)


13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13962

class StartTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :test_set_id,
  :target,
  :api_mode,
  :test_execution_modality)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The creation date and time for the test set execution.

Returns:

  • (Time)


13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13962

class StartTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :test_set_id,
  :target,
  :api_mode,
  :test_execution_modality)
  SENSITIVE = []
  include Aws::Structure
end

#target ⇒ Types::TestExecutionTarget

The target bot for the test set execution.



13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13962

class StartTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :test_set_id,
  :target,
  :api_mode,
  :test_execution_modality)
  SENSITIVE = []
  include Aws::Structure
end

#test_execution_id ⇒ String

The unique identifier of the test set execution.

Returns:

  • (String)


13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13962

class StartTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :test_set_id,
  :target,
  :api_mode,
  :test_execution_modality)
  SENSITIVE = []
  include Aws::Structure
end

#test_execution_modality ⇒ String

Indicates whether audio or text is used.

Returns:

  • (String)


13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13962

class StartTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :test_set_id,
  :target,
  :api_mode,
  :test_execution_modality)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_id ⇒ String

The test set Id for the test set execution.

Returns:

  • (String)


13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13962

class StartTestExecutionResponse < Struct.new(
  :test_execution_id,
  :creation_date_time,
  :test_set_id,
  :target,
  :api_mode,
  :test_execution_modality)
  SENSITIVE = []
  include Aws::Structure
end