Class: Aws::LexModelsV2::Types::StartTestSetGenerationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The creation date and time for the test set generation.

Returns:

  • (Time)


14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description used for the test set generation.

Returns:

  • (String)


14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#generation_data_source ⇒ Types::TestSetGenerationDataSource

The data source for the test set generation.



14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.

Returns:

  • (String)


14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#storage_location ⇒ Types::TestSetStorageLocation

The Amazon S3 storage location for the test set generation.



14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_generation_id ⇒ String

The unique identifier of the test set generation to describe.

Returns:

  • (String)


14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_generation_status ⇒ String

The status for the test set generation.

Returns:

  • (String)


14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_name ⇒ String

The test set name used for the test set generation.

Returns:

  • (String)


14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end

#test_set_tags ⇒ Hash<String,String>

A list of tags that was used for the test set that is being generated.

Returns:

  • (Hash<String,String>)


14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14054

class StartTestSetGenerationResponse < Struct.new(
  :test_set_generation_id,
  :creation_date_time,
  :test_set_generation_status,
  :test_set_name,
  :description,
  :storage_location,
  :generation_data_source,
  :role_arn,
  :test_set_tags)
  SENSITIVE = []
  include Aws::Structure
end