Class: Aws::LexModelsV2::Types::StillWaitingResponseSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Defines the messages that Amazon Lex sends to a user to remind them that the bot is waiting for a response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_interrupt ⇒ Boolean

Indicates that the user can interrupt the response by speaking while the message is being played.

Returns:

  • (Boolean)


14093
14094
14095
14096
14097
14098
14099
14100
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14093

class StillWaitingResponseSpecification < Struct.new(
  :message_groups,
  :frequency_in_seconds,
  :timeout_in_seconds,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end

#frequency_in_seconds ⇒ Integer

How often a message should be sent to the user. Minimum of 1 second, maximum of 5 minutes.

Returns:

  • (Integer)


14093
14094
14095
14096
14097
14098
14099
14100
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14093

class StillWaitingResponseSpecification < Struct.new(
  :message_groups,
  :frequency_in_seconds,
  :timeout_in_seconds,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end

#message_groups ⇒ Array<Types::MessageGroup>

One or more message groups, each containing one or more messages, that define the prompts that Amazon Lex sends to the user.

Returns:



14093
14094
14095
14096
14097
14098
14099
14100
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14093

class StillWaitingResponseSpecification < Struct.new(
  :message_groups,
  :frequency_in_seconds,
  :timeout_in_seconds,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_in_seconds ⇒ Integer

If Amazon Lex waits longer than this length of time for a response, it will stop sending messages.

Returns:

  • (Integer)


14093
14094
14095
14096
14097
14098
14099
14100
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14093

class StillWaitingResponseSpecification < Struct.new(
  :message_groups,
  :frequency_in_seconds,
  :timeout_in_seconds,
  :allow_interrupt)
  SENSITIVE = []
  include Aws::Structure
end