Class: Aws::LexModelsV2::Types::StopBotAnalyzerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::StopBotAnalyzerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_analyzer_request_id ⇒ String
The unique identifier of the analysis request to stop.
-
#bot_id ⇒ String
The unique identifier of the bot.
Instance Attribute Details
#bot_analyzer_request_id ⇒ String
The unique identifier of the analysis request to stop.
14068 14069 14070 14071 14072 14073 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14068 class StopBotAnalyzerRequest < Struct.new( :bot_id, :bot_analyzer_request_id) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot.
14068 14069 14070 14071 14072 14073 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14068 class StopBotAnalyzerRequest < Struct.new( :bot_id, :bot_analyzer_request_id) SENSITIVE = [] include Aws::Structure end |