Class: Aws::LexModelsV2::Types::StopBotRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot containing the bot recommendation to be stopped.

Returns:

  • (String)


14179
14180
14181
14182
14183
14184
14185
14186
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14179

class StopBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_id ⇒ String

The unique identifier of the bot recommendation to be stopped.

Returns:

  • (String)


14179
14180
14181
14182
14183
14184
14185
14186
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14179

class StopBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot containing the bot recommendation.

Returns:

  • (String)


14179
14180
14181
14182
14183
14184
14185
14186
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14179

class StopBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale of the bot recommendation to stop. The string must match one of the supported locales. For more information, see Supported languages

Returns:

  • (String)


14179
14180
14181
14182
14183
14184
14185
14186
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14179

class StopBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id)
  SENSITIVE = []
  include Aws::Structure
end