Class: Aws::LexModelsV2::Types::SubSlotValueElicitationSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::SubSlotValueElicitationSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Subslot elicitation settings.
DefaultValueSpecification is a list of default values for a constituent sub slot in a composite slot. Default values are used when Amazon Lex hasn’t determined a value for a slot. You can specify default values from context variables, session attributes, and defined values. This is similar to DefaultValueSpecification for slots.
PromptSpecification is the prompt that Amazon Lex uses to elicit the sub slot value from the user. This is similar to PromptSpecification for slots.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_value_specification ⇒ Types::SlotDefaultValueSpecification
Defines a list of values that Amazon Lex should use as the default value for a slot.
-
#prompt_specification ⇒ Types::PromptSpecification
Specifies a list of message groups that Amazon Lex sends to a user to elicit a response.
-
#sample_utterances ⇒ Array<Types::SampleUtterance>
If you know a specific pattern that users might respond to an Amazon Lex request for a sub slot value, you can provide those utterances to improve accuracy.
-
#wait_and_continue_specification ⇒ Types::WaitAndContinueSpecification
Specifies the prompts that Amazon Lex uses while a bot is waiting for customer input.
Instance Attribute Details
#default_value_specification ⇒ Types::SlotDefaultValueSpecification
Defines a list of values that Amazon Lex should use as the default value for a slot.
13806 13807 13808 13809 13810 13811 13812 13813 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13806 class SubSlotValueElicitationSetting < Struct.new( :default_value_specification, :prompt_specification, :sample_utterances, :wait_and_continue_specification) SENSITIVE = [] include Aws::Structure end |
#prompt_specification ⇒ Types::PromptSpecification
Specifies a list of message groups that Amazon Lex sends to a user to elicit a response.
13806 13807 13808 13809 13810 13811 13812 13813 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13806 class SubSlotValueElicitationSetting < Struct.new( :default_value_specification, :prompt_specification, :sample_utterances, :wait_and_continue_specification) SENSITIVE = [] include Aws::Structure end |
#sample_utterances ⇒ Array<Types::SampleUtterance>
If you know a specific pattern that users might respond to an Amazon Lex request for a sub slot value, you can provide those utterances to improve accuracy. This is optional. In most cases Amazon Lex is capable of understanding user utterances. This is similar to SampleUtterances for slots.
13806 13807 13808 13809 13810 13811 13812 13813 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13806 class SubSlotValueElicitationSetting < Struct.new( :default_value_specification, :prompt_specification, :sample_utterances, :wait_and_continue_specification) SENSITIVE = [] include Aws::Structure end |
#wait_and_continue_specification ⇒ Types::WaitAndContinueSpecification
Specifies the prompts that Amazon Lex uses while a bot is waiting for customer input.
13806 13807 13808 13809 13810 13811 13812 13813 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13806 class SubSlotValueElicitationSetting < Struct.new( :default_value_specification, :prompt_specification, :sample_utterances, :wait_and_continue_specification) SENSITIVE = [] include Aws::Structure end |