Class: Aws::LexModelsV2::Types::TestExecutionResultItems
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::TestExecutionResultItems
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Contains the results of the test execution, grouped by type of results. See [Test result details“>Test results details] for details about different types of results.
[1]: docs.aws.amazon.com/lexv2/latest/dg/test-results-details-test-set.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conversation_level_test_results ⇒ Types::ConversationLevelTestResults
Results related to conversations in the test set, including metrics about success and failure of conversations and intent and slot failures.
-
#intent_classification_test_results ⇒ Types::IntentClassificationTestResults
Intent recognition results aggregated by intent name.
-
#intent_level_slot_resolution_test_results ⇒ Types::IntentLevelSlotResolutionTestResults
Slot resolution results aggregated by intent and slot name.
-
#overall_test_results ⇒ Types::OverallTestResults
Overall results for the test execution, including the breakdown of conversations and single-input utterances.
-
#utterance_level_test_results ⇒ Types::UtteranceLevelTestResults
Results related to utterances in the test set.
Instance Attribute Details
#conversation_level_test_results ⇒ Types::ConversationLevelTestResults
Results related to conversations in the test set, including metrics about success and failure of conversations and intent and slot failures.
14360 14361 14362 14363 14364 14365 14366 14367 14368 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14360 class TestExecutionResultItems < Struct.new( :overall_test_results, :conversation_level_test_results, :intent_classification_test_results, :intent_level_slot_resolution_test_results, :utterance_level_test_results) SENSITIVE = [] include Aws::Structure end |
#intent_classification_test_results ⇒ Types::IntentClassificationTestResults
Intent recognition results aggregated by intent name. The aggregated results contain success and failure rates of intent recognition, speech transcriptions, and end-to-end conversations.
14360 14361 14362 14363 14364 14365 14366 14367 14368 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14360 class TestExecutionResultItems < Struct.new( :overall_test_results, :conversation_level_test_results, :intent_classification_test_results, :intent_level_slot_resolution_test_results, :utterance_level_test_results) SENSITIVE = [] include Aws::Structure end |
#intent_level_slot_resolution_test_results ⇒ Types::IntentLevelSlotResolutionTestResults
Slot resolution results aggregated by intent and slot name. The aggregated results contain success and failure rates of slot resolution, speech transcriptions, and end-to-end conversations
14360 14361 14362 14363 14364 14365 14366 14367 14368 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14360 class TestExecutionResultItems < Struct.new( :overall_test_results, :conversation_level_test_results, :intent_classification_test_results, :intent_level_slot_resolution_test_results, :utterance_level_test_results) SENSITIVE = [] include Aws::Structure end |
#overall_test_results ⇒ Types::OverallTestResults
Overall results for the test execution, including the breakdown of conversations and single-input utterances.
14360 14361 14362 14363 14364 14365 14366 14367 14368 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14360 class TestExecutionResultItems < Struct.new( :overall_test_results, :conversation_level_test_results, :intent_classification_test_results, :intent_level_slot_resolution_test_results, :utterance_level_test_results) SENSITIVE = [] include Aws::Structure end |
#utterance_level_test_results ⇒ Types::UtteranceLevelTestResults
Results related to utterances in the test set.
14360 14361 14362 14363 14364 14365 14366 14367 14368 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14360 class TestExecutionResultItems < Struct.new( :overall_test_results, :conversation_level_test_results, :intent_classification_test_results, :intent_level_slot_resolution_test_results, :utterance_level_test_results) SENSITIVE = [] include Aws::Structure end |