Class: Aws::LexModelsV2::Types::TestSetIntentDiscrepancyItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains information about discrepancy in an intent information between the test set and the bot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_messageString

The error message for a discrepancy for an intent between the test set and the bot.

Returns:

  • (String)


14640
14641
14642
14643
14644
14645
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14640

class TestSetIntentDiscrepancyItem < Struct.new(
  :intent_name,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#intent_nameString

The name of the intent in the discrepancy report.

Returns:

  • (String)


14640
14641
14642
14643
14644
14645
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14640

class TestSetIntentDiscrepancyItem < Struct.new(
  :intent_name,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end