Class: Aws::LexModelsV2::Types::TestSetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::TestSetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Contains summary information about the test set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The date and time at which the test set was created.
-
#description ⇒ String
The description of the test set.
-
#last_updated_date_time ⇒ Time
The date and time at which the test set was last updated.
-
#modality ⇒ String
Specifies whether the test set contains written or spoken data.
-
#num_turns ⇒ Integer
The number of turns in the test set.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permission to access the test set.
-
#status ⇒ String
The status of the test set.
-
#storage_location ⇒ Types::TestSetStorageLocation
Contains information about the location at which the test set is stored.
-
#test_set_id ⇒ String
The unique identifier of the test set.
-
#test_set_name ⇒ String
The name of the test set.
Instance Attribute Details
#creation_date_time ⇒ Time
The date and time at which the test set was created.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the test set.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The date and time at which the test set was last updated.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#modality ⇒ String
Specifies whether the test set contains written or spoken data.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#num_turns ⇒ Integer
The number of turns in the test set.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permission to access the test set.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the test set.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#storage_location ⇒ Types::TestSetStorageLocation
Contains information about the location at which the test set is stored.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_id ⇒ String
The unique identifier of the test set.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_name ⇒ String
The name of the test set.
14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14810 class TestSetSummary < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |