Class: Aws::LexModelsV2::Types::UpdateBotAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_id ⇒ String

The unique identifier of the bot alias.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_locale_settings ⇒ Hash<String,Types::BotAliasLocaleSettings>

The new Lambda functions to use in each locale for the bot alias.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_name ⇒ String

The new name to assign to the bot alias.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The identifier of the bot with the updated alias.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The new bot version to assign to the bot alias.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_log_settings ⇒ Types::ConversationLogSettings

The new settings for storing conversation logs in Amazon CloudWatch Logs and Amazon S3 buckets.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The new description to assign to the bot alias.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end

#sentiment_analysis_settings ⇒ Types::SentimentAnalysisSettings

Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.

Returns:



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15075

class UpdateBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_id)
  SENSITIVE = []
  include Aws::Structure
end