Class: Aws::LexModelsV2::Types::UpdateBotLocaleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_filler_settings ⇒ Types::AudioFillerSettings

Updated audio filler settings to apply to the bot locale. When enabled, requires unifiedSpeechSettings (speech-to-speech) to be configured on the bot locale.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_id ⇒ String

The unique identifier of the bot that contains the locale.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the locale to be updated. The version can only be the DRAFT version.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The new description of the locale.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#generative_ai_settings ⇒ Types::GenerativeAISettings

Contains settings for generative AI features powered by Amazon Bedrock for your bot locale. Use this object to turn generative AI features on and off. Pricing may differ if you turn a feature on. For more information, see LINK.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale to update. The string must match one of the supported locales. For more information, see Supported languages.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nlu_intent_confidence_threshold ⇒ Float

The new confidence threshold where Amazon Lex inserts the AMAZON.FallbackIntent and AMAZON.KendraSearchIntent intents in the list of possible intents for an utterance.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#speaker_diarization_settings ⇒ Types::SpeakerDiarizationSettings

The updated speaker diarization settings to apply to the bot locale. If you omit this field, Amazon Lex keeps the setting currently stored on the bot locale. To turn speaker diarization off, set enabled to false explicitly.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#speech_detection_sensitivity ⇒ String

The new sensitivity level for voice activity detection (VAD) in the bot locale. This setting helps optimize speech recognition accuracy by adjusting how the system responds to background noise during voice interactions.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings

Updated speech-to-text settings to apply to the bot locale.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#unified_speech_settings ⇒ Types::UnifiedSpeechSettings

Updated unified speech settings to apply to the bot locale.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end

#voice_settings ⇒ Types::VoiceSettings

The new Amazon Polly voice Amazon Lex should use for voice interaction with the user.

Returns:



15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15225

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity,
  :speaker_diarization_settings)
  SENSITIVE = []
  include Aws::Structure
end