Class: Aws::LexModelsV2::Types::UpdateBotLocaleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot that contains the updated locale.

Returns:

  • (String)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#bot_locale_statusString

The current status of the locale. When the bot status is Built the locale is ready for use.

Returns:

  • (String)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that contains the updated locale.

Returns:

  • (String)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

A timestamp of the date and time that the locale was created.

Returns:

  • (Time)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The updated description of the locale.

Returns:

  • (String)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonsArray<String>

If the botLocaleStatus is Failed, the failureReasons field lists the errors that occurred while building the bot.

Returns:

  • (Array<String>)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#generative_ai_settingsTypes::GenerativeAISettings

Contains settings for generative AI features powered by Amazon Bedrock for your bot locale.



15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

A timestamp of the date and time that the locale was last updated.

Returns:

  • (Time)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The language and locale of the updated bot locale.

Returns:

  • (String)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#locale_nameString

The updated locale name for the locale.

Returns:

  • (String)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#nlu_intent_confidence_thresholdFloat

The updated confidence threshold for inserting the AMAZON.FallbackIntent and AMAZON.KendraSearchIntent intents in the list of possible intents for an utterance.

Returns:

  • (Float)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

Recommended actions to take to resolve an error in the failureReasons field.

Returns:

  • (Array<String>)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#speech_detection_sensitivityString

The updated sensitivity level for voice activity detection (VAD) in the bot locale.

Returns:

  • (String)


15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#speech_recognition_settingsTypes::SpeechRecognitionSettings

The updated speech-to-text settings for the bot locale.



15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#unified_speech_settingsTypes::UnifiedSpeechSettings

The updated unified speech settings for the bot locale.



15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#voice_settingsTypes::VoiceSettings

The updated Amazon Polly voice to use for voice interaction with the user.



15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15179

class UpdateBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end