Class: Aws::LexModelsV2::Types::UpdateBotRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The unique identifier of the bot containing the bot recommendation to be updated.

Returns:

  • (String)


15322
15323
15324
15325
15326
15327
15328
15329
15330
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15322

class UpdateBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_idString

The unique identifier of the bot recommendation to be updated.

Returns:

  • (String)


15322
15323
15324
15325
15326
15327
15328
15329
15330
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15322

class UpdateBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot containing the bot recommendation to be updated.

Returns:

  • (String)


15322
15323
15324
15325
15326
15327
15328
15329
15330
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15322

class UpdateBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_settingTypes::EncryptionSetting

The object representing the passwords that will be used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.



15322
15323
15324
15325
15326
15327
15328
15329
15330
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15322

class UpdateBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale of the bot recommendation to update. The string must match one of the supported locales. For more information, see [Supported languages]

[1]: docs.aws.amazon.com/lexv2/latest/dg/how-languages.html

Returns:

  • (String)


15322
15323
15324
15325
15326
15327
15328
15329
15330
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15322

class UpdateBotRecommendationRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_id,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end