Class: Aws::LexModelsV2::Types::UpdateBotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The unique identifier of the bot to update. This identifier is returned by the [CreateBot] operation.

[1]: docs.aws.amazon.com/lexv2/latest/APIReference/API_CreateBot.html

Returns:

  • (String)


15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_membersArray<Types::BotMember>

The list of bot members in the network associated with the update action.

Returns:



15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_nameString

The new name of the bot. The name must be unique in the account that creates the bot.

Returns:

  • (String)


15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#bot_typeString

The type of the bot to be updated.

Returns:

  • (String)


15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#data_privacyTypes::DataPrivacy

Provides information on additional privacy protections Amazon Lex should use with the bot’s data.

Returns:



15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the bot.

Returns:

  • (String)


15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#error_log_settingsTypes::ErrorLogSettings

Allows you to modify how Amazon Lex logs errors during bot interactions, including destinations for error logs and the types of errors to be captured.



15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idle_session_ttl_in_secondsInteger

The time, in seconds, that Amazon Lex should keep information about a user’s conversation with the bot.

A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout.

You can specify between 60 (1 minute) and 86,400 (24 hours) seconds.

Returns:

  • (Integer)


15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that has permissions to access the bot.

Returns:

  • (String)


15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15456

class UpdateBotRequest < Struct.new(
  :bot_id,
  :bot_name,
  :description,
  :role_arn,
  :data_privacy,
  :idle_session_ttl_in_seconds,
  :bot_type,
  :bot_members,
  :error_log_settings)
  SENSITIVE = []
  include Aws::Structure
end