Class: Aws::LexModelsV2::Types::UpdateIntentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The identifier of the bot that contains the intent.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the intent. Will always be DRAFT.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

A timestamp of when the intent was created.

Returns:

  • (Time)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The updated description of the intent.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dialog_code_hook ⇒ Types::DialogCodeHookSettings

The updated Lambda function called during each turn of the conversation with the user.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings

The updated Lambda function called when the intent is ready for fulfillment.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#initial_response_setting ⇒ Types::InitialResponseSetting

Configuration settings for a response sent to the user before Amazon Lex starts eliciting slots.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#input_contexts ⇒ Array<Types::InputContext>

The updated list of contexts that must be active for the intent to be considered by Amazon Lex.

Returns:



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_closing_setting ⇒ Types::IntentClosingSetting

The updated response that Amazon Lex sends the user when the intent is closed.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting

The updated prompts that Amazon Lex sends to the user to confirm the completion of an intent.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_display_name ⇒ String

The updated display name of the intent.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The identifier of the intent that was updated.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_name ⇒ String

The updated name of the intent.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_configuration ⇒ Types::KendraConfiguration

The updated configuration for connecting to an Amazon Kendra index with the AMAZON.KendraSearchIntent intent.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

A timestamp of the last time that the intent was modified.

Returns:

  • (Time)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The updated language and locale of the intent.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#output_contexts ⇒ Array<Types::OutputContext>

The updated list of contexts that Amazon Lex activates when the intent is fulfilled.

Returns:



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#parent_intent_signature ⇒ String

The updated built-in intent that is the parent of this intent.

Returns:

  • (String)


15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration

Qinconnect intent configuration details for the update intent response.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration

Details about the configuration of the built-in Amazon.QnAIntent.



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sample_utterances ⇒ Array<Types::SampleUtterance>

The updated list of sample utterances for the intent.

Returns:



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#slot_priorities ⇒ Array<Types::SlotPriority>

The updated list of slots and their priorities that are elicited from the user for the intent.

Returns:



15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15884

class UpdateIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end