Class: Aws::LexModelsV2::Types::UpdateSlotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_id ⇒ String

The unique identifier of the bot that contains the slot.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that contains the slot. Must always be DRAFT.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The new description for the slot.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#intent_id ⇒ String

The identifier of the intent that contains the slot.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The identifier of the language and locale that contains the slot. The string must match one of the supported locales. For more information, see Supported languages.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#multiple_values_setting ⇒ Types::MultipleValuesSetting

Determines whether the slot accepts multiple values in one response. Multiple value slots are only available in the en-US locale. If you set this value to true in any other locale, Amazon Lex throws a ValidationException.

If the multipleValuesSetting is not set, the default value is false.



16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#obfuscation_setting ⇒ Types::ObfuscationSetting

New settings that determine how slot values are formatted in Amazon CloudWatch logs.



16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_id ⇒ String

The unique identifier for the slot to update.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_name ⇒ String

The new name for the slot.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_id ⇒ String

The unique identifier of the new slot type to associate with this slot.

Returns:

  • (String)


16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#sub_slot_setting ⇒ Types::SubSlotSetting

Specifications for the constituent sub slots and the expression for the composite slot.



16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting

A new set of prompts that Amazon Lex sends to the user to elicit a response the provides a value for the slot.



16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
16048
16049
16050
16051
16052
16053
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16038

class UpdateSlotRequest < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end