Class: Aws::LexModelsV2::Types::UpdateSlotResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot that contains the slot.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that contains the slot. Will always be ‘DRAFT`.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The timestamp of the date and time that the slot was created.

Returns:

  • (Time)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The updated description of the bot.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#intent_idString

The intent that contains the slot.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

The timestamp of the date and time that the slot was last updated.

Returns:

  • (Time)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The locale that contains the slot.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#multiple_values_settingTypes::MultipleValuesSetting

Indicates whether the slot accepts multiple values in one response.



16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#obfuscation_settingTypes::ObfuscationSetting

The updated setting that determines whether the slot value is obfuscated in the Amazon CloudWatch logs.



16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_idString

The unique identifier of the slot that was updated.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_nameString

The updated name of the slot.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_idString

The updated identifier of the slot type that provides values for the slot.

Returns:

  • (String)


16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#sub_slot_settingTypes::SubSlotSetting

Specifications for the constituent sub slots and the expression for the composite slot.



16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#value_elicitation_settingTypes::SlotValueElicitationSetting

The updated prompts that Amazon Lex sends to the user to elicit a response that provides a value for the slot.



16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061

class UpdateSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end