Class: Aws::LexModelsV2::Types::UserTurnInputSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains information about the user messages in the turn in the input.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#request_attributes ⇒ Hash<String,String>

Request attributes of the user turn.

Returns:

  • (Hash<String,String>)


16382
16383
16384
16385
16386
16387
16388
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16382

class UserTurnInputSpecification < Struct.new(
  :utterance_input,
  :request_attributes,
  :session_state)
  SENSITIVE = []
  include Aws::Structure
end

#session_state ⇒ Types::InputSessionStateSpecification

Contains information about the session state in the input.



16382
16383
16384
16385
16386
16387
16388
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16382

class UserTurnInputSpecification < Struct.new(
  :utterance_input,
  :request_attributes,
  :session_state)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_input ⇒ Types::UtteranceInputSpecification

The utterance input in the user turn.



16382
16383
16384
16385
16386
16387
16388
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16382

class UserTurnInputSpecification < Struct.new(
  :utterance_input,
  :request_attributes,
  :session_state)
  SENSITIVE = []
  include Aws::Structure
end