Class: Aws::LexModelsV2::Types::UserTurnOutputSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains results that are output for the user turn by the test execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_contexts ⇒ Array<Types::ActiveContext>

The contexts that are active in the turn.

Returns:



16428
16429
16430
16431
16432
16433
16434
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16428

class UserTurnOutputSpecification < Struct.new(
  :intent,
  :active_contexts,
  :transcript)
  SENSITIVE = []
  include Aws::Structure
end

#intent ⇒ Types::UserTurnIntentOutput

Contains information about the intent.



16428
16429
16430
16431
16432
16433
16434
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16428

class UserTurnOutputSpecification < Struct.new(
  :intent,
  :active_contexts,
  :transcript)
  SENSITIVE = []
  include Aws::Structure
end

#transcript ⇒ String

The transcript that is output for the user turn by the test execution.

Returns:

  • (String)


16428
16429
16430
16431
16432
16433
16434
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16428

class UserTurnOutputSpecification < Struct.new(
  :intent,
  :active_contexts,
  :transcript)
  SENSITIVE = []
  include Aws::Structure
end