Class: Aws::LexModelsV2::Types::UserTurnResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains the results for the user turn by the test execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actual_output ⇒ Types::UserTurnOutputSpecification

Contains information about the actual output for the user turn.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_level_result ⇒ Types::ConversationLevelResultDetail

Contains information about the results related to the conversation associated with the user turn.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#end_to_end_result ⇒ String

Specifies whether the expected and actual outputs match or not, or if there is an error in execution.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#error_details ⇒ Types::ExecutionErrorDetails

Details about an error in an execution of a test set.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#expected_output ⇒ Types::UserTurnOutputSpecification

Contains information about the expected output for the user turn.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#input ⇒ Types::UserTurnInputSpecification

Contains information about the user messages in the turn in the input.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#intent_match_result ⇒ String

Specifies whether the expected and actual intents match or not.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#slot_match_result ⇒ String

Specifies whether the expected and actual slots match or not.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end

#speech_transcription_result ⇒ String

Specifies whether the expected and actual speech transcriptions match or not, or if there is an error in execution.



16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16480

class UserTurnResult < Struct.new(
  :input,
  :expected_output,
  :actual_output,
  :error_details,
  :end_to_end_result,
  :intent_match_result,
  :slot_match_result,
  :speech_transcription_result,
  :conversation_level_result)
  SENSITIVE = []
  include Aws::Structure
end