Class: Aws::LexModelsV2::Types::UtteranceSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

An object containing information about a specific utterance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_intent_name ⇒ String

The name of the intent that the utterance is associated to.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#associated_slot_name ⇒ String

The name of the slot that the utterance is associated to.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#audio_voice_duration_millis ⇒ Integer

The duration in milliseconds of the audio associated with the utterance.

Returns:

  • (Integer)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_id ⇒ String

The identifier of the alias of the bot that the utterance was made to.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_response_audio_voice_id ⇒ String

The identifier for the audio of the bot response.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_responses ⇒ Array<Types::UtteranceBotResponse>

A list of objects containing information about the bot response to the utterance.

Returns:



16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_version ⇒ String

The version of the bot that the utterance was made to.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#channel ⇒ String

The channel that is integrated with the bot that the utterance was made to.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_end_time ⇒ Time

The date and time when the conversation in which the utterance took place ended. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.

Returns:

  • (Time)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_start_time ⇒ Time

The date and time when the conversation in which the utterance took place began. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.

Returns:

  • (Time)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#dialog_action_type ⇒ String

The type of dialog action that the utterance is associated to. See the type field in DialogAction for more information.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#input_type ⇒ String

The input type of the utterance. The possible values are as follows:

  • PCM format: audio data must be in little-endian byte order.

  • audio/l16; rate=16000; channels=1

  • audio/x-l16; sample-rate=16000; channel-count=1

  • audio/lpcm; sample-rate=8000; sample-size-bits=16; channel-count=1; is-big-endian=false

  • Opus format

  • audio/x-cbr-opus-with-preamble;preamble-size=0;bit-rate=256000;frame-size-milliseconds=4

^

  • Text format

  • text/plain; charset=utf-8

^

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#intent_state ⇒ String

The state of the intent that the utterance is associated to.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#locale_id ⇒ String

The locale of the bot that the utterance was made to.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#mode ⇒ String

The mode of the session. The possible values are as follows:

  • Speech – The session consisted of spoken dialogue.

  • Text – The session consisted of written dialogue.

  • DTMF – The session consisted of touch-tone keypad (Dual Tone Multi-Frequency) key presses.

  • MultiMode – The session consisted of multiple modes.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#output_type ⇒ String

The output type of the utterance. The possible values are as follows:

  • audio/mpeg

  • audio/ogg

  • audio/pcm (16 KHz)

  • audio/ (defaults to mpeg)

  • text/plain; charset=utf-8

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#session_id ⇒ String

The identifier of the session that the utterance was made in.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#slots_filled_in_session ⇒ String

The slots that have been filled in the session by the time of the utterance.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utterance ⇒ String

The text of the utterance.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_request_id ⇒ String

The identifier of the request associated with the utterance.

Returns:

  • (String)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_timestamp ⇒ Time

The date and time when the utterance took place.

Returns:

  • (Time)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_understood ⇒ Boolean

Specifies whether the bot understood the utterance or not.

Returns:

  • (Boolean)


16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16844

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end