Class: Aws::LexModelsV2::Waiters::BotAliasAvailable

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs

Overview

Wait until a bot alias is available

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ BotAliasAvailable

Returns a new instance of BotAliasAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 35
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


92
93
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 92

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



130
131
132
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 130

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeBotAliasResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :bot_alias_id (required, String)

    The identifier of the bot alias to describe.

  • :bot_id (required, String)

    The identifier of the bot associated with the bot alias to describe.

Returns:



125
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 125

def wait: (