Class: Aws::LexModelsV2::Waiters::BotAvailable
- Inherits:
-
Object
- Object
- Aws::LexModelsV2::Waiters::BotAvailable
- Defined in:
- lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs
Overview
Wait until a bot is available
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ BotAvailable
constructor
A new instance of BotAvailable.
-
#wait(params = {}) ⇒ Types::DescribeBotResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ BotAvailable
Returns a new instance of BotAvailable.
143 144 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 143
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
187 188 189 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 187 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeBotResponse
Returns a response object which responds to the following methods:
- #bot_id => String
- #bot_name => String
- #description => String
- #role_arn => String
- #data_privacy => Types::DataPrivacy
- #idle_session_ttl_in_seconds => Integer
- #bot_status => String
- #creation_date_time => Time
- #last_updated_date_time => Time
- #bot_type => String
- #bot_members => Array<Types::BotMember>
- #failure_reasons => Array<String>
- #error_log_settings => Types::ErrorLogSettings
182 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 182
def wait: (
|