Class: Aws::LexModelsV2::Waiters::BotExportCompleted
- Inherits:
-
Object
- Object
- Aws::LexModelsV2::Waiters::BotExportCompleted
- Defined in:
- lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs
Overview
Wait until a bot has been exported
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ BotExportCompleted
constructor
A new instance of BotExportCompleted.
-
#wait(params = {}) ⇒ Types::DescribeExportResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ BotExportCompleted
Returns a new instance of BotExportCompleted.
200 201 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 200
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
238 239 240 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 238 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeExportResponse
Returns a response object which responds to the following methods:
- #export_id => String
- #resource_specification => Types::ExportResourceSpecification
- #file_format => String
- #export_status => String
- #failure_reasons => Array<String>
- #download_url => String
- #creation_date_time => Time
- #last_updated_date_time => Time
233 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 233
def wait: (
|