Class: Aws::LexModelsV2::Waiters::BotLocaleBuilt

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs

Overview

Wait until a bot locale is built

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ BotLocaleBuilt

Returns a new instance of BotLocaleBuilt.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 35
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


302
303
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 302

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



346
347
348
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 346

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeBotLocaleResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :bot_id (required, String)

    The identifier of the bot associated with the locale.

  • :bot_version (required, String)

    The version of the bot associated with the locale.

  • :locale_id (required, String)

    The unique identifier of the locale to describe. The string must match one of the supported locales. For more information, see Supported languages.

Returns:



341
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 341

def wait: (