Class: Aws::LexModelsV2::Waiters::BotLocaleCreated
- Inherits:
-
Object
- Object
- Aws::LexModelsV2::Waiters::BotLocaleCreated
- Defined in:
- lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs
Overview
Wait unit a bot locale is created
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ BotLocaleCreated
constructor
A new instance of BotLocaleCreated.
-
#wait(params = {}) ⇒ Types::DescribeBotLocaleResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ BotLocaleCreated
Returns a new instance of BotLocaleCreated.
359 360 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 359
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
409 410 411 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 409 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeBotLocaleResponse
Returns a response object which responds to the following methods:
- #bot_id => String
- #bot_version => String
- #locale_id => String
- #locale_name => String
- #description => String
- #nlu_intent_confidence_threshold => Float
- #voice_settings => Types::VoiceSettings
- #unified_speech_settings => Types::UnifiedSpeechSettings
- #audio_filler_settings => Types::AudioFillerSettings
- #speech_recognition_settings => Types::SpeechRecognitionSettings
- #intents_count => Integer
- #slot_types_count => Integer
- #bot_locale_status => String
- #failure_reasons => Array<String>
- #creation_date_time => Time
- #last_updated_date_time => Time
- #last_build_submitted_date_time => Time
- #bot_locale_history_events => Array<Types::BotLocaleHistoryEvent>
- #recommended_actions => Array<String>
- #generative_ai_settings => Types::GenerativeAISettings
- #speech_detection_sensitivity => String
404 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 404
def wait: (
|