Class: Aws::LexModelsV2::Waiters::BotVersionAvailable

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs

Overview

Wait until a bot version is available

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ BotVersionAvailable

Returns a new instance of BotVersionAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 35
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


485
486
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 485

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



528
529
530
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 528

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeBotVersionResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :bot_id (required, String)

    The identifier of the bot containing the version to return metadata for.

  • :bot_version (required, String)

    The version of the bot to return metadata for.

Returns:



523
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 523

def wait: (