Class: Aws::LexModelsV2::Types::AudioFillerSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::AudioFillerSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Configuration that plays background filler audio during speech-to-speech interactions to mask processing delays and improve the perceived responsiveness of the bot.
Audio filler requires ‘unifiedSpeechSettings` (speech-to-speech) to be enabled on the bot locale when `enabled` is `true`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_type ⇒ String
The identifier of the audio filler to play while Amazon Lex processes the user’s input.
-
#enabled ⇒ Boolean
Specifies whether audio filler playback is enabled for the bot locale.
-
#minimum_play_duration_in_milliseconds ⇒ Integer
The minimum time, in milliseconds, that audio filler plays once it has started, even if the bot response becomes ready sooner.
-
#response_delivery_delay_in_milliseconds ⇒ Integer
The silent delay, in milliseconds, inserted between the end of audio filler playback and the start of the bot’s response.
-
#start_delay_in_milliseconds ⇒ Integer
The time, in milliseconds, to wait after the end of the user’s utterance before starting audio filler playback.
Instance Attribute Details
#audio_type ⇒ String
The identifier of the audio filler to play while Amazon Lex processes the user’s input. This field is required when ‘enabled` is `true`.
1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1583 class AudioFillerSettings < Struct.new( :enabled, :audio_type, :start_delay_in_milliseconds, :minimum_play_duration_in_milliseconds, :response_delivery_delay_in_milliseconds) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Specifies whether audio filler playback is enabled for the bot locale. Set to ‘true` to play filler audio while Amazon Lex processes a user utterance. Set to `false` to disable filler audio.
1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1583 class AudioFillerSettings < Struct.new( :enabled, :audio_type, :start_delay_in_milliseconds, :minimum_play_duration_in_milliseconds, :response_delivery_delay_in_milliseconds) SENSITIVE = [] include Aws::Structure end |
#minimum_play_duration_in_milliseconds ⇒ Integer
The minimum time, in milliseconds, that audio filler plays once it has started, even if the bot response becomes ready sooner. Valid range is ‘1000` to `5000` milliseconds. If not specified, Amazon Lex uses a default of `3000` milliseconds.
1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1583 class AudioFillerSettings < Struct.new( :enabled, :audio_type, :start_delay_in_milliseconds, :minimum_play_duration_in_milliseconds, :response_delivery_delay_in_milliseconds) SENSITIVE = [] include Aws::Structure end |
#response_delivery_delay_in_milliseconds ⇒ Integer
The silent delay, in milliseconds, inserted between the end of audio filler playback and the start of the bot’s response. Valid range is ‘200` to `1000` milliseconds. If not specified, Amazon Lex uses a default of `500` milliseconds.
1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1583 class AudioFillerSettings < Struct.new( :enabled, :audio_type, :start_delay_in_milliseconds, :minimum_play_duration_in_milliseconds, :response_delivery_delay_in_milliseconds) SENSITIVE = [] include Aws::Structure end |
#start_delay_in_milliseconds ⇒ Integer
The time, in milliseconds, to wait after the end of the user’s utterance before starting audio filler playback. Valid range is ‘500` to `5000` milliseconds. If not specified, Amazon Lex uses a default of `2500` milliseconds.
1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1583 class AudioFillerSettings < Struct.new( :enabled, :audio_type, :start_delay_in_milliseconds, :minimum_play_duration_in_milliseconds, :response_delivery_delay_in_milliseconds) SENSITIVE = [] include Aws::Structure end |