Class: Aws::LexModelsV2::Types::BatchUpdateCustomVocabularyItemResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BatchUpdateCustomVocabularyItemResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot associated with this custom vocabulary.
-
#bot_version ⇒ String
The identifier of the version of the bot associated with this custom vocabulary.
-
#errors ⇒ Array<Types::FailedCustomVocabularyItem>
A list of custom vocabulary items that failed to update during the operation.
-
#locale_id ⇒ String
The identifier of the language and locale where this custom vocabulary is used.
-
#resources ⇒ Array<Types::CustomVocabularyItem>
A list of custom vocabulary items that were successfully updated during the operation.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot associated with this custom vocabulary.
1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1881 class BatchUpdateCustomVocabularyItemResponse < Struct.new( :bot_id, :bot_version, :locale_id, :errors, :resources) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The identifier of the version of the bot associated with this custom vocabulary.
1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1881 class BatchUpdateCustomVocabularyItemResponse < Struct.new( :bot_id, :bot_version, :locale_id, :errors, :resources) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::FailedCustomVocabularyItem>
A list of custom vocabulary items that failed to update during the operation. The reason for the error is contained within each error object.
1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1881 class BatchUpdateCustomVocabularyItemResponse < Struct.new( :bot_id, :bot_version, :locale_id, :errors, :resources) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale where this custom vocabulary is used. The string must match one of the supported locales. For more information, see [ Supported Languages ][1].
1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1881 class BatchUpdateCustomVocabularyItemResponse < Struct.new( :bot_id, :bot_version, :locale_id, :errors, :resources) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::CustomVocabularyItem>
A list of custom vocabulary items that were successfully updated during the operation.
1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 1881 class BatchUpdateCustomVocabularyItemResponse < Struct.new( :bot_id, :bot_version, :locale_id, :errors, :resources) SENSITIVE = [] include Aws::Structure end |