Class: Aws::LexModelsV2::Types::BotLocaleImportSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BotLocaleImportSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Provides the bot locale parameters required for importing a bot locale.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot to import the locale to.
-
#bot_version ⇒ String
The version of the bot to import the locale to.
-
#locale_id ⇒ String
The identifier of the language and locale that the bot will be used in.
-
#nlu_intent_confidence_threshold ⇒ Float
Determines the threshold where Amazon Lex will insert the
AMAZON.FallbackIntent,AMAZON.KendraSearchIntent, or both when returning alternative intents. -
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) in the bot locale.
-
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
Speech-to-text settings to apply when importing the bot locale configuration.
-
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
Unified speech settings to apply when importing the bot locale configuration.
-
#voice_settings ⇒ Types::VoiceSettings
Defines settings for using an Amazon Polly voice to communicate with a user.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot to import the locale to.
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot to import the locale to. This can only be the DRAFT version of the bot.
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale that the bot will be used in. The string must match one of the supported locales. All of the intents, slot types, and slots used in the bot must have the same locale. For more information, see [Supported languages].
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |
#nlu_intent_confidence_threshold ⇒ Float
Determines the threshold where Amazon Lex will insert the AMAZON.FallbackIntent, AMAZON.KendraSearchIntent, or both when returning alternative intents. AMAZON.FallbackIntent and AMAZON.KendraSearchIntent are only inserted if they are configured for the bot.
For example, suppose a bot is configured with the confidence threshold of 0.80 and the AMAZON.FallbackIntent. Amazon Lex returns three alternative intents with the following confidence scores: IntentA (0.70), IntentB (0.60), IntentC (0.50). The response from the PostText operation would be:
-
AMAZON.FallbackIntent -
IntentA -
IntentB -
IntentC
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) in the bot locale. This setting helps optimize speech recognition accuracy by adjusting how the system responds to background noise during voice interactions.
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
Speech-to-text settings to apply when importing the bot locale configuration.
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
Unified speech settings to apply when importing the bot locale configuration.
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |
#voice_settings ⇒ Types::VoiceSettings
Defines settings for using an Amazon Polly voice to communicate with a user.
Valid values include:
-
standard -
neural -
long-form -
generative
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2419 class BotLocaleImportSpecification < Struct.new( :bot_id, :bot_version, :locale_id, :nlu_intent_confidence_threshold, :voice_settings, :speech_recognition_settings, :speech_detection_sensitivity, :unified_speech_settings) SENSITIVE = [] include Aws::Structure end |