Class: Aws::LexModelsV2::Types::BotRecommendationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::BotRecommendationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
A summary of the bot recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_recommendation_id ⇒ String
The unique identifier of the bot recommendation to be updated.
-
#bot_recommendation_status ⇒ String
The status of the bot recommendation.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was created.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was last updated.
Instance Attribute Details
#bot_recommendation_id ⇒ String
The unique identifier of the bot recommendation to be updated.
2663 2664 2665 2666 2667 2668 2669 2670 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2663 class BotRecommendationSummary < Struct.new( :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#bot_recommendation_status ⇒ String
The status of the bot recommendation.
If the status is Failed, then the reasons for the failure are listed in the failureReasons field.
2663 2664 2665 2666 2667 2668 2669 2670 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2663 class BotRecommendationSummary < Struct.new( :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was created.
2663 2664 2665 2666 2667 2668 2669 2670 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2663 class BotRecommendationSummary < Struct.new( :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was last updated.
2663 2664 2665 2666 2667 2668 2669 2670 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 2663 class BotRecommendationSummary < Struct.new( :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |