Class: Aws::LexModelsV2::Types::CreateBotAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::CreateBotAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_alias_locale_settings ⇒ Hash<String,Types::BotAliasLocaleSettings>
Maps configuration information to a specific locale.
-
#bot_alias_name ⇒ String
The alias to create.
-
#bot_id ⇒ String
The unique identifier of the bot that the alias applies to.
-
#bot_version ⇒ String
The version of the bot that this alias points to.
-
#conversation_log_settings ⇒ Types::ConversationLogSettings
Specifies whether Amazon Lex logs text and audio for a conversation with the bot.
-
#description ⇒ String
A description of the alias.
-
#sentiment_analysis_settings ⇒ Types::SentimentAnalysisSettings
Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
-
#tags ⇒ Hash<String,String>
A list of tags to add to the bot alias.
Instance Attribute Details
#bot_alias_locale_settings ⇒ Hash<String,Types::BotAliasLocaleSettings>
Maps configuration information to a specific locale. You can use this parameter to specify a specific Lambda function to run different functions in different locales.
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_alias_name ⇒ String
The alias to create. The name must be unique for the bot.
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot that the alias applies to.
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that this alias points to. You can use the
- UpdateBotAlias][1
-
operation to change the bot version associated
with the alias.
[1]: docs.aws.amazon.com/lexv2/latest/APIReference/API_UpdateBotAlias.html
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |
#conversation_log_settings ⇒ Types::ConversationLogSettings
Specifies whether Amazon Lex logs text and audio for a conversation with the bot. When you enable conversation logs, text logs store text input, transcripts of audio input, and associated metadata in Amazon CloudWatch Logs. Audio logs store audio input in Amazon S3.
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the alias. Use this description to help identify the alias.
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |
#sentiment_analysis_settings ⇒ Types::SentimentAnalysisSettings
Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of tags to add to the bot alias. You can only add tags when you create an alias, you can’t use the UpdateBotAlias operation to update the tags on a bot alias. To update tags, use the TagResource operation.
3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3453 class CreateBotAliasRequest < Struct.new( :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_id, :tags) SENSITIVE = [] include Aws::Structure end |