Class: Aws::LexModelsV2::Types::CreateBotAliasResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::CreateBotAliasResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_alias_id ⇒ String
The unique identifier of the bot alias.
-
#bot_alias_locale_settings ⇒ Hash<String,Types::BotAliasLocaleSettings>
Configuration information for a specific locale.
-
#bot_alias_name ⇒ String
The name specified for the bot alias.
-
#bot_alias_status ⇒ String
The current status of the alias.
-
#bot_id ⇒ String
The unique identifier of the bot that this alias applies to.
-
#bot_version ⇒ String
The version of the bot associated with this alias.
-
#conversation_log_settings ⇒ Types::ConversationLogSettings
The conversation log settings specified for the alias.
-
#creation_date_time ⇒ Time
A Unix timestamp indicating the date and time that the bot alias was created.
-
#description ⇒ String
The description specified for the bot alias.
-
#sentiment_analysis_settings ⇒ Types::SentimentAnalysisSettings
Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
-
#tags ⇒ Hash<String,String>
A list of tags associated with the bot alias.
Instance Attribute Details
#bot_alias_id ⇒ String
The unique identifier of the bot alias.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_alias_locale_settings ⇒ Hash<String,Types::BotAliasLocaleSettings>
Configuration information for a specific locale.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_alias_name ⇒ String
The name specified for the bot alias.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_alias_status ⇒ String
The current status of the alias. The alias is first put into the
Creating state. When the alias is ready to be used, it is put into
the Available state. You can use the DescribeBotAlias operation
to get the current state of an alias.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot that this alias applies to.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with this alias.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#conversation_log_settings ⇒ Types::ConversationLogSettings
The conversation log settings specified for the alias.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A Unix timestamp indicating the date and time that the bot alias was created.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description specified for the bot alias.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#sentiment_analysis_settings ⇒ Types::SentimentAnalysisSettings
Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of tags associated with the bot alias.
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3582 class CreateBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_status, :bot_id, :creation_date_time, :tags) SENSITIVE = [] include Aws::Structure end |