Class: Aws::LexModelsV2::Types::CreateBotLocaleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::CreateBotLocaleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_filler_settings ⇒ Types::AudioFillerSettings
The audio filler settings configured for the created bot locale.
-
#bot_id ⇒ String
The specified bot identifier.
-
#bot_locale_status ⇒ String
The status of the bot.
-
#bot_version ⇒ String
The specified bot version.
-
#creation_date_time ⇒ Time
A timestamp specifying the date and time that the bot locale was created.
-
#description ⇒ String
The specified description of the bot locale.
-
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains specifications about the generative AI capabilities from Amazon Bedrock that you can turn on for your bot.
-
#locale_id ⇒ String
The specified locale identifier.
-
#locale_name ⇒ String
The specified locale name.
-
#nlu_intent_confidence_threshold ⇒ Float
The specified confidence threshold for inserting the ‘AMAZON.FallbackIntent` and `AMAZON.KendraSearchIntent` intents.
-
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) that was specified for the bot locale.
-
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The speech-to-text settings configured for the created bot locale.
-
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The unified speech settings configured for the created bot locale.
-
#voice_settings ⇒ Types::VoiceSettings
The Amazon Polly voice ID that Amazon Lex uses for voice interaction with the user.
Instance Attribute Details
#audio_filler_settings ⇒ Types::AudioFillerSettings
The audio filler settings configured for the created bot locale.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The specified bot identifier.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_locale_status ⇒ String
The status of the bot.
When the status is ‘Creating` the bot locale is being configured. When the status is `Building` Amazon Lex is building the bot for testing and use.
If the status of the bot is ‘ReadyExpressTesting`, you can test the bot using the exact utterances specified in the bots’ intents. When the bot is ready for full testing or to run, the status is ‘Built`.
If there was a problem with building the bot, the status is ‘Failed`. If the bot was saved but not built, the status is `NotBuilt`.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The specified bot version.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp specifying the date and time that the bot locale was created.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The specified description of the bot locale.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains specifications about the generative AI capabilities from Amazon Bedrock that you can turn on for your bot.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The specified locale identifier.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#locale_name ⇒ String
The specified locale name.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#nlu_intent_confidence_threshold ⇒ Float
The specified confidence threshold for inserting the ‘AMAZON.FallbackIntent` and `AMAZON.KendraSearchIntent` intents.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) that was specified for the bot locale.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The speech-to-text settings configured for the created bot locale.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The unified speech settings configured for the created bot locale.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#voice_settings ⇒ Types::VoiceSettings
The Amazon Polly voice ID that Amazon Lex uses for voice interaction with the user.
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 3765 class CreateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_name, :locale_id, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :creation_date_time, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |