Class: Aws::LexModelsV2::Types::CreateSlotResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::CreateSlotResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot associated with the slot.
-
#bot_version ⇒ String
The version of the bot associated with the slot.
-
#creation_date_time ⇒ Time
The timestamp of the date and time that the slot was created.
-
#description ⇒ String
The description associated with the slot.
-
#intent_id ⇒ String
The unique identifier of the intent associated with the slot.
-
#locale_id ⇒ String
The language and local specified for the slot.
-
#multiple_values_setting ⇒ Types::MultipleValuesSetting
Indicates whether the slot returns multiple values in one response.
-
#obfuscation_setting ⇒ Types::ObfuscationSetting
Indicates whether the slot is configured to obfuscate values in Amazon CloudWatch logs.
-
#slot_id ⇒ String
The unique identifier associated with the slot.
-
#slot_name ⇒ String
The name specified for the slot.
-
#slot_type_id ⇒ String
The unique identifier of the slot type associated with this slot.
-
#sub_slot_setting ⇒ Types::SubSlotSetting
Specifications for the constituent sub slots and the expression for the composite slot.
-
#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting
The value elicitation settings specified for the slot.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot associated with the slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The timestamp of the date and time that the slot was created.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description associated with the slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The unique identifier of the intent associated with the slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and local specified for the slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#multiple_values_setting ⇒ Types::MultipleValuesSetting
Indicates whether the slot returns multiple values in one response.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#obfuscation_setting ⇒ Types::ObfuscationSetting
Indicates whether the slot is configured to obfuscate values in Amazon CloudWatch logs.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_id ⇒ String
The unique identifier associated with the slot. Use this to identify the slot when you update or delete it.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_name ⇒ String
The name specified for the slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_id ⇒ String
The unique identifier of the slot type associated with this slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#sub_slot_setting ⇒ Types::SubSlotSetting
Specifications for the constituent sub slots and the expression for the composite slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting
The value elicitation settings specified for the slot.
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4709 class CreateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |