Class: Aws::LexModelsV2::Types::CreateSlotTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::CreateSlotTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot associated with this slot type.
-
#bot_version ⇒ String
The identifier of the bot version associated with this slot type.
-
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
-
#description ⇒ String
A description of the slot type.
-
#external_source_setting ⇒ Types::ExternalSourceSetting
Sets the type of external information used to create the slot type.
-
#locale_id ⇒ String
The identifier of the language and locale that the slot type will be used in.
-
#parent_slot_type_signature ⇒ String
The built-in slot type used as a parent of this slot type.
-
#slot_type_name ⇒ String
The name for the slot.
-
#slot_type_values ⇒ Array<Types::SlotTypeValue>
A list of
SlotTypeValueobjects that defines the values that the slot type can take. -
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
Determines the strategy that Amazon Lex uses to select a value from the list of possible values.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot associated with this slot type.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The identifier of the bot version associated with this slot type.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the slot type. Use the description to help identify the slot type in lists.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#external_source_setting ⇒ Types::ExternalSourceSetting
Sets the type of external information used to create the slot type.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale that the slot type will be used in. The string must match one of the supported locales. All of the bots, intents, and slots used by the slot type must have the same locale. For more information, see [Supported languages].
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#parent_slot_type_signature ⇒ String
The built-in slot type used as a parent of this slot type. When you define a parent slot type, the new slot type has the configuration of the parent slot type.
Only AMAZON.AlphaNumeric is supported.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_name ⇒ String
The name for the slot. A slot type name must be unique within the intent.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_values ⇒ Array<Types::SlotTypeValue>
A list of SlotTypeValue objects that defines the values that the slot type can take. Each value can have a list of synonyms, additional values that help train the machine learning model about the values that it resolves for a slot.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
Determines the strategy that Amazon Lex uses to select a value from the list of possible values. The field can be set to one of the following values:
-
ORIGINAL_VALUE- Returns the value entered by the user, if the user value is similar to the slot value. -
TOP_RESOLUTION- If there is a resolution list for the slot, return the first value in the resolution list. If there is no resolution list, return null.
If you don’t specify the valueSelectionSetting parameter, the default is ORIGINAL_VALUE.
4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 4705 class CreateSlotTypeRequest < Struct.new( :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |