Class: Aws::LexModelsV2::Types::CustomVocabularyItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The unique custom vocabulary item from the custom vocabulary list.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_asString

The DisplayAs value for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (String)


5041
5042
5043
5044
5045
5046
5047
5048
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5041

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end

#item_idString

The unique item identifer for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (String)


5041
5042
5043
5044
5045
5046
5047
5048
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5041

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end

#phraseString

The unique phrase for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (String)


5041
5042
5043
5044
5045
5046
5047
5048
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5041

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end

#weightInteger

The weight assigned for the custom vocabulary item from the custom vocabulary list.

Returns:

  • (Integer)


5041
5042
5043
5044
5045
5046
5047
5048
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5041

class CustomVocabularyItem < Struct.new(
  :item_id,
  :phrase,
  :weight,
  :display_as)
  SENSITIVE = []
  include Aws::Structure
end