Method: Aws::LexModelsV2::Types::DataSourceConfiguration#kendra_configuration
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
#kendra_configuration ⇒ Types::QnAKendraConfiguration
Contains details about the configuration of the Amazon Kendra index used for the AMAZON.QnAIntent. To create a Amazon Kendra index, follow the steps at [Creating an index].
5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5030 class DataSourceConfiguration < Struct.new( :opensearch_configuration, :kendra_configuration, :bedrock_knowledge_store_configuration) SENSITIVE = [] include Aws::Structure end |