Class: Aws::LexModelsV2::Types::DeleteBotAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_idString

The unique identifier of the bot alias to delete.

Returns:

  • (String)


5180
5181
5182
5183
5184
5185
5186
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5180

class DeleteBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The unique identifier of the bot associated with the alias to delete.

Returns:

  • (String)


5180
5181
5182
5183
5184
5185
5186
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5180

class DeleteBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_checkBoolean

By default, Amazon Lex checks if any other resource, such as a bot network, is using the bot alias before it is deleted and throws a ResourceInUseException exception if the alias is being used by another resource. Set this parameter to true to skip this check and remove the alias even if it is being used by another resource.

Returns:

  • (Boolean)


5180
5181
5182
5183
5184
5185
5186
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5180

class DeleteBotAliasRequest < Struct.new(
  :bot_alias_id,
  :bot_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end