Class: Aws::LexModelsV2::Types::DeleteBotAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DeleteBotAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_alias_id ⇒ String
The unique identifier of the bot alias to delete.
-
#bot_id ⇒ String
The unique identifier of the bot associated with the alias to delete.
-
#skip_resource_in_use_check ⇒ Boolean
By default, Amazon Lex checks if any other resource, such as a bot network, is using the bot alias before it is deleted and throws a
ResourceInUseExceptionexception if the alias is being used by another resource.
Instance Attribute Details
#bot_alias_id ⇒ String
The unique identifier of the bot alias to delete.
5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5272 class DeleteBotAliasRequest < Struct.new( :bot_alias_id, :bot_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot associated with the alias to delete.
5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5272 class DeleteBotAliasRequest < Struct.new( :bot_alias_id, :bot_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#skip_resource_in_use_check ⇒ Boolean
By default, Amazon Lex checks if any other resource, such as a bot
network, is using the bot alias before it is deleted and throws a
ResourceInUseException exception if the alias is being used by
another resource. Set this parameter to true to skip this check
and remove the alias even if it is being used by another resource.
5272 5273 5274 5275 5276 5277 5278 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5272 class DeleteBotAliasRequest < Struct.new( :bot_alias_id, :bot_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |