Class: Aws::LexModelsV2::Types::DeleteBotAliasResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_idString

The unique identifier of the bot alias to delete.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5205

class DeleteBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_id,
  :bot_alias_status)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_statusString

The current status of the alias. The status is Deleting while the alias is in the process of being deleted. Once the alias is deleted, it will no longer appear in the list of aliases returned by the ListBotAliases operation.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5205

class DeleteBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_id,
  :bot_alias_status)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The unique identifier of the bot that contains the alias to delete.

Returns:

  • (String)


5205
5206
5207
5208
5209
5210
5211
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5205

class DeleteBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_id,
  :bot_alias_status)
  SENSITIVE = []
  include Aws::Structure
end