Class: Aws::LexModelsV2::Types::DeleteBotLocaleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DeleteBotLocaleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot that contained the deleted locale.
-
#bot_locale_status ⇒ String
The status of deleting the bot locale.
-
#bot_version ⇒ String
The version of the bot that contained the deleted locale.
-
#locale_id ⇒ String
The language and locale of the deleted locale.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot that contained the deleted locale.
5283 5284 5285 5286 5287 5288 5289 5290 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283 class DeleteBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_locale_status) SENSITIVE = [] include Aws::Structure end |
#bot_locale_status ⇒ String
The status of deleting the bot locale. The locale first enters the Deleting status. Once the locale is deleted it no longer appears in the list of locales for the bot.
5283 5284 5285 5286 5287 5288 5289 5290 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283 class DeleteBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_locale_status) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contained the deleted locale.
5283 5284 5285 5286 5287 5288 5289 5290 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283 class DeleteBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_locale_status) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and locale of the deleted locale.
5283 5284 5285 5286 5287 5288 5289 5290 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5283 class DeleteBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_locale_status) SENSITIVE = [] include Aws::Structure end |