Class: Aws::LexModelsV2::Types::DeleteBotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DeleteBotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot to delete.
-
#skip_resource_in_use_check ⇒ Boolean
By default, Amazon Lex checks if any other resource, such as an alias or bot network, is using the bot version before it is deleted and throws a
ResourceInUseExceptionexception if the bot is being used by another resource.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot to delete.
5347 5348 5349 5350 5351 5352 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5347 class DeleteBotRequest < Struct.new( :bot_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#skip_resource_in_use_check ⇒ Boolean
By default, Amazon Lex checks if any other resource, such as an alias or bot network, is using the bot version before it is deleted and throws a ResourceInUseException exception if the bot is being used by another resource. Set this parameter to true to skip this check and remove the bot even if it is being used by another resource.
5347 5348 5349 5350 5351 5352 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5347 class DeleteBotRequest < Struct.new( :bot_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |