Class: Aws::LexModelsV2::Types::DeleteBotVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot that contains the version.

Returns:

  • (String)


5391
5392
5393
5394
5395
5396
5397
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5391

class DeleteBotVersionRequest < Struct.new(
  :bot_id,
  :bot_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot to delete.

Returns:

  • (String)


5391
5392
5393
5394
5395
5396
5397
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5391

class DeleteBotVersionRequest < Struct.new(
  :bot_id,
  :bot_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_checkBoolean

By default, Amazon Lex checks if any other resource, such as an alias or bot network, is using the bot version before it is deleted and throws a ResourceInUseException exception if the version is being used by another resource. Set this parameter to true to skip this check and remove the version even if it is being used by another resource.

Returns:

  • (Boolean)


5391
5392
5393
5394
5395
5396
5397
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5391

class DeleteBotVersionRequest < Struct.new(
  :bot_id,
  :bot_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end