Class: Aws::LexModelsV2::Types::DeleteResourcePolicyStatementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DeleteResourcePolicyStatementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_revision_id ⇒ String
The identifier of the revision of the policy to delete the statement from.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy is attached to.
-
#statement_id ⇒ String
The name of the statement (SID) to delete from the policy.
Instance Attribute Details
#expected_revision_id ⇒ String
The identifier of the revision of the policy to delete the statement from. If this revision ID doesn't match the current revision ID, Amazon Lex throws an exception.
If you don't specify a revision, Amazon Lex removes the current contents of the statement.
5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5736 class DeleteResourcePolicyStatementRequest < Struct.new( :resource_arn, :statement_id, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy is attached to.
5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5736 class DeleteResourcePolicyStatementRequest < Struct.new( :resource_arn, :statement_id, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |
#statement_id ⇒ String
The name of the statement (SID) to delete from the policy.
5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5736 class DeleteResourcePolicyStatementRequest < Struct.new( :resource_arn, :statement_id, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |