Class: Aws::LexModelsV2::Types::DescribeBotAliasResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_history_eventsArray<Types::BotAliasHistoryEvent>

A list of events that affect a bot alias. For example, an event is recorded when the version that the alias points to changes.

Returns:



5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_idString

The identifier of the bot alias.

Returns:

  • (String)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_locale_settingsHash<String,Types::BotAliasLocaleSettings>

The locale settings that are unique to the alias.

Returns:



5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_nameString

The name of the bot alias.

Returns:

  • (String)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_statusString

The current status of the alias. When the alias is ‘Available`, the alias is ready for use with your bot.

Returns:

  • (String)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The identifier of the bot associated with the bot alias.

Returns:

  • (String)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot associated with the bot alias.

Returns:

  • (String)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_log_settingsTypes::ConversationLogSettings

Specifics of how Amazon Lex logs text and audio conversations with the bot associated with the alias.



5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

A timestamp of the date and time that the alias was created.

Returns:

  • (Time)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the bot alias.

Returns:

  • (String)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

A timestamp of the date and time that the alias was last updated.

Returns:

  • (Time)


5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#parent_bot_networksArray<Types::ParentBotNetwork>

A list of the networks to which the bot alias you described belongs.

Returns:



5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end

#sentiment_analysis_settingsTypes::SentimentAnalysisSettings

Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.



5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5951

class DescribeBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_history_events,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time,
  :parent_bot_networks)
  SENSITIVE = []
  include Aws::Structure
end