Class: Aws::LexModelsV2::Types::DescribeBotAliasResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeBotAliasResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_alias_history_events ⇒ Array<Types::BotAliasHistoryEvent>
A list of events that affect a bot alias.
-
#bot_alias_id ⇒ String
The identifier of the bot alias.
-
#bot_alias_locale_settings ⇒ Hash<String,Types::BotAliasLocaleSettings>
The locale settings that are unique to the alias.
-
#bot_alias_name ⇒ String
The name of the bot alias.
-
#bot_alias_status ⇒ String
The current status of the alias.
-
#bot_id ⇒ String
The identifier of the bot associated with the bot alias.
-
#bot_version ⇒ String
The version of the bot associated with the bot alias.
-
#conversation_log_settings ⇒ Types::ConversationLogSettings
Specifics of how Amazon Lex logs text and audio conversations with the bot associated with the alias.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the alias was created.
-
#description ⇒ String
The description of the bot alias.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the alias was last updated.
-
#parent_bot_networks ⇒ Array<Types::ParentBotNetwork>
A list of the networks to which the bot alias you described belongs.
-
#sentiment_analysis_settings ⇒ Types::SentimentAnalysisSettings
Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
Instance Attribute Details
#bot_alias_history_events ⇒ Array<Types::BotAliasHistoryEvent>
A list of events that affect a bot alias. For example, an event is recorded when the version that the alias points to changes.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#bot_alias_id ⇒ String
The identifier of the bot alias.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#bot_alias_locale_settings ⇒ Hash<String,Types::BotAliasLocaleSettings>
The locale settings that are unique to the alias.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#bot_alias_name ⇒ String
The name of the bot alias.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#bot_alias_status ⇒ String
The current status of the alias. When the alias is Available, the
alias is ready for use with your bot.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The identifier of the bot associated with the bot alias.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the bot alias.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#conversation_log_settings ⇒ Types::ConversationLogSettings
Specifics of how Amazon Lex logs text and audio conversations with the bot associated with the alias.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the alias was created.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the bot alias.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the alias was last updated.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#parent_bot_networks ⇒ Array<Types::ParentBotNetwork>
A list of the networks to which the bot alias you described belongs.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |
#sentiment_analysis_settings ⇒ Types::SentimentAnalysisSettings
Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5970 class DescribeBotAliasResponse < Struct.new( :bot_alias_id, :bot_alias_name, :description, :bot_version, :bot_alias_locale_settings, :conversation_log_settings, :sentiment_analysis_settings, :bot_alias_history_events, :bot_alias_status, :bot_id, :creation_date_time, :last_updated_date_time, :parent_bot_networks) SENSITIVE = [] include Aws::Structure end |