Class: Aws::LexModelsV2::Types::DescribeBotAnalyzerRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeBotAnalyzerRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_analyzer_request_id ⇒ String
The unique identifier of the analysis request.
-
#bot_id ⇒ String
The unique identifier of the bot.
-
#max_results ⇒ Integer
The maximum number of recommendations to return in the response.
-
#next_token ⇒ String
If the response from a previous request was truncated, the ‘nextToken` value is used to retrieve the next page of recommendations.
Instance Attribute Details
#bot_analyzer_request_id ⇒ String
The unique identifier of the analysis request.
5990 5991 5992 5993 5994 5995 5996 5997 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5990 class DescribeBotAnalyzerRecommendationRequest < Struct.new( :bot_id, :bot_analyzer_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot.
5990 5991 5992 5993 5994 5995 5996 5997 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5990 class DescribeBotAnalyzerRecommendationRequest < Struct.new( :bot_id, :bot_analyzer_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of recommendations to return in the response. The default is 5.
5990 5991 5992 5993 5994 5995 5996 5997 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5990 class DescribeBotAnalyzerRecommendationRequest < Struct.new( :bot_id, :bot_analyzer_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response from a previous request was truncated, the ‘nextToken` value is used to retrieve the next page of recommendations.
5990 5991 5992 5993 5994 5995 5996 5997 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5990 class DescribeBotAnalyzerRecommendationRequest < Struct.new( :bot_id, :bot_analyzer_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |