Class: Aws::LexModelsV2::Types::DescribeBotAnalyzerRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_analyzer_request_idString

The unique identifier of the analysis request.

Returns:



5917
5918
5919
5920
5921
5922
5923
5924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5917

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The unique identifier of the bot.

Returns:



5917
5918
5919
5920
5921
5922
5923
5924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5917

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of recommendations to return in the response. The default is 5.

Returns:



5917
5918
5919
5920
5921
5922
5923
5924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5917

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response from a previous request was truncated, the nextToken value is used to retrieve the next page of recommendations.

Returns:



5917
5918
5919
5920
5921
5922
5923
5924
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 5917

class DescribeBotAnalyzerRecommendationRequest < Struct.new(
  :bot_id,
  :bot_analyzer_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end