Class: Aws::LexModelsV2::Types::DescribeBotAnalyzerRecommendationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeBotAnalyzerRecommendationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_analyzer_recommendation_list ⇒ Array<Types::BotAnalyzerRecommendation>
A list of recommendations for optimizing your bot configuration.
-
#bot_analyzer_status ⇒ String
The current status of the analysis.
-
#bot_id ⇒ String
The unique identifier of the bot.
-
#bot_version ⇒ String
The version of the bot that was analyzed.
-
#creation_date_time ⇒ Time
The date and time when the analysis was initiated.
-
#locale_id ⇒ String
The locale identifier of the bot locale that was analyzed.
-
#next_token ⇒ String
If the response is truncated, this token can be used in a subsequent request to retrieve the next page of recommendations.
Instance Attribute Details
#bot_analyzer_recommendation_list ⇒ Array<Types::BotAnalyzerRecommendation>
A list of recommendations for optimizing your bot configuration. Each recommendation includes the issue location, priority, description, and proposed fix.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6034 class DescribeBotAnalyzerRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_analyzer_status, :creation_date_time, :bot_analyzer_recommendation_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_analyzer_status ⇒ String
The current status of the analysis.
Valid Values: ‘Processing | Available | Failed | Stopping | Stopped`
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6034 class DescribeBotAnalyzerRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_analyzer_status, :creation_date_time, :bot_analyzer_recommendation_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6034 class DescribeBotAnalyzerRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_analyzer_status, :creation_date_time, :bot_analyzer_recommendation_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that was analyzed.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6034 class DescribeBotAnalyzerRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_analyzer_status, :creation_date_time, :bot_analyzer_recommendation_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the analysis was initiated.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6034 class DescribeBotAnalyzerRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_analyzer_status, :creation_date_time, :bot_analyzer_recommendation_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The locale identifier of the bot locale that was analyzed.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6034 class DescribeBotAnalyzerRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_analyzer_status, :creation_date_time, :bot_analyzer_recommendation_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, this token can be used in a subsequent request to retrieve the next page of recommendations.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6034 class DescribeBotAnalyzerRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_analyzer_status, :creation_date_time, :bot_analyzer_recommendation_list, :next_token) SENSITIVE = [] include Aws::Structure end |