Class: Aws::LexModelsV2::Types::DescribeBotLocaleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_filler_settingsTypes::AudioFillerSettings

The audio filler settings configured for the bot locale.



6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The identifier of the bot associated with the locale.

Returns:

  • (String)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#bot_locale_history_eventsArray<Types::BotLocaleHistoryEvent>

History of changes, such as when a locale is used in an alias, that have taken place for the locale.

Returns:



6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#bot_locale_statusString

The status of the bot. If the status is ‘Failed`, the reasons for the failure are listed in the `failureReasons` field.

Returns:

  • (String)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot associated with the locale.

Returns:

  • (String)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time that the locale was created.

Returns:

  • (Time)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the locale.

Returns:

  • (String)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonsArray<String>

if ‘botLocaleStatus` is `Failed`, Amazon Lex explains why it failed to build the bot.

Returns:

  • (Array<String>)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#generative_ai_settingsTypes::GenerativeAISettings

Contains settings for Amazon Bedrock’s generative AI features for your bot locale.



6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#intents_countInteger

The number of intents defined for the locale.

Returns:

  • (Integer)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#last_build_submitted_date_timeTime

The date and time that the locale was last submitted for building.

Returns:

  • (Time)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

The date and time that the locale was last updated.

Returns:

  • (Time)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The unique identifier of the described locale.

Returns:

  • (String)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#locale_nameString

The name of the locale.

Returns:

  • (String)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#nlu_intent_confidence_thresholdFloat

The confidence threshold where Amazon Lex inserts the ‘AMAZON.FallbackIntent` and `AMAZON.KendraSearchIntent` intents in the list of possible intents for an utterance.

Returns:

  • (Float)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

Recommended actions to take to resolve an error in the ‘failureReasons` field.

Returns:

  • (Array<String>)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#slot_types_countInteger

The number of slot types defined for the locale.

Returns:

  • (Integer)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#speech_detection_sensitivityString

The sensitivity level for voice activity detection (VAD) configured for the bot locale.

Returns:

  • (String)


6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#speech_recognition_settingsTypes::SpeechRecognitionSettings

The speech-to-text settings configured for the bot locale.



6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#unified_speech_settingsTypes::UnifiedSpeechSettings

The unified speech settings configured for the bot locale.



6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#voice_settingsTypes::VoiceSettings

The Amazon Polly voice Amazon Lex uses for voice interaction with the user.



6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6169

class DescribeBotLocaleResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :locale_name,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :audio_filler_settings,
  :speech_recognition_settings,
  :intents_count,
  :slot_types_count,
  :bot_locale_status,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :last_build_submitted_date_time,
  :bot_locale_history_events,
  :recommended_actions,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end