Class: Aws::LexModelsV2::Types::DescribeBotLocaleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeBotLocaleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_filler_settings ⇒ Types::AudioFillerSettings
The audio filler settings configured for the bot locale.
-
#bot_id ⇒ String
The identifier of the bot associated with the locale.
-
#bot_locale_history_events ⇒ Array<Types::BotLocaleHistoryEvent>
History of changes, such as when a locale is used in an alias, that have taken place for the locale.
-
#bot_locale_status ⇒ String
The status of the bot.
-
#bot_version ⇒ String
The version of the bot associated with the locale.
-
#creation_date_time ⇒ Time
The date and time that the locale was created.
-
#description ⇒ String
The description of the locale.
-
#failure_reasons ⇒ Array<String>
if
botLocaleStatusisFailed, Amazon Lex explains why it failed to build the bot. -
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains settings for Amazon Bedrock's generative AI features for your bot locale.
-
#intents_count ⇒ Integer
The number of intents defined for the locale.
-
#last_build_submitted_date_time ⇒ Time
The date and time that the locale was last submitted for building.
-
#last_updated_date_time ⇒ Time
The date and time that the locale was last updated.
-
#locale_id ⇒ String
The unique identifier of the described locale.
-
#locale_name ⇒ String
The name of the locale.
-
#nlu_intent_confidence_threshold ⇒ Float
The confidence threshold where Amazon Lex inserts the
AMAZON.FallbackIntentandAMAZON.KendraSearchIntentintents in the list of possible intents for an utterance. -
#recommended_actions ⇒ Array<String>
Recommended actions to take to resolve an error in the
failureReasonsfield. -
#slot_types_count ⇒ Integer
The number of slot types defined for the locale.
-
#speaker_diarization_settings ⇒ Types::SpeakerDiarizationSettings
The speaker diarization settings configured for the bot locale.
-
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) configured for the bot locale.
-
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The speech-to-text settings configured for the bot locale.
-
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The unified speech settings configured for the bot locale.
-
#voice_settings ⇒ Types::VoiceSettings
The Amazon Polly voice Amazon Lex uses for voice interaction with the user.
Instance Attribute Details
#audio_filler_settings ⇒ Types::AudioFillerSettings
The audio filler settings configured for the bot locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The identifier of the bot associated with the locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#bot_locale_history_events ⇒ Array<Types::BotLocaleHistoryEvent>
History of changes, such as when a locale is used in an alias, that have taken place for the locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#bot_locale_status ⇒ String
The status of the bot. If the status is Failed, the reasons for
the failure are listed in the failureReasons field.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time that the locale was created.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#failure_reasons ⇒ Array<String>
if botLocaleStatus is Failed, Amazon Lex explains why it failed
to build the bot.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains settings for Amazon Bedrock's generative AI features for your bot locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#intents_count ⇒ Integer
The number of intents defined for the locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#last_build_submitted_date_time ⇒ Time
The date and time that the locale was last submitted for building.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The date and time that the locale was last updated.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The unique identifier of the described locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#locale_name ⇒ String
The name of the locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#nlu_intent_confidence_threshold ⇒ Float
The confidence threshold where Amazon Lex inserts the
AMAZON.FallbackIntent and AMAZON.KendraSearchIntent intents in
the list of possible intents for an utterance.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#recommended_actions ⇒ Array<String>
Recommended actions to take to resolve an error in the
failureReasons field.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#slot_types_count ⇒ Integer
The number of slot types defined for the locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#speaker_diarization_settings ⇒ Types::SpeakerDiarizationSettings
The speaker diarization settings configured for the bot locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#speech_detection_sensitivity ⇒ String
The sensitivity level for voice activity detection (VAD) configured for the bot locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The speech-to-text settings configured for the bot locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The unified speech settings configured for the bot locale.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |
#voice_settings ⇒ Types::VoiceSettings
The Amazon Polly voice Amazon Lex uses for voice interaction with the user.
6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6192 class DescribeBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :intents_count, :slot_types_count, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :last_build_submitted_date_time, :bot_locale_history_events, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity, :speaker_diarization_settings) SENSITIVE = [] include Aws::Structure end |