Class: Aws::LexModelsV2::Types::DescribeBotRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeBotRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot associated with the bot recommendation.
-
#bot_recommendation_id ⇒ String
The identifier of the bot recommendation to describe.
-
#bot_version ⇒ String
The version of the bot associated with the bot recommendation.
-
#locale_id ⇒ String
The identifier of the language and locale of the bot recommendation to describe.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot associated with the bot recommendation.
6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244 class DescribeBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |
#bot_recommendation_id ⇒ String
The identifier of the bot recommendation to describe.
6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244 class DescribeBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the bot recommendation.
6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244 class DescribeBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the bot recommendation to describe. The string must match one of the supported locales. For more information, see Supported languages.
6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6244 class DescribeBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |