Class: Aws::LexModelsV2::Types::DescribeBotRecommendationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot associated with the bot recommendation.

Returns:

  • (String)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_idString

The identifier of the bot recommendation being described.

Returns:

  • (String)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_resultsTypes::BotRecommendationResults

The object representing the URL of the bot definition, the URL of the associated transcript and a statistical summary of the bot recommendation results.



6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_statusString

The status of the bot recommendation. If the status is Failed, then the reasons for the failure are listed in the failureReasons field.

Returns:

  • (String)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot associated with the bot recommendation.

Returns:

  • (String)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time that the bot recommendation was created.

Returns:

  • (Time)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_settingTypes::EncryptionSetting

The object representing the passwords that were used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.



6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonsArray<String>

If botRecommendationStatus is Failed, Amazon Lex explains why.

Returns:

  • (Array<String>)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

The date and time that the bot recommendation was last updated.

Returns:

  • (Time)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale of the bot recommendation to describe.

Returns:

  • (String)


6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_source_settingTypes::TranscriptSourceSetting

The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.



6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6204

class DescribeBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :failure_reasons,
  :creation_date_time,
  :last_updated_date_time,
  :transcript_source_setting,
  :encryption_setting,
  :bot_recommendation_results)
  SENSITIVE = []
  include Aws::Structure
end