Class: Aws::LexModelsV2::Types::DescribeBotVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeBotVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot that contains the version.
-
#bot_members ⇒ Array<Types::BotMember>
The members of bot network in the version that was described.
-
#bot_name ⇒ String
The name of the bot that contains the version.
-
#bot_status ⇒ String
The current status of the bot.
-
#bot_type ⇒ String
The type of the bot in the version that was described.
-
#bot_version ⇒ String
The version of the bot that was described.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot version was created.
-
#data_privacy ⇒ Types::DataPrivacy
Data privacy settings for the bot version.
-
#description ⇒ String
The description specified for the bot.
-
#failure_reasons ⇒ Array<String>
If the ‘botStatus` is `Failed`, this contains a list of reasons that the version couldn’t be built.
-
#idle_session_ttl_in_seconds ⇒ Integer
The number of seconds that a session with the bot remains active before it is discarded by Amazon Lex.
-
#parent_bot_networks ⇒ Array<Types::ParentBotNetwork>
A list of the networks to which the bot version you described belongs.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permission to access the bot version.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot that contains the version.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#bot_members ⇒ Array<Types::BotMember>
The members of bot network in the version that was described.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#bot_name ⇒ String
The name of the bot that contains the version.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#bot_status ⇒ String
The current status of the bot. When the status is ‘Available`, the bot version is ready for use.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#bot_type ⇒ String
The type of the bot in the version that was described.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that was described.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot version was created.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#data_privacy ⇒ Types::DataPrivacy
Data privacy settings for the bot version.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description specified for the bot.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#failure_reasons ⇒ Array<String>
If the ‘botStatus` is `Failed`, this contains a list of reasons that the version couldn’t be built.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#idle_session_ttl_in_seconds ⇒ Integer
The number of seconds that a session with the bot remains active before it is discarded by Amazon Lex.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#parent_bot_networks ⇒ Array<Types::ParentBotNetwork>
A list of the networks to which the bot version you described belongs.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permission to access the bot version.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6614 class DescribeBotVersionResponse < Struct.new( :bot_id, :bot_name, :bot_version, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :failure_reasons, :creation_date_time, :parent_bot_networks, :bot_type, :bot_members) SENSITIVE = [] include Aws::Structure end |