Class: Aws::LexModelsV2::Types::DescribeExportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeExportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The date and time that the export was created.
-
#download_url ⇒ String
A pre-signed S3 URL that points to the bot or bot locale archive.
-
#export_id ⇒ String
The unique identifier of the described export.
-
#export_status ⇒ String
The status of the export.
-
#failure_reasons ⇒ Array<String>
If the
exportStatusis failed, contains one or more reasons why the export could not be completed. -
#file_format ⇒ String
The file format used in the files that describe the resource.
-
#last_updated_date_time ⇒ Time
The last date and time that the export was updated.
-
#resource_specification ⇒ Types::ExportResourceSpecification
The bot, bot ID, and optional locale ID of the exported bot or bot locale.
Instance Attribute Details
#creation_date_time ⇒ Time
The date and time that the export was created.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#download_url ⇒ String
A pre-signed S3 URL that points to the bot or bot locale archive. The URL is only available for 5 minutes after calling the DescribeExport operation.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#export_id ⇒ String
The unique identifier of the described export.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#export_status ⇒ String
The status of the export. When the status is Complete the export archive file is available for download.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#failure_reasons ⇒ Array<String>
If the exportStatus is failed, contains one or more reasons why the export could not be completed.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#file_format ⇒ String
The file format used in the files that describe the resource.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The last date and time that the export was updated.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#resource_specification ⇒ Types::ExportResourceSpecification
The bot, bot ID, and optional locale ID of the exported bot or bot locale.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6668 class DescribeExportResponse < Struct.new( :export_id, :resource_specification, :file_format, :export_status, :failure_reasons, :download_url, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |