Class: Aws::LexModelsV2::Types::DescribeImportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeImportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The date and time that the import was created.
-
#failure_reasons ⇒ Array<String>
If the
importStatusfield isFailed, this provides one or more reasons for the failure. -
#import_id ⇒ String
The unique identifier of the described import.
-
#import_status ⇒ String
The status of the import process.
-
#imported_resource_id ⇒ String
The unique identifier that Amazon Lex assigned to the resource created by the import.
-
#imported_resource_name ⇒ String
The name of the imported resource.
-
#last_updated_date_time ⇒ Time
The date and time that the import was last updated.
-
#merge_strategy ⇒ String
The strategy used when there was a name conflict between the imported resource and an existing resource.
-
#resource_specification ⇒ Types::ImportResourceSpecification
The specifications of the imported bot, bot locale, or custom vocabulary.
Instance Attribute Details
#creation_date_time ⇒ Time
The date and time that the import was created.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#failure_reasons ⇒ Array<String>
If the importStatus field is Failed, this provides one or more reasons for the failure.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
The unique identifier of the described import.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
The status of the import process. When the status is Completed the resource is imported and ready for use.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#imported_resource_id ⇒ String
The unique identifier that Amazon Lex assigned to the resource created by the import.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#imported_resource_name ⇒ String
The name of the imported resource.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The date and time that the import was last updated.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#merge_strategy ⇒ String
The strategy used when there was a name conflict between the imported resource and an existing resource. When the merge strategy is FailOnConflict existing resources are not overwritten and the import fails.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#resource_specification ⇒ Types::ImportResourceSpecification
The specifications of the imported bot, bot locale, or custom vocabulary.
6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6579 class DescribeImportResponse < Struct.new( :import_id, :resource_specification, :imported_resource_id, :imported_resource_name, :merge_strategy, :import_status, :failure_reasons, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |