Class: Aws::LexModelsV2::Types::DescribeIntentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot associated with the intent.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot associated with the intent.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

A timestamp of the date and time that the intent was created.

Returns:

  • (Time)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the intent.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dialog_code_hookTypes::DialogCodeHookSettings

The Lambda function called during each turn of a conversation with the intent.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_code_hookTypes::FulfillmentCodeHookSettings

The Lambda function called when the intent is complete and ready for fulfillment.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#initial_response_settingTypes::InitialResponseSetting

Configuration setting for a response sent to the user before Amazon Lex starts eliciting slots.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#input_contextsArray<Types::InputContext>

A list of contexts that must be active for the intent to be considered for sending to the user.

Returns:



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_closing_settingTypes::IntentClosingSetting

The response that Amazon Lex sends to when the intent is closed.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_confirmation_settingTypes::IntentConfirmationSetting

Prompts that Amazon Lex sends to the user to confirm completion of an intent.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_display_nameString

The display name specified for the intent.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_idString

The unique identifier assigned to the intent when it was created.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intent_nameString

The name specified for the intent.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_configurationTypes::KendraConfiguration

Configuration information required to use the ‘AMAZON.KendraSearchIntent` intent.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

A timestamp of the date and time that the intent was last updated.

Returns:

  • (Time)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The language and locale specified for the intent.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#output_contextsArray<Types::OutputContext>

A list of contexts that are activated when the intent is fulfilled.

Returns:



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#parent_intent_signatureString

The identifier of the built-in intent that this intent is derived from, if any.

Returns:

  • (String)


6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#q_in_connect_intent_configurationTypes::QInConnectIntentConfiguration

Qinconnect intent configuration details for the describe intent response.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#qn_a_intent_configurationTypes::QnAIntentConfiguration

Details about the configuration of the built-in ‘Amazon.QnAIntent`.



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sample_utterancesArray<Types::SampleUtterance>

User utterances that trigger this intent.

Returns:



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#slot_prioritiesArray<Types::SlotPriority>

The list that determines the priority that slots should be elicited from the user.

Returns:



6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962

class DescribeIntentResponse < Struct.new(
  :intent_id,
  :intent_name,
  :intent_display_name,
  :description,
  :parent_intent_signature,
  :sample_utterances,
  :dialog_code_hook,
  :fulfillment_code_hook,
  :slot_priorities,
  :intent_confirmation_setting,
  :intent_closing_setting,
  :input_contexts,
  :output_contexts,
  :kendra_configuration,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :initial_response_setting,
  :qn_a_intent_configuration,
  :q_in_connect_intent_configuration)
  SENSITIVE = []
  include Aws::Structure
end