Class: Aws::LexModelsV2::Types::DescribeIntentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeIntentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot associated with the intent.
-
#bot_version ⇒ String
The version of the bot associated with the intent.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the intent was created.
-
#description ⇒ String
The description of the intent.
-
#dialog_code_hook ⇒ Types::DialogCodeHookSettings
The Lambda function called during each turn of a conversation with the intent.
-
#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings
The Lambda function called when the intent is complete and ready for fulfillment.
-
#initial_response_setting ⇒ Types::InitialResponseSetting
Configuration setting for a response sent to the user before Amazon Lex starts eliciting slots.
-
#input_contexts ⇒ Array<Types::InputContext>
A list of contexts that must be active for the intent to be considered for sending to the user.
-
#intent_closing_setting ⇒ Types::IntentClosingSetting
The response that Amazon Lex sends to when the intent is closed.
-
#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting
Prompts that Amazon Lex sends to the user to confirm completion of an intent.
-
#intent_display_name ⇒ String
The display name specified for the intent.
-
#intent_id ⇒ String
The unique identifier assigned to the intent when it was created.
-
#intent_name ⇒ String
The name specified for the intent.
-
#kendra_configuration ⇒ Types::KendraConfiguration
Configuration information required to use the ‘AMAZON.KendraSearchIntent` intent.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the intent was last updated.
-
#locale_id ⇒ String
The language and locale specified for the intent.
-
#output_contexts ⇒ Array<Types::OutputContext>
A list of contexts that are activated when the intent is fulfilled.
-
#parent_intent_signature ⇒ String
The identifier of the built-in intent that this intent is derived from, if any.
-
#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration
Qinconnect intent configuration details for the describe intent response.
-
#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration
Details about the configuration of the built-in ‘Amazon.QnAIntent`.
-
#sample_utterances ⇒ Array<Types::SampleUtterance>
User utterances that trigger this intent.
-
#slot_priorities ⇒ Array<Types::SlotPriority>
The list that determines the priority that slots should be elicited from the user.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot associated with the intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the intent was created.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#dialog_code_hook ⇒ Types::DialogCodeHookSettings
The Lambda function called during each turn of a conversation with the intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings
The Lambda function called when the intent is complete and ready for fulfillment.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#initial_response_setting ⇒ Types::InitialResponseSetting
Configuration setting for a response sent to the user before Amazon Lex starts eliciting slots.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#input_contexts ⇒ Array<Types::InputContext>
A list of contexts that must be active for the intent to be considered for sending to the user.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_closing_setting ⇒ Types::IntentClosingSetting
The response that Amazon Lex sends to when the intent is closed.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting
Prompts that Amazon Lex sends to the user to confirm completion of an intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_display_name ⇒ String
The display name specified for the intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The unique identifier assigned to the intent when it was created.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_name ⇒ String
The name specified for the intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#kendra_configuration ⇒ Types::KendraConfiguration
Configuration information required to use the ‘AMAZON.KendraSearchIntent` intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the intent was last updated.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and locale specified for the intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#output_contexts ⇒ Array<Types::OutputContext>
A list of contexts that are activated when the intent is fulfilled.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#parent_intent_signature ⇒ String
The identifier of the built-in intent that this intent is derived from, if any.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration
Qinconnect intent configuration details for the describe intent response.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration
Details about the configuration of the built-in ‘Amazon.QnAIntent`.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#sample_utterances ⇒ Array<Types::SampleUtterance>
User utterances that trigger this intent.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#slot_priorities ⇒ Array<Types::SlotPriority>
The list that determines the priority that slots should be elicited from the user.
6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 6962 class DescribeIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |