Class: Aws::LexModelsV2::Types::DescribeSlotResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot associated with the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot associated with the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

A timestamp of the date and time that the slot was created.

Returns:

  • (Time)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description specified for the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#intent_idString

The identifier of the intent associated with the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

A timestamp of the date and time that the slot was last updated.

Returns:

  • (Time)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The language and locale specified for the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#multiple_values_settingTypes::MultipleValuesSetting

Indicates whether the slot accepts multiple values in a single utterance.

If the ‘multipleValuesSetting` is not set, the default value is `false`.



7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#obfuscation_settingTypes::ObfuscationSetting

Whether slot values are shown in Amazon CloudWatch logs. If the value is ‘None`, the actual value of the slot is shown in logs.



7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_idString

The unique identifier generated for the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_nameString

The name specified for the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_idString

The identifier of the slot type that determines the values entered into the slot.

Returns:

  • (String)


7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#sub_slot_settingTypes::SubSlotSetting

Specifications for the constituent sub slots and the expression for the composite slot.



7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end

#value_elicitation_settingTypes::SlotValueElicitationSetting

Prompts that Amazon Lex uses to elicit a value for the slot.



7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7137

class DescribeSlotResponse < Struct.new(
  :slot_id,
  :slot_name,
  :description,
  :slot_type_id,
  :value_elicitation_setting,
  :obfuscation_setting,
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :creation_date_time,
  :last_updated_date_time,
  :multiple_values_setting,
  :sub_slot_setting)
  SENSITIVE = []
  include Aws::Structure
end