Class: Aws::LexModelsV2::Types::DescribeSlotResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeSlotResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot associated with the slot.
-
#bot_version ⇒ String
The version of the bot associated with the slot.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the slot was created.
-
#description ⇒ String
The description specified for the slot.
-
#intent_id ⇒ String
The identifier of the intent associated with the slot.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the slot was last updated.
-
#locale_id ⇒ String
The language and locale specified for the slot.
-
#multiple_values_setting ⇒ Types::MultipleValuesSetting
Indicates whether the slot accepts multiple values in a single utterance.
-
#obfuscation_setting ⇒ Types::ObfuscationSetting
Whether slot values are shown in Amazon CloudWatch logs.
-
#slot_id ⇒ String
The unique identifier generated for the slot.
-
#slot_name ⇒ String
The name specified for the slot.
-
#slot_type_id ⇒ String
The identifier of the slot type that determines the values entered into the slot.
-
#sub_slot_setting ⇒ Types::SubSlotSetting
Specifications for the constituent sub slots and the expression for the composite slot.
-
#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting
Prompts that Amazon Lex uses to elicit a value for the slot.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot associated with the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot associated with the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the slot was created.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description specified for the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The identifier of the intent associated with the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the slot was last updated.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and locale specified for the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#multiple_values_setting ⇒ Types::MultipleValuesSetting
Indicates whether the slot accepts multiple values in a single utterance.
If the multipleValuesSetting is not set, the default value is false.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#obfuscation_setting ⇒ Types::ObfuscationSetting
Whether slot values are shown in Amazon CloudWatch logs. If the value is None, the actual value of the slot is shown in logs.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_id ⇒ String
The unique identifier generated for the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_name ⇒ String
The name specified for the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_id ⇒ String
The identifier of the slot type that determines the values entered into the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#sub_slot_setting ⇒ Types::SubSlotSetting
Specifications for the constituent sub slots and the expression for the composite slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting
Prompts that Amazon Lex uses to elicit a value for the slot.
7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7059 class DescribeSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |