Class: Aws::LexModelsV2::Types::DescribeTestSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::DescribeTestSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The creation date and time for the test set data.
-
#description ⇒ String
The description of the test set.
-
#last_updated_date_time ⇒ Time
The date and time for the last update of the test set data.
-
#modality ⇒ String
Indicates whether the test set is audio or text data.
-
#num_turns ⇒ Integer
The total number of agent and user turn in the test set.
-
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
-
#status ⇒ String
The status of the test set.
-
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the test set data.
-
#test_set_id ⇒ String
The test set Id for the test set response.
-
#test_set_name ⇒ String
The test set name of the test set.
Instance Attribute Details
#creation_date_time ⇒ Time
The creation date and time for the test set data.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the test set.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The date and time for the last update of the test set data.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#modality ⇒ String
Indicates whether the test set is audio or text data.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#num_turns ⇒ Integer
The total number of agent and user turn in the test set.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the test set.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the test set data.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_id ⇒ String
The test set Id for the test set response.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_name ⇒ String
The test set name of the test set.
7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7458 class DescribeTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |