Class: Aws::LexModelsV2::Types::EncryptionSetting

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

The object representing the passwords that were used to encrypt the data related to the bot recommendation, as well as the KMS key ARN used to encrypt the associated metadata.

Constant Summary collapse

SENSITIVE =
[:bot_locale_export_password, :associated_transcripts_password]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_transcripts_passwordString

The password used to encrypt the associated transcript file.

Returns:

  • (String)


7716
7717
7718
7719
7720
7721
7722
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7716

class EncryptionSetting < Struct.new(
  :kms_key_arn,
  :bot_locale_export_password,
  :associated_transcripts_password)
  SENSITIVE = [:bot_locale_export_password, :associated_transcripts_password]
  include Aws::Structure
end

#bot_locale_export_passwordString

The password used to encrypt the recommended bot recommendation file.

Returns:

  • (String)


7716
7717
7718
7719
7720
7721
7722
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7716

class EncryptionSetting < Struct.new(
  :kms_key_arn,
  :bot_locale_export_password,
  :associated_transcripts_password)
  SENSITIVE = [:bot_locale_export_password, :associated_transcripts_password]
  include Aws::Structure
end

#kms_key_arnString

The KMS key ARN used to encrypt the metadata associated with the bot recommendation.

Returns:

  • (String)


7716
7717
7718
7719
7720
7721
7722
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 7716

class EncryptionSetting < Struct.new(
  :kms_key_arn,
  :bot_locale_export_password,
  :associated_transcripts_password)
  SENSITIVE = [:bot_locale_export_password, :associated_transcripts_password]
  include Aws::Structure
end