Class: Aws::LexModelsV2::Types::GenerateBotElementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The bot unique Id for the bot request to generate utterances.

Returns:

  • (String)


8018
8019
8020
8021
8022
8023
8024
8025
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8018

class GenerateBotElementRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The bot version for the bot request to generate utterances.

Returns:

  • (String)


8018
8019
8020
8021
8022
8023
8024
8025
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8018

class GenerateBotElementRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#intent_idString

The intent unique Id for the bot request to generate utterances.

Returns:

  • (String)


8018
8019
8020
8021
8022
8023
8024
8025
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8018

class GenerateBotElementRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The unique locale Id for the bot request to generate utterances.

Returns:

  • (String)


8018
8019
8020
8021
8022
8023
8024
8025
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8018

class GenerateBotElementRequest < Struct.new(
  :intent_id,
  :bot_id,
  :bot_version,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end