Class: Aws::LexModelsV2::Types::IntentClosingSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::IntentClosingSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Provides a statement the Amazon Lex conveys to the user when the intent is successfully fulfilled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active ⇒ Boolean
Specifies whether an intent’s closing response is used.
-
#closing_response ⇒ Types::ResponseSpecification
The response that Amazon Lex sends to the user when the intent is complete.
-
#conditional ⇒ Types::ConditionalSpecification
A list of conditional branches associated with the intent’s closing response.
-
#next_step ⇒ Types::DialogState
Specifies the next step that the bot executes after playing the intent’s closing response.
Instance Attribute Details
#active ⇒ Boolean
Specifies whether an intent’s closing response is used. When this field is false, the closing response isn’t sent to the user. If the active field isn’t specified, the default is true.
8548 8549 8550 8551 8552 8553 8554 8555 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8548 class IntentClosingSetting < Struct.new( :closing_response, :active, :next_step, :conditional) SENSITIVE = [] include Aws::Structure end |
#closing_response ⇒ Types::ResponseSpecification
The response that Amazon Lex sends to the user when the intent is complete.
8548 8549 8550 8551 8552 8553 8554 8555 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8548 class IntentClosingSetting < Struct.new( :closing_response, :active, :next_step, :conditional) SENSITIVE = [] include Aws::Structure end |
#conditional ⇒ Types::ConditionalSpecification
A list of conditional branches associated with the intent’s closing response. These branches are executed when the nextStep attribute is set to EvalutateConditional.
8548 8549 8550 8551 8552 8553 8554 8555 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8548 class IntentClosingSetting < Struct.new( :closing_response, :active, :next_step, :conditional) SENSITIVE = [] include Aws::Structure end |
#next_step ⇒ Types::DialogState
Specifies the next step that the bot executes after playing the intent’s closing response.
8548 8549 8550 8551 8552 8553 8554 8555 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8548 class IntentClosingSetting < Struct.new( :closing_response, :active, :next_step, :conditional) SENSITIVE = [] include Aws::Structure end |