Class: Aws::LexModelsV2::Types::IntentOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::IntentOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Override settings to configure the intent state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the intent.
-
#slots ⇒ Hash<String,Types::SlotValueOverride>
A map of all of the slot value overrides for the intent.
Instance Attribute Details
#name ⇒ String
The name of the intent. Only required when you’re switching intents.
8778 8779 8780 8781 8782 8783 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8778 class IntentOverride < Struct.new( :name, :slots) SENSITIVE = [] include Aws::Structure end |
#slots ⇒ Hash<String,Types::SlotValueOverride>
A map of all of the slot value overrides for the intent. The name of the slot maps to the value of the slot. Slots that are not included in the map aren’t overridden.
8778 8779 8780 8781 8782 8783 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8778 class IntentOverride < Struct.new( :name, :slots) SENSITIVE = [] include Aws::Structure end |