Class: Aws::LexModelsV2::Types::KendraConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::KendraConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Provides configuration information for the AMAZON.KendraSearchIntent intent. When you use this intent, Amazon Lex searches the specified Amazon Kendra index and returns documents from the index that match the user’s utterance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kendra_index ⇒ String
The Amazon Resource Name (ARN) of the Amazon Kendra index that you want the
AMAZON.KendraSearchIntentintent to search. -
#query_filter_string ⇒ String
A query filter that Amazon Lex sends to Amazon Kendra to filter the response from a query.
-
#query_filter_string_enabled ⇒ Boolean
Determines whether the
AMAZON.KendraSearchIntentintent uses a custom query string to query the Amazon Kendra index.
Instance Attribute Details
#kendra_index ⇒ String
The Amazon Resource Name (ARN) of the Amazon Kendra index that you want the AMAZON.KendraSearchIntent intent to search. The index must be in the same account and Region as the Amazon Lex bot.
8956 8957 8958 8959 8960 8961 8962 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8956 class KendraConfiguration < Struct.new( :kendra_index, :query_filter_string_enabled, :query_filter_string) SENSITIVE = [] include Aws::Structure end |
#query_filter_string ⇒ String
A query filter that Amazon Lex sends to Amazon Kendra to filter the response from a query. The filter is in the format defined by Amazon Kendra. For more information, see [Filtering queries].
8956 8957 8958 8959 8960 8961 8962 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8956 class KendraConfiguration < Struct.new( :kendra_index, :query_filter_string_enabled, :query_filter_string) SENSITIVE = [] include Aws::Structure end |
#query_filter_string_enabled ⇒ Boolean
Determines whether the AMAZON.KendraSearchIntent intent uses a custom query string to query the Amazon Kendra index.
8956 8957 8958 8959 8960 8961 8962 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 8956 class KendraConfiguration < Struct.new( :kendra_index, :query_filter_string_enabled, :query_filter_string) SENSITIVE = [] include Aws::Structure end |