Class: Aws::LexModelsV2::Types::ListBotAliasesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot to list aliases for.

Returns:

  • (String)


9238
9239
9240
9241
9242
9243
9244
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9238

class ListBotAliasesRequest < Struct.new(
  :bot_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of aliases to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


9238
9239
9240
9241
9242
9243
9244
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9238

class ListBotAliasesRequest < Struct.new(
  :bot_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response from the ListBotAliases operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


9238
9239
9240
9241
9242
9243
9244
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9238

class ListBotAliasesRequest < Struct.new(
  :bot_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end