Class: Aws::LexModelsV2::Types::ListBotAliasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListBotAliasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot to list aliases for.
-
#max_results ⇒ Integer
The maximum number of aliases to return in each page of results.
-
#next_token ⇒ String
If the response from the
ListBotAliasesoperation contains more results than specified in themaxResultsparameter, a token is returned in the response.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot to list aliases for.
9340 9341 9342 9343 9344 9345 9346 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9340 class ListBotAliasesRequest < Struct.new( :bot_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of aliases to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.
9340 9341 9342 9343 9344 9345 9346 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9340 class ListBotAliasesRequest < Struct.new( :bot_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response from the ListBotAliases operation contains more
results than specified in the maxResults parameter, a token is
returned in the response. Use that token in the nextToken
parameter to return the next page of results.
9340 9341 9342 9343 9344 9345 9346 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9340 class ListBotAliasesRequest < Struct.new( :bot_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |