Class: Aws::LexModelsV2::Types::ListBotAliasesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListBotAliasesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_alias_summaries ⇒ Array<Types::BotAliasSummary>
Summary information for the bot aliases that meet the filter criteria specified in the request.
-
#bot_id ⇒ String
The identifier of the bot associated with the aliases.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListBotAliasesoperation.
Instance Attribute Details
#bot_alias_summaries ⇒ Array<Types::BotAliasSummary>
Summary information for the bot aliases that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more aliases available, the nextToken field contains a token to get the next page of results.
9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9083 class ListBotAliasesResponse < Struct.new( :bot_alias_summaries, :next_token, :bot_id) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The identifier of the bot associated with the aliases.
9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9083 class ListBotAliasesResponse < Struct.new( :bot_alias_summaries, :next_token, :bot_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListBotAliases operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBotAliases operation request to get the next page of results.
9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9083 class ListBotAliasesResponse < Struct.new( :bot_alias_summaries, :next_token, :bot_id) SENSITIVE = [] include Aws::Structure end |