Class: Aws::LexModelsV2::Types::ListBotLocalesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListBotLocalesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot to list locales for.
-
#bot_locale_summaries ⇒ Array<Types::BotLocaleSummary>
Summary information for the locales that meet the filter criteria specified in the request.
-
#bot_version ⇒ String
The version of the bot.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListBotLocalesoperation.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot to list locales for.
9518 9519 9520 9521 9522 9523 9524 9525 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9518 class ListBotLocalesResponse < Struct.new( :bot_id, :bot_version, :next_token, :bot_locale_summaries) SENSITIVE = [] include Aws::Structure end |
#bot_locale_summaries ⇒ Array<Types::BotLocaleSummary>
Summary information for the locales that meet the filter criteria
specified in the request. The length of the list is specified in the
maxResults parameter of the request. If there are more locales
available, the nextToken field contains a token to get the next
page of results.
9518 9519 9520 9521 9522 9523 9524 9525 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9518 class ListBotLocalesResponse < Struct.new( :bot_id, :bot_version, :next_token, :bot_locale_summaries) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot.
9518 9519 9520 9521 9522 9523 9524 9525 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9518 class ListBotLocalesResponse < Struct.new( :bot_id, :bot_version, :next_token, :bot_locale_summaries) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a
response to the ListBotLocales operation. If the nextToken field
is present, you send the contents as the nextToken parameter of a
ListBotLocales operation request to get the next page of results.
9518 9519 9520 9521 9522 9523 9524 9525 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9518 class ListBotLocalesResponse < Struct.new( :bot_id, :bot_version, :next_token, :bot_locale_summaries) SENSITIVE = [] include Aws::Structure end |