Class: Aws::LexModelsV2::Types::ListBotRecommendationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The unique identifier of the bot that contains the bot recommendation list.

Returns:

  • (String)


9496
9497
9498
9499
9500
9501
9502
9503
9504
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9496

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_summariesArray<Types::BotRecommendationSummary>

Summary information for the bot recommendations that meet the filter specified in this request. The length of the list is specified in the maxResults parameter of the request. If there are more bot recommendations available, the nextToken field contains a token to get the next page of results.



9496
9497
9498
9499
9500
9501
9502
9503
9504
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9496

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that contains the bot recommendation list.

Returns:

  • (String)


9496
9497
9498
9499
9500
9501
9502
9503
9504
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9496

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale of the bot recommendation list.

Returns:

  • (String)


9496
9497
9498
9499
9500
9501
9502
9503
9504
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9496

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates whether there are more results to return in a response to the ListBotRecommendations operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBotRecommendations operation request to get the next page of results.

Returns:

  • (String)


9496
9497
9498
9499
9500
9501
9502
9503
9504
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9496

class ListBotRecommendationsResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end