Class: Aws::LexModelsV2::Types::ListBotVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot to list versions for.

Returns:

  • (String)


9711
9712
9713
9714
9715
9716
9717
9718
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotVersionsRequest < Struct.new(
  :bot_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of versions to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


9711
9712
9713
9714
9715
9716
9717
9718
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotVersionsRequest < Struct.new(
  :bot_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response to the ListBotVersion operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


9711
9712
9713
9714
9715
9716
9717
9718
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotVersionsRequest < Struct.new(
  :bot_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byTypes::BotVersionSortBy

Specifies sorting parameters for the list of versions. You can specify that the list be sorted by version name in either ascending or descending order.



9711
9712
9713
9714
9715
9716
9717
9718
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9711

class ListBotVersionsRequest < Struct.new(
  :bot_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end