Class: Aws::LexModelsV2::Types::ListBotVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListBotVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot to list versions for.
-
#bot_version_summaries ⇒ Array<Types::BotVersionSummary>
Summary information for the bot versions that meet the filter criteria specified in the request.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListBotVersionsoperation.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot to list versions for.
9742 9743 9744 9745 9746 9747 9748 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9742 class ListBotVersionsResponse < Struct.new( :bot_id, :bot_version_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_version_summaries ⇒ Array<Types::BotVersionSummary>
Summary information for the bot versions that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more versions available, the nextToken field contains a token to get the next page of results.
9742 9743 9744 9745 9746 9747 9748 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9742 class ListBotVersionsResponse < Struct.new( :bot_id, :bot_version_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListBotVersions operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBotAliases operation request to get the next page of results.
9742 9743 9744 9745 9746 9747 9748 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9742 class ListBotVersionsResponse < Struct.new( :bot_id, :bot_version_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |