Class: Aws::LexModelsV2::Types::ListBotsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListBotsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_summaries ⇒ Array<Types::BotSummary>
Summary information for the bots that meet the filter criteria specified in the request.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListBotsoperation.
Instance Attribute Details
#bot_summaries ⇒ Array<Types::BotSummary>
Summary information for the bots that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more bots available, the nextToken field contains a token to the next page of results.
9552 9553 9554 9555 9556 9557 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9552 class ListBotsResponse < Struct.new( :bot_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListBots operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBots operation request to get the next page of results.
9552 9553 9554 9555 9556 9557 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9552 class ListBotsResponse < Struct.new( :bot_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |