Class: Aws::LexModelsV2::Types::ListBuiltInIntentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListBuiltInIntentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#built_in_intent_summaries ⇒ Array<Types::BuiltInIntentSummary>
Summary information for the built-in intents that meet the filter criteria specified in the request.
-
#locale_id ⇒ String
The language and locale of the intents in the list.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListBuiltInIntentsoperation.
Instance Attribute Details
#built_in_intent_summaries ⇒ Array<Types::BuiltInIntentSummary>
Summary information for the built-in intents that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more intents available, the nextToken field contains a token to get the next page of results.
9876 9877 9878 9879 9880 9881 9882 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9876 class ListBuiltInIntentsResponse < Struct.new( :built_in_intent_summaries, :next_token, :locale_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and locale of the intents in the list.
9876 9877 9878 9879 9880 9881 9882 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9876 class ListBuiltInIntentsResponse < Struct.new( :built_in_intent_summaries, :next_token, :locale_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListBuiltInIntents operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListBotAliases operation request to get the next page of results.
9876 9877 9878 9879 9880 9881 9882 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9876 class ListBuiltInIntentsResponse < Struct.new( :built_in_intent_summaries, :next_token, :locale_id) SENSITIVE = [] include Aws::Structure end |