Class: Aws::LexModelsV2::Types::ListBuiltInSlotTypesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#locale_idString

The identifier of the language and locale of the slot types to list. The string must match one of the supported locales. For more information, see [Supported languages].

[1]: docs.aws.amazon.com/lexv2/latest/dg/how-languages.html

Returns:

  • (String)


9660
9661
9662
9663
9664
9665
9666
9667
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9660

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of built-in slot types to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


9660
9661
9662
9663
9664
9665
9666
9667
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9660

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response from the ListBuiltInSlotTypes operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


9660
9661
9662
9663
9664
9665
9666
9667
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9660

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byTypes::BuiltInSlotTypeSortBy

Determines the sort order for the response from the ListBuiltInSlotTypes operation. You can choose to sort by the slot type signature in either ascending or descending order.



9660
9661
9662
9663
9664
9665
9666
9667
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9660

class ListBuiltInSlotTypesRequest < Struct.new(
  :locale_id,
  :sort_by,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end