Class: Aws::LexModelsV2::Types::ListBuiltInSlotTypesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListBuiltInSlotTypesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#built_in_slot_type_summaries ⇒ Array<Types::BuiltInSlotTypeSummary>
Summary information for the built-in slot types that meet the filter criteria specified in the request.
-
#locale_id ⇒ String
The language and locale of the slot types in the list.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListBuiltInSlotTypesoperation.
Instance Attribute Details
#built_in_slot_type_summaries ⇒ Array<Types::BuiltInSlotTypeSummary>
Summary information for the built-in slot types that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more slot types available, the nextToken field contains a token to get the next page of results.
9946 9947 9948 9949 9950 9951 9952 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9946 class ListBuiltInSlotTypesResponse < Struct.new( :built_in_slot_type_summaries, :next_token, :locale_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and locale of the slot types in the list.
9946 9947 9948 9949 9950 9951 9952 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9946 class ListBuiltInSlotTypesResponse < Struct.new( :built_in_slot_type_summaries, :next_token, :locale_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListBuiltInSlotTypes operation. If the nextToken field is present, you send the contents as the nextToken parameter of a LIstBuiltInSlotTypes operation request to get the next page of results.
9946 9947 9948 9949 9950 9951 9952 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9946 class ListBuiltInSlotTypesResponse < Struct.new( :built_in_slot_type_summaries, :next_token, :locale_id) SENSITIVE = [] include Aws::Structure end |