Class: Aws::LexModelsV2::Types::ListBuiltInSlotTypesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#built_in_slot_type_summariesArray<Types::BuiltInSlotTypeSummary>

Summary information for the built-in slot types that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more slot types available, the nextToken field contains a token to get the next page of results.

Returns:



9691
9692
9693
9694
9695
9696
9697
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9691

class ListBuiltInSlotTypesResponse < Struct.new(
  :built_in_slot_type_summaries,
  :next_token,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The language and locale of the slot types in the list.

Returns:

  • (String)


9691
9692
9693
9694
9695
9696
9697
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9691

class ListBuiltInSlotTypesResponse < Struct.new(
  :built_in_slot_type_summaries,
  :next_token,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates whether there are more results to return in a response to the ListBuiltInSlotTypes operation. If the nextToken field is present, you send the contents as the nextToken parameter of a LIstBuiltInSlotTypes operation request to get the next page of results.

Returns:

  • (String)


9691
9692
9693
9694
9695
9696
9697
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 9691

class ListBuiltInSlotTypesResponse < Struct.new(
  :built_in_slot_type_summaries,
  :next_token,
  :locale_id)
  SENSITIVE = []
  include Aws::Structure
end