Class: Aws::LexModelsV2::Types::ListIntentMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bin_byArray<Types::AnalyticsBinBySpecification>

A list of objects, each of which contains specifications for organizing the results by time.



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The identifier for the bot for which you want to retrieve intent metrics.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_timeTime

The date and time that marks the end of the range of time for which you want to see intent metrics.

Returns:

  • (Time)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::AnalyticsIntentFilter>

A list of objects, each of which describes a condition by which you want to filter the results.

Returns:



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#group_byArray<Types::AnalyticsIntentGroupBySpecification>

A list of objects, each of which specifies how to group the results. You can group by the following criteria:

  • IntentName – The name of the intent.

  • IntentEndState – The final state of the intent. The possible end states are detailed in [Key definitions] in the user guide.

[1]: docs.aws.amazon.com/analytics-key-definitions-intents



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned.

Returns:

  • (Integer)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<Types::AnalyticsIntentMetric>

A list of objects, each of which contains a metric you want to list, the statistic for the metric you want to return, and the order by which to organize the results.

Returns:



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response from the ListIntentMetrics operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListIntentMetrics request to return the next page of results. For a complete set of results, call the ListIntentMetrics operation until the nextToken returned in the response is null.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_timeTime

The timestamp that marks the beginning of the range of time for which you want to see intent metrics.

Returns:

  • (Time)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10284

class ListIntentMetricsRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :metrics,
  :bin_by,
  :group_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end