Class: Aws::LexModelsV2::Types::ListRecommendedIntentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListRecommendedIntentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot associated with the recommended intent.
-
#bot_recommendation_id ⇒ String
The identifier of the bot recommendation that contains the recommended intent.
-
#bot_version ⇒ String
The version of the bot that contains the intent.
-
#locale_id ⇒ String
The identifier of the language and locale of the intents to list.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListRecommendedIntents operation.
-
#summary_list ⇒ Array<Types::RecommendedIntentSummary>
Summary information for the intents that meet the filter criteria specified in the request.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot associated with the recommended intent.
10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10776 class ListRecommendedIntentsResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id, :summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_recommendation_id ⇒ String
The identifier of the bot recommendation that contains the recommended intent.
10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10776 class ListRecommendedIntentsResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id, :summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the intent.
10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10776 class ListRecommendedIntentsResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id, :summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the intents to list. The string must match one of the supported locales. For more information, see Supported languages.
10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10776 class ListRecommendedIntentsResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id, :summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListRecommendedIntents operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListRecommendedIntents operation request to get the next page of results.
10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10776 class ListRecommendedIntentsResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id, :summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#summary_list ⇒ Array<Types::RecommendedIntentSummary>
Summary information for the intents that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more intents available, the nextToken field contains a token to get the next page of results.
10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10776 class ListRecommendedIntentsResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_id, :summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |