Class: Aws::LexModelsV2::Types::ListSessionAnalyticsDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier for the bot for which you want to retrieve session analytics.

Returns:

  • (String)


10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10729

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_timeTime

The date and time that marks the end of the range of time for which you want to see session analytics.

Returns:

  • (Time)


10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10729

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::AnalyticsSessionFilter>

A list of objects, each of which describes a condition by which you want to filter the results.

Returns:



10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10729

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned.

Returns:

  • (Integer)


10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10729

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response from the ListSessionAnalyticsData operation contains more results than specified in the maxResults parameter, a token is returned in the response.

Use the returned token in the nextToken parameter of a ListSessionAnalyticsData request to return the next page of results. For a complete set of results, call the ListSessionAnalyticsData operation until the nextToken returned in the response is null.

Returns:

  • (String)


10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10729

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byTypes::SessionDataSortBy

An object specifying the measure and method by which to sort the session analytics data.



10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10729

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_timeTime

The date and time that marks the beginning of the range of time for which you want to see session analytics.

Returns:

  • (Time)


10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10729

class ListSessionAnalyticsDataRequest < Struct.new(
  :bot_id,
  :start_date_time,
  :end_date_time,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end