Class: Aws::LexModelsV2::Types::ListSlotTypesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListSlotTypesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot that contains the slot types.
-
#bot_version ⇒ String
The version of the bot that contains the slot type.
-
#filters ⇒ Array<Types::SlotTypeFilter>
Provides the specification of a filter used to limit the slot types in the response to only those that match the filter specification.
-
#locale_id ⇒ String
The identifier of the language and locale of the slot types to list.
-
#max_results ⇒ Integer
The maximum number of slot types to return in each page of results.
-
#next_token ⇒ String
If the response from the
ListSlotTypesoperation contains more results than specified in themaxResultsparameter, a token is returned in the response. -
#sort_by ⇒ Types::SlotTypeSortBy
Determines the sort order for the response from the
ListSlotTypesoperation.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot that contains the slot types.
10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10924 class ListSlotTypesRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the slot type.
10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10924 class ListSlotTypesRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::SlotTypeFilter>
Provides the specification of a filter used to limit the slot types in the response to only those that match the filter specification. You can only specify one filter and only one string to filter on.
10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10924 class ListSlotTypesRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the slot types to list. The string must match one of the supported locales. For more information, see [Supported languages].
10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10924 class ListSlotTypesRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of slot types to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.
10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10924 class ListSlotTypesRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response from the ListSlotTypes operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.
10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10924 class ListSlotTypesRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ Types::SlotTypeSortBy
Determines the sort order for the response from the ListSlotTypes operation. You can choose to sort by the slot type name or last updated date in either ascending or descending order.
10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10924 class ListSlotTypesRequest < Struct.new( :bot_id, :bot_version, :locale_id, :sort_by, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |