Class: Aws::LexModelsV2::Types::ListSlotTypesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListSlotTypesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot that contains the slot types.
-
#bot_version ⇒ String
The version of the bot that contains the slot types.
-
#locale_id ⇒ String
The language and local of the slot types in the list.
-
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the
ListSlotTypesoperation. -
#slot_type_summaries ⇒ Array<Types::SlotTypeSummary>
Summary information for the slot types that meet the filter criteria specified in the request.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot that contains the slot types.
10710 10711 10712 10713 10714 10715 10716 10717 10718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10710 class ListSlotTypesResponse < Struct.new( :bot_id, :bot_version, :locale_id, :slot_type_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the slot types.
10710 10711 10712 10713 10714 10715 10716 10717 10718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10710 class ListSlotTypesResponse < Struct.new( :bot_id, :bot_version, :locale_id, :slot_type_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and local of the slot types in the list.
10710 10711 10712 10713 10714 10715 10716 10717 10718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10710 class ListSlotTypesResponse < Struct.new( :bot_id, :bot_version, :locale_id, :slot_type_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates whether there are more results to return in a response to the ListSlotTypes operation. If the nextToken field is present, you send the contents as the nextToken parameter of a ListSlotTypes operation request to get the next page of results.
10710 10711 10712 10713 10714 10715 10716 10717 10718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10710 class ListSlotTypesResponse < Struct.new( :bot_id, :bot_version, :locale_id, :slot_type_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#slot_type_summaries ⇒ Array<Types::SlotTypeSummary>
Summary information for the slot types that meet the filter criteria specified in the request. The length of the list is specified in the maxResults parameter of the request. If there are more slot types available, the nextToken field contains a token to get the next page of results.
10710 10711 10712 10713 10714 10715 10716 10717 10718 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 10710 class ListSlotTypesResponse < Struct.new( :bot_id, :bot_version, :locale_id, :slot_type_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |