Class: Aws::LexModelsV2::Types::ListSlotsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot that contains the slot.

Returns:

  • (String)


11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that contains the slot.

Returns:

  • (String)


11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::SlotFilter>

Provides the specification of a filter used to limit the slots in the response to only those that match the filter specification. You can only specify one filter and only one string to filter on.

Returns:



11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#intent_idString

The unique identifier of the intent that contains the slot.

Returns:

  • (String)


11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale of the slots to list. The string must match one of the supported locales. For more information, see [Supported languages].

[1]: docs.aws.amazon.com/lexv2/latest/dg/how-languages.html

Returns:

  • (String)


11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of slots to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned.

Returns:

  • (Integer)


11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response from the ListSlots operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.

Returns:

  • (String)


11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byTypes::SlotSortBy

Determines the sort order for the response from the ListSlots operation. You can choose to sort by the slot name or last updated date in either ascending or descending order.

Returns:



11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11024

class ListSlotsRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :intent_id,
  :sort_by,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end