Class: Aws::LexModelsV2::Types::ListTestExecutionResultItemsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::ListTestExecutionResultItemsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of test execution result items to return in each page.
-
#next_token ⇒ String
If the response from the
ListTestExecutionResultItemsoperation contains more results than specified in themaxResultsparameter, a token is returned in the response. -
#result_filter_by ⇒ Types::TestExecutionResultFilterBy
The filter for the list of results from the test set execution.
-
#test_execution_id ⇒ String
The unique identifier of the test execution to list the result items.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of test execution result items to return in each page. If there are fewer results than the max page size, only the actual number of results are returned.
11130 11131 11132 11133 11134 11135 11136 11137 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11130 class ListTestExecutionResultItemsRequest < Struct.new( :test_execution_id, :result_filter_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response from the ListTestExecutionResultItems operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results.
11130 11131 11132 11133 11134 11135 11136 11137 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11130 class ListTestExecutionResultItemsRequest < Struct.new( :test_execution_id, :result_filter_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#result_filter_by ⇒ Types::TestExecutionResultFilterBy
The filter for the list of results from the test set execution.
11130 11131 11132 11133 11134 11135 11136 11137 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11130 class ListTestExecutionResultItemsRequest < Struct.new( :test_execution_id, :result_filter_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_execution_id ⇒ String
The unique identifier of the test execution to list the result items.
11130 11131 11132 11133 11134 11135 11136 11137 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11130 class ListTestExecutionResultItemsRequest < Struct.new( :test_execution_id, :result_filter_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |