Class: Aws::LexModelsV2::Types::NluImprovementSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::NluImprovementSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Configures the Assisted Natural Language Understanding (NLU) feature for your bot. This specification determines whether enhanced intent recognition and utterance understanding capabilities are active.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assisted_nlu_mode ⇒ String
Specifies the mode for Assisted NLU operation.
-
#enabled ⇒ Boolean
Determines whether the Assisted NLU feature is enabled for the bot.
-
#intent_disambiguation_settings ⇒ Types::IntentDisambiguationSettings
An object containing specifications for the Intent Disambiguation feature within the Assisted NLU settings.
Instance Attribute Details
#assisted_nlu_mode ⇒ String
Specifies the mode for Assisted NLU operation. Use ‘Primary` to make Assisted NLU the primary intent recognition method, or `Fallback` to use it only when standard NLU confidence is low.
11715 11716 11717 11718 11719 11720 11721 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11715 class NluImprovementSpecification < Struct.new( :enabled, :assisted_nlu_mode, :intent_disambiguation_settings) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Determines whether the Assisted NLU feature is enabled for the bot. When set to ‘true`, Amazon Lex uses advanced models to improve intent recognition and slot resolution, with the default being `false`.
11715 11716 11717 11718 11719 11720 11721 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11715 class NluImprovementSpecification < Struct.new( :enabled, :assisted_nlu_mode, :intent_disambiguation_settings) SENSITIVE = [] include Aws::Structure end |
#intent_disambiguation_settings ⇒ Types::IntentDisambiguationSettings
An object containing specifications for the Intent Disambiguation feature within the Assisted NLU settings. These settings determine how the bot handles ambiguous user inputs that could match multiple intents.
11715 11716 11717 11718 11719 11720 11721 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11715 class NluImprovementSpecification < Struct.new( :enabled, :assisted_nlu_mode, :intent_disambiguation_settings) SENSITIVE = [] include Aws::Structure end |