Class: Aws::LexModelsV2::Types::PostDialogCodeHookInvocationSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::PostDialogCodeHookInvocationSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Specifies next steps to run after the dialog code hook finishes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the dialog code hook throws an exception or returns with the
Statefield of theIntentobject set toFailed. -
#failure_next_step ⇒ Types::DialogState
Specifies the next step the bot runs after the dialog code hook throws an exception or returns with the
Statefield of theIntentobject set toFailed. -
#failure_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
-
#success_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the dialog code hook finishes successfully.
-
#success_next_step ⇒ Types::DialogState
Specifics the next step the bot runs after the dialog code hook finishes successfully.
-
#success_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
-
#timeout_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate if the code hook times out.
-
#timeout_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the code hook times out.
-
#timeout_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
Instance Attribute Details
#failure_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the dialog code hook throws an exception or returns with the State field of the Intent object set to Failed.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#failure_next_step ⇒ Types::DialogState
Specifies the next step the bot runs after the dialog code hook throws an exception or returns with the State field of the Intent object set to Failed.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#failure_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#success_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the dialog code hook finishes successfully.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#success_next_step ⇒ Types::DialogState
Specifics the next step the bot runs after the dialog code hook finishes successfully.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#success_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#timeout_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate if the code hook times out.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#timeout_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the code hook times out.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |
#timeout_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 11876 class PostDialogCodeHookInvocationSpecification < Struct.new( :success_response, :success_next_step, :success_conditional, :failure_response, :failure_next_step, :failure_conditional, :timeout_response, :timeout_next_step, :timeout_conditional) SENSITIVE = [] include Aws::Structure end |