Method: Aws::LexModelsV2::Types::RuntimeHints#slot_hints
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
#slot_hints ⇒ Hash<String,Hash<String,Types::RuntimeHintDetails>>
A list of the slots in the intent that should have runtime hints added, and the phrases that should be added for each slot.
The first level of the slotHints map is the name of the intent. The second level is the name of the slot within the intent. For more information, see [Using hints to improve accuracy].
The intent name and slot name must exist.
12094 12095 12096 12097 12098 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12094 class RuntimeHints < Struct.new( :slot_hints) SENSITIVE = [] include Aws::Structure end |