Class: Aws::LexModelsV2::Types::RuntimeSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Contains specifications about the Amazon Lex runtime generative AI capabilities from Amazon Bedrock that you can turn on for your bot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nlu_improvementTypes::NluImprovementSpecification

An object containing specifications for the Assisted NLU feature within the bot’s runtime settings. These settings determine how the bot processes and interprets user utterances during conversations.



12449
12450
12451
12452
12453
12454
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12449

class RuntimeSettings < Struct.new(
  :slot_resolution_improvement,
  :nlu_improvement)
  SENSITIVE = []
  include Aws::Structure
end

#slot_resolution_improvementTypes::SlotResolutionImprovementSpecification

An object containing specifications for the assisted slot resolution feature.



12449
12450
12451
12452
12453
12454
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12449

class RuntimeSettings < Struct.new(
  :slot_resolution_improvement,
  :nlu_improvement)
  SENSITIVE = []
  include Aws::Structure
end