Class: Aws::LexModelsV2::Types::RuntimeSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::RuntimeSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Contains specifications about the Amazon Lex runtime generative AI capabilities from Amazon Bedrock that you can turn on for your bot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#nlu_improvement ⇒ Types::NluImprovementSpecification
An object containing specifications for the Assisted NLU feature within the bot’s runtime settings.
-
#slot_resolution_improvement ⇒ Types::SlotResolutionImprovementSpecification
An object containing specifications for the assisted slot resolution feature.
Instance Attribute Details
#nlu_improvement ⇒ Types::NluImprovementSpecification
An object containing specifications for the Assisted NLU feature within the bot’s runtime settings. These settings determine how the bot processes and interprets user utterances during conversations.
12371 12372 12373 12374 12375 12376 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12371 class RuntimeSettings < Struct.new( :slot_resolution_improvement, :nlu_improvement) SENSITIVE = [] include Aws::Structure end |
#slot_resolution_improvement ⇒ Types::SlotResolutionImprovementSpecification
An object containing specifications for the assisted slot resolution feature.
12371 12372 12373 12374 12375 12376 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12371 class RuntimeSettings < Struct.new( :slot_resolution_improvement, :nlu_improvement) SENSITIVE = [] include Aws::Structure end |