Class: Aws::LexModelsV2::Types::SessionSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::SessionSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
An object containing information about a specific session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_alias_id ⇒ String
The identifier of the alias of the bot that the session was held with.
-
#bot_version ⇒ String
The version of the bot that the session was held with.
-
#channel ⇒ String
The channel that is integrated with the bot that the session was held with.
-
#conversation_duration_seconds ⇒ Integer
The duration of the conversation in seconds.
-
#conversation_end_state ⇒ String
The final state of the conversation.
-
#conversation_end_time ⇒ Time
The date and time when the conversation ended.
-
#conversation_start_time ⇒ Time
The date and time when the conversation began.
-
#invoked_intent_samples ⇒ Array<Types::InvokedIntentSample>
A list of objects containing the name of an intent that was invoked.
-
#locale_id ⇒ String
The locale of the bot that the session was held with.
-
#mode ⇒ String
The mode of the session.
-
#number_of_turns ⇒ Integer
The number of turns that the session took.
-
#originating_request_id ⇒ String
The identifier of the first request in a session.
-
#session_id ⇒ String
The identifier of the session.
Instance Attribute Details
#bot_alias_id ⇒ String
The identifier of the alias of the bot that the session was held with.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that the session was held with.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#channel ⇒ String
The channel that is integrated with the bot that the session was held with.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#conversation_duration_seconds ⇒ Integer
The duration of the conversation in seconds. A conversation is defined as a unique combination of a ‘sessionId` and an `originatingRequestId`.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#conversation_end_state ⇒ String
The final state of the conversation. A conversation is defined as a unique combination of a ‘sessionId` and an `originatingRequestId`.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#conversation_end_time ⇒ Time
The date and time when the conversation ended. A conversation is defined as a unique combination of a ‘sessionId` and an `originatingRequestId`.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#conversation_start_time ⇒ Time
The date and time when the conversation began. A conversation is defined as a unique combination of a ‘sessionId` and an `originatingRequestId`.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#invoked_intent_samples ⇒ Array<Types::InvokedIntentSample>
A list of objects containing the name of an intent that was invoked.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The locale of the bot that the session was held with.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The mode of the session. The possible values are as follows:
-
‘Speech` – The session was spoken.
-
‘Text` – The session was written.
-
‘DTMF` – The session used a touch-tone keypad (Dual Tone Multi-Frequency).
-
‘MultiMode` – The session used multiple modes.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#number_of_turns ⇒ Integer
The number of turns that the session took.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#originating_request_id ⇒ String
The identifier of the first request in a session.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The identifier of the session.
12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12843 class SessionSpecification < Struct.new( :bot_alias_id, :bot_version, :locale_id, :channel, :session_id, :conversation_start_time, :conversation_end_time, :conversation_duration_seconds, :conversation_end_state, :mode, :number_of_turns, :invoked_intent_samples, :originating_request_id) SENSITIVE = [] include Aws::Structure end |