Class: Aws::LexModelsV2::Types::SlotCaptureSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::SlotCaptureSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Settings used when Amazon Lex successfully captures a slot value from a user.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capture_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the slot value is captured.
-
#capture_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the slot value is captured before the code hook times out.
-
#capture_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
-
#code_hook ⇒ Types::DialogCodeHookInvocationSetting
Code hook called after Amazon Lex successfully captures a slot value.
-
#elicitation_code_hook ⇒ Types::ElicitationCodeHookInvocationSetting
Code hook called when Amazon Lex doesn’t capture a slot value.
-
#failure_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate when the slot value isn’t captured.
-
#failure_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the slot value code is not recognized.
-
#failure_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
Instance Attribute Details
#capture_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate after the slot value is captured.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |
#capture_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the slot value is captured before the code hook times out.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |
#capture_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |
#code_hook ⇒ Types::DialogCodeHookInvocationSetting
Code hook called after Amazon Lex successfully captures a slot value.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |
#elicitation_code_hook ⇒ Types::ElicitationCodeHookInvocationSetting
Code hook called when Amazon Lex doesn’t capture a slot value.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |
#failure_conditional ⇒ Types::ConditionalSpecification
A list of conditional branches to evaluate when the slot value isn’t captured.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |
#failure_next_step ⇒ Types::DialogState
Specifies the next step that the bot runs when the slot value code is not recognized.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |
#failure_response ⇒ Types::ResponseSpecification
Specifies a list of message groups that Amazon Lex uses to respond the user input.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 12827 class SlotCaptureSetting < Struct.new( :capture_response, :capture_next_step, :capture_conditional, :failure_response, :failure_next_step, :failure_conditional, :code_hook, :elicitation_code_hook) SENSITIVE = [] include Aws::Structure end |