Class: Aws::LexModelsV2::Types::SlotValueElicitationSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::SlotValueElicitationSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Specifies the elicitation setting details eliciting a slot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_value_specification ⇒ Types::SlotDefaultValueSpecification
A list of default values for a slot.
-
#prompt_specification ⇒ Types::PromptSpecification
The prompt that Amazon Lex uses to elicit the slot value from the user.
-
#sample_utterances ⇒ Array<Types::SampleUtterance>
If you know a specific pattern that users might respond to an Amazon Lex request for a slot value, you can provide those utterances to improve accuracy.
-
#slot_capture_setting ⇒ Types::SlotCaptureSetting
Specifies the settings that Amazon Lex uses when a slot value is successfully entered by a user.
-
#slot_constraint ⇒ String
Specifies whether the slot is required or optional.
-
#slot_resolution_setting ⇒ Types::SlotResolutionSetting
An object containing information about whether assisted slot resolution is turned on for the slot or not.
-
#wait_and_continue_specification ⇒ Types::WaitAndContinueSpecification
Specifies the prompts that Amazon Lex uses while a bot is waiting for customer input.
Instance Attribute Details
#default_value_specification ⇒ Types::SlotDefaultValueSpecification
A list of default values for a slot. Default values are used when Amazon Lex hasn’t determined a value for a slot. You can specify default values from context variables, session attributes, and defined values.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13348 class SlotValueElicitationSetting < Struct.new( :default_value_specification, :slot_constraint, :prompt_specification, :sample_utterances, :wait_and_continue_specification, :slot_capture_setting, :slot_resolution_setting) SENSITIVE = [] include Aws::Structure end |
#prompt_specification ⇒ Types::PromptSpecification
The prompt that Amazon Lex uses to elicit the slot value from the user.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13348 class SlotValueElicitationSetting < Struct.new( :default_value_specification, :slot_constraint, :prompt_specification, :sample_utterances, :wait_and_continue_specification, :slot_capture_setting, :slot_resolution_setting) SENSITIVE = [] include Aws::Structure end |
#sample_utterances ⇒ Array<Types::SampleUtterance>
If you know a specific pattern that users might respond to an Amazon Lex request for a slot value, you can provide those utterances to improve accuracy. This is optional. In most cases, Amazon Lex is capable of understanding user utterances.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13348 class SlotValueElicitationSetting < Struct.new( :default_value_specification, :slot_constraint, :prompt_specification, :sample_utterances, :wait_and_continue_specification, :slot_capture_setting, :slot_resolution_setting) SENSITIVE = [] include Aws::Structure end |
#slot_capture_setting ⇒ Types::SlotCaptureSetting
Specifies the settings that Amazon Lex uses when a slot value is successfully entered by a user.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13348 class SlotValueElicitationSetting < Struct.new( :default_value_specification, :slot_constraint, :prompt_specification, :sample_utterances, :wait_and_continue_specification, :slot_capture_setting, :slot_resolution_setting) SENSITIVE = [] include Aws::Structure end |
#slot_constraint ⇒ String
Specifies whether the slot is required or optional.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13348 class SlotValueElicitationSetting < Struct.new( :default_value_specification, :slot_constraint, :prompt_specification, :sample_utterances, :wait_and_continue_specification, :slot_capture_setting, :slot_resolution_setting) SENSITIVE = [] include Aws::Structure end |
#slot_resolution_setting ⇒ Types::SlotResolutionSetting
An object containing information about whether assisted slot resolution is turned on for the slot or not.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13348 class SlotValueElicitationSetting < Struct.new( :default_value_specification, :slot_constraint, :prompt_specification, :sample_utterances, :wait_and_continue_specification, :slot_capture_setting, :slot_resolution_setting) SENSITIVE = [] include Aws::Structure end |
#wait_and_continue_specification ⇒ Types::WaitAndContinueSpecification
Specifies the prompts that Amazon Lex uses while a bot is waiting for customer input.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13348 class SlotValueElicitationSetting < Struct.new( :default_value_specification, :slot_constraint, :prompt_specification, :sample_utterances, :wait_and_continue_specification, :slot_capture_setting, :slot_resolution_setting) SENSITIVE = [] include Aws::Structure end |