Class: Aws::LexModelsV2::Types::StartBotAnalyzerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::StartBotAnalyzerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_scope ⇒ String
The scope of analysis to perform.
-
#bot_id ⇒ String
The unique identifier of the bot to analyze.
-
#bot_version ⇒ String
The version of the bot to analyze.
-
#locale_id ⇒ String
The locale identifier for the bot locale to analyze.
Instance Attribute Details
#analysis_scope ⇒ String
The scope of analysis to perform. Currently only ‘BotLocale` scope is supported.
Valid Values: ‘BotLocale`
13560 13561 13562 13563 13564 13565 13566 13567 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13560 class StartBotAnalyzerRequest < Struct.new( :bot_id, :analysis_scope, :locale_id, :bot_version) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The unique identifier of the bot to analyze.
13560 13561 13562 13563 13564 13565 13566 13567 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13560 class StartBotAnalyzerRequest < Struct.new( :bot_id, :analysis_scope, :locale_id, :bot_version) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot to analyze. Defaults to ‘DRAFT` if not specified.
13560 13561 13562 13563 13564 13565 13566 13567 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13560 class StartBotAnalyzerRequest < Struct.new( :bot_id, :analysis_scope, :locale_id, :bot_version) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The locale identifier for the bot locale to analyze. Required when ‘analysisScope` is `BotLocale`.
13560 13561 13562 13563 13564 13565 13566 13567 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13560 class StartBotAnalyzerRequest < Struct.new( :bot_id, :analysis_scope, :locale_id, :bot_version) SENSITIVE = [] include Aws::Structure end |