Class: Aws::LexModelsV2::Types::StartBotAnalyzerResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_analyzer_request_idString

A unique identifier for this analysis request. Use this identifier to check the status and retrieve results.

Returns:

  • (String)


13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13599

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_analyzer_statusString

The current status of the analysis. The initial status is ‘Processing`.

Valid Values: ‘Processing | Available | Failed | Stopping | Stopped`

Returns:

  • (String)


13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13599

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The unique identifier of the bot being analyzed.

Returns:

  • (String)


13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13599

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot being analyzed.

Returns:

  • (String)


13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13599

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the analysis was initiated.

Returns:

  • (Time)


13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13599

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The locale identifier of the bot locale being analyzed.

Returns:

  • (String)


13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13599

class StartBotAnalyzerResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_analyzer_status,
  :bot_analyzer_request_id,
  :creation_date_time)
  SENSITIVE = []
  include Aws::Structure
end