Class: Aws::LexModelsV2::Types::StartBotRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::StartBotRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot containing the bot recommendation.
-
#bot_version ⇒ String
The version of the bot containing the bot recommendation.
-
#encryption_setting ⇒ Types::EncryptionSetting
The object representing the passwords that will be used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.
-
#locale_id ⇒ String
The identifier of the language and locale of the bot recommendation to start.
-
#transcript_source_setting ⇒ Types::TranscriptSourceSetting
The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot containing the bot recommendation.
13563 13564 13565 13566 13567 13568 13569 13570 13571 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13563 class StartBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot containing the bot recommendation.
13563 13564 13565 13566 13567 13568 13569 13570 13571 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13563 class StartBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#encryption_setting ⇒ Types::EncryptionSetting
The object representing the passwords that will be used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.
13563 13564 13565 13566 13567 13568 13569 13570 13571 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13563 class StartBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the bot recommendation to start. The string must match one of the supported locales. For more information, see [Supported languages]
13563 13564 13565 13566 13567 13568 13569 13570 13571 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13563 class StartBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#transcript_source_setting ⇒ Types::TranscriptSourceSetting
The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.
13563 13564 13565 13566 13567 13568 13569 13570 13571 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13563 class StartBotRecommendationRequest < Struct.new( :bot_id, :bot_version, :locale_id, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |