Class: Aws::LexModelsV2::Types::StartBotRecommendationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The unique identifier of the bot containing the bot recommendation.

Returns:

  • (String)


13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_idString

The identifier of the bot recommendation that you have created.

Returns:

  • (String)


13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_recommendation_statusString

The status of the bot recommendation.

If the status is Failed, then the reasons for the failure are listed in the failureReasons field.

Returns:

  • (String)


13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot containing the bot recommendation.

Returns:

  • (String)


13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

A timestamp of the date and time that the bot recommendation was created.

Returns:

  • (Time)


13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_settingTypes::EncryptionSetting

The object representing the passwords that were used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.



13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale of the bot recommendation to start. The string must match one of the supported locales. For more information, see [Supported languages]

[1]: docs.aws.amazon.com/lexv2/latest/dg/how-languages.html

Returns:

  • (String)


13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_source_settingTypes::TranscriptSourceSetting

The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.



13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13698

class StartBotRecommendationResponse < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :bot_recommendation_status,
  :bot_recommendation_id,
  :creation_date_time,
  :transcript_source_setting,
  :encryption_setting)
  SENSITIVE = []
  include Aws::Structure
end