Class: Aws::LexModelsV2::Types::StartBotResourceGenerationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::StartBotResourceGenerationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot for which to generate intents and slot types.
-
#bot_version ⇒ String
The version of the bot for which to generate intents and slot types.
-
#generation_input_prompt ⇒ String
The prompt to generate intents and slot types for the bot locale.
-
#locale_id ⇒ String
The locale of the bot for which to generate intents and slot types.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot for which to generate intents and slot types.
13777 13778 13779 13780 13781 13782 13783 13784 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13777 class StartBotResourceGenerationRequest < Struct.new( :generation_input_prompt, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot for which to generate intents and slot types.
13777 13778 13779 13780 13781 13782 13783 13784 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13777 class StartBotResourceGenerationRequest < Struct.new( :generation_input_prompt, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#generation_input_prompt ⇒ String
The prompt to generate intents and slot types for the bot locale. Your description should be both detailed and precise to help generate appropriate and sufficient intents for your bot. Include a list of actions to improve the intent creation process.
13777 13778 13779 13780 13781 13782 13783 13784 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13777 class StartBotResourceGenerationRequest < Struct.new( :generation_input_prompt, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The locale of the bot for which to generate intents and slot types.
13777 13778 13779 13780 13781 13782 13783 13784 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13777 class StartBotResourceGenerationRequest < Struct.new( :generation_input_prompt, :bot_id, :bot_version, :locale_id) SENSITIVE = [] include Aws::Structure end |