Class: Aws::LexModelsV2::Types::StartImportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::StartImportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The date and time that the import request was created.
-
#import_id ⇒ String
A unique identifier for the import.
-
#import_status ⇒ String
The current status of the import.
-
#merge_strategy ⇒ String
The strategy used when there was a name conflict between the imported resource and an existing resource.
-
#resource_specification ⇒ Types::ImportResourceSpecification
The parameters used when importing the resource.
Instance Attribute Details
#creation_date_time ⇒ Time
The date and time that the import request was created.
13443 13444 13445 13446 13447 13448 13449 13450 13451 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13443 class StartImportResponse < Struct.new( :import_id, :resource_specification, :merge_strategy, :import_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
A unique identifier for the import.
13443 13444 13445 13446 13447 13448 13449 13450 13451 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13443 class StartImportResponse < Struct.new( :import_id, :resource_specification, :merge_strategy, :import_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
The current status of the import. When the status is Complete the bot, bot alias, or custom vocabulary is ready to use.
13443 13444 13445 13446 13447 13448 13449 13450 13451 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13443 class StartImportResponse < Struct.new( :import_id, :resource_specification, :merge_strategy, :import_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#merge_strategy ⇒ String
The strategy used when there was a name conflict between the imported resource and an existing resource. When the merge strategy is FailOnConflict existing resources are not overwritten and the import fails.
13443 13444 13445 13446 13447 13448 13449 13450 13451 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13443 class StartImportResponse < Struct.new( :import_id, :resource_specification, :merge_strategy, :import_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#resource_specification ⇒ Types::ImportResourceSpecification
The parameters used when importing the resource.
13443 13444 13445 13446 13447 13448 13449 13450 13451 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 13443 class StartImportResponse < Struct.new( :import_id, :resource_specification, :merge_strategy, :import_status, :creation_date_time) SENSITIVE = [] include Aws::Structure end |