Class: Aws::LexModelsV2::Types::StartTestSetGenerationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::StartTestSetGenerationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The creation date and time for the test set generation.
-
#description ⇒ String
The description used for the test set generation.
-
#generation_data_source ⇒ Types::TestSetGenerationDataSource
The data source for the test set generation.
-
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
-
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the test set generation.
-
#test_set_generation_id ⇒ String
The unique identifier of the test set generation to describe.
-
#test_set_generation_status ⇒ String
The status for the test set generation.
-
#test_set_name ⇒ String
The test set name used for the test set generation.
-
#test_set_tags ⇒ Hash<String,String>
A list of tags that was used for the test set that is being generated.
Instance Attribute Details
#creation_date_time ⇒ Time
The creation date and time for the test set generation.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description used for the test set generation.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#generation_data_source ⇒ Types::TestSetGenerationDataSource
The data source for the test set generation.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the test set generation.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#test_set_generation_id ⇒ String
The unique identifier of the test set generation to describe.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#test_set_generation_status ⇒ String
The status for the test set generation.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#test_set_name ⇒ String
The test set name used for the test set generation.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |
#test_set_tags ⇒ Hash<String,String>
A list of tags that was used for the test set that is being generated.
14010 14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14010 class StartTestSetGenerationResponse < Struct.new( :test_set_generation_id, :creation_date_time, :test_set_generation_status, :test_set_name, :description, :storage_location, :generation_data_source, :role_arn, :test_set_tags) SENSITIVE = [] include Aws::Structure end |