Class: Aws::LexModelsV2::Types::StopBotRecommendationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::StopBotRecommendationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot containing the bot recommendation that is being stopped.
-
#bot_recommendation_id ⇒ String
The unique identifier of the bot recommendation that is being stopped.
-
#bot_recommendation_status ⇒ String
The status of the bot recommendation.
-
#bot_version ⇒ String
The version of the bot containing the recommendation that is being stopped.
-
#locale_id ⇒ String
The identifier of the language and locale of the bot response to stop.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot containing the bot recommendation that is being stopped.
14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14176 class StopBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |
#bot_recommendation_id ⇒ String
The unique identifier of the bot recommendation that is being stopped.
14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14176 class StopBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |
#bot_recommendation_status ⇒ String
The status of the bot recommendation. If the status is Failed, then the reasons for the failure are listed in the failureReasons field.
14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14176 class StopBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot containing the recommendation that is being stopped.
14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14176 class StopBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the bot response to stop. The string must match one of the supported locales. For more information, see [Supported languages]
14176 14177 14178 14179 14180 14181 14182 14183 14184 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 14176 class StopBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id) SENSITIVE = [] include Aws::Structure end |