Class: Aws::LexModelsV2::Types::UpdateBotAliasResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_alias_idString

The identifier of the updated bot alias.

Returns:

  • (String)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_locale_settingsHash<String,Types::BotAliasLocaleSettings>

The updated Lambda functions to use in each locale for the bot alias.

Returns:



15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_nameString

The updated name of the bot alias.

Returns:

  • (String)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_statusString

The current status of the bot alias. When the status is ‘Available` the alias is ready for use.

Returns:

  • (String)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_idString

The identifier of the bot with the updated alias.

Returns:

  • (String)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The updated version of the bot that the alias points to.

Returns:

  • (String)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_log_settingsTypes::ConversationLogSettings

The updated settings for storing conversation logs in Amazon CloudWatch Logs and Amazon S3 buckets.



15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

A timestamp of the date and time that the bot was created.

Returns:

  • (Time)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The updated description of the bot alias.

Returns:

  • (String)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

A timestamp of the date and time that the bot was last updated.

Returns:

  • (Time)


15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#sentiment_analysis_settingsTypes::SentimentAnalysisSettings

Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.



15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15094

class UpdateBotAliasResponse < Struct.new(
  :bot_alias_id,
  :bot_alias_name,
  :description,
  :bot_version,
  :bot_alias_locale_settings,
  :conversation_log_settings,
  :sentiment_analysis_settings,
  :bot_alias_status,
  :bot_id,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end