Class: Aws::LexModelsV2::Types::UpdateBotLocaleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The unique identifier of the bot that contains the locale.

Returns:

  • (String)


15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that contains the locale to be updated. The version can only be the DRAFT version.

Returns:

  • (String)


15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The new description of the locale.

Returns:

  • (String)


15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#generative_ai_settingsTypes::GenerativeAISettings

Contains settings for generative AI features powered by Amazon Bedrock for your bot locale. Use this object to turn generative AI features on and off. Pricing may differ if you turn a feature on. For more information, see LINK.



15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The identifier of the language and locale to update. The string must match one of the supported locales. For more information, see [Supported languages].

[1]: docs.aws.amazon.com/lexv2/latest/dg/how-languages.html

Returns:

  • (String)


15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#nlu_intent_confidence_thresholdFloat

The new confidence threshold where Amazon Lex inserts the AMAZON.FallbackIntent and AMAZON.KendraSearchIntent intents in the list of possible intents for an utterance.

Returns:

  • (Float)


15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#speech_detection_sensitivityString

The new sensitivity level for voice activity detection (VAD) in the bot locale. This setting helps optimize speech recognition accuracy by adjusting how the system responds to background noise during voice interactions.

Returns:

  • (String)


15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#speech_recognition_settingsTypes::SpeechRecognitionSettings

Updated speech-to-text settings to apply to the bot locale.



15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#unified_speech_settingsTypes::UnifiedSpeechSettings

Updated unified speech settings to apply to the bot locale.



15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end

#voice_settingsTypes::VoiceSettings

The new Amazon Polly voice Amazon Lex should use for voice interaction with the user.



15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15090

class UpdateBotLocaleRequest < Struct.new(
  :bot_id,
  :bot_version,
  :locale_id,
  :description,
  :nlu_intent_confidence_threshold,
  :voice_settings,
  :unified_speech_settings,
  :speech_recognition_settings,
  :generative_ai_settings,
  :speech_detection_sensitivity)
  SENSITIVE = []
  include Aws::Structure
end