Class: Aws::LexModelsV2::Types::UpdateBotLocaleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateBotLocaleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_filler_settings ⇒ Types::AudioFillerSettings
The updated audio filler settings for the bot locale.
-
#bot_id ⇒ String
The identifier of the bot that contains the updated locale.
-
#bot_locale_status ⇒ String
The current status of the locale.
-
#bot_version ⇒ String
The version of the bot that contains the updated locale.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the locale was created.
-
#description ⇒ String
The updated description of the locale.
-
#failure_reasons ⇒ Array<String>
If the ‘botLocaleStatus` is `Failed`, the `failureReasons` field lists the errors that occurred while building the bot.
-
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains settings for generative AI features powered by Amazon Bedrock for your bot locale.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the locale was last updated.
-
#locale_id ⇒ String
The language and locale of the updated bot locale.
-
#locale_name ⇒ String
The updated locale name for the locale.
-
#nlu_intent_confidence_threshold ⇒ Float
The updated confidence threshold for inserting the ‘AMAZON.FallbackIntent` and `AMAZON.KendraSearchIntent` intents in the list of possible intents for an utterance.
-
#recommended_actions ⇒ Array<String>
Recommended actions to take to resolve an error in the ‘failureReasons` field.
-
#speech_detection_sensitivity ⇒ String
The updated sensitivity level for voice activity detection (VAD) in the bot locale.
-
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The updated speech-to-text settings for the bot locale.
-
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The updated unified speech settings for the bot locale.
-
#voice_settings ⇒ Types::VoiceSettings
The updated Amazon Polly voice to use for voice interaction with the user.
Instance Attribute Details
#audio_filler_settings ⇒ Types::AudioFillerSettings
The updated audio filler settings for the bot locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_id ⇒ String
The identifier of the bot that contains the updated locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_locale_status ⇒ String
The current status of the locale. When the bot status is ‘Built` the locale is ready for use.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the updated locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the locale was created.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description of the locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#failure_reasons ⇒ Array<String>
If the ‘botLocaleStatus` is `Failed`, the `failureReasons` field lists the errors that occurred while building the bot.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#generative_ai_settings ⇒ Types::GenerativeAISettings
Contains settings for generative AI features powered by Amazon Bedrock for your bot locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the locale was last updated.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The language and locale of the updated bot locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#locale_name ⇒ String
The updated locale name for the locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#nlu_intent_confidence_threshold ⇒ Float
The updated confidence threshold for inserting the ‘AMAZON.FallbackIntent` and `AMAZON.KendraSearchIntent` intents in the list of possible intents for an utterance.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#recommended_actions ⇒ Array<String>
Recommended actions to take to resolve an error in the ‘failureReasons` field.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#speech_detection_sensitivity ⇒ String
The updated sensitivity level for voice activity detection (VAD) in the bot locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#speech_recognition_settings ⇒ Types::SpeechRecognitionSettings
The updated speech-to-text settings for the bot locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#unified_speech_settings ⇒ Types::UnifiedSpeechSettings
The updated unified speech settings for the bot locale.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#voice_settings ⇒ Types::VoiceSettings
The updated Amazon Polly voice to use for voice interaction with the user.
15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15268 class UpdateBotLocaleResponse < Struct.new( :bot_id, :bot_version, :locale_id, :locale_name, :description, :nlu_intent_confidence_threshold, :voice_settings, :unified_speech_settings, :audio_filler_settings, :speech_recognition_settings, :bot_locale_status, :failure_reasons, :creation_date_time, :last_updated_date_time, :recommended_actions, :generative_ai_settings, :speech_detection_sensitivity) SENSITIVE = [] include Aws::Structure end |