Class: Aws::LexModelsV2::Types::UpdateBotRecommendationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateBotRecommendationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot containing the bot recommendation that has been updated.
-
#bot_recommendation_id ⇒ String
The unique identifier of the bot recommendation to be updated.
-
#bot_recommendation_status ⇒ String
The status of the bot recommendation.
-
#bot_version ⇒ String
The version of the bot containing the bot recommendation that has been updated.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was created.
-
#encryption_setting ⇒ Types::EncryptionSetting
The object representing the passwords that were used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was last updated.
-
#locale_id ⇒ String
The identifier of the language and locale of the bot recommendation to update.
-
#transcript_source_setting ⇒ Types::TranscriptSourceSetting
The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot containing the bot recommendation that has been updated.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#bot_recommendation_id ⇒ String
The unique identifier of the bot recommendation to be updated.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#bot_recommendation_status ⇒ String
The status of the bot recommendation.
If the status is Failed, then the reasons for the failure are listed in the failureReasons field.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot containing the bot recommendation that has been updated.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was created.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#encryption_setting ⇒ Types::EncryptionSetting
The object representing the passwords that were used to encrypt the data related to the bot recommendation results, as well as the KMS key ARN used to encrypt the associated metadata.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot recommendation was last updated.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale of the bot recommendation to update. The string must match one of the supported locales. For more information, see [Supported languages]
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |
#transcript_source_setting ⇒ Types::TranscriptSourceSetting
The object representing the Amazon S3 bucket containing the transcript, as well as the associated metadata.
15296 15297 15298 15299 15300 15301 15302 15303 15304 15305 15306 15307 15308 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15296 class UpdateBotRecommendationResponse < Struct.new( :bot_id, :bot_version, :locale_id, :bot_recommendation_status, :bot_recommendation_id, :creation_date_time, :last_updated_date_time, :transcript_source_setting, :encryption_setting) SENSITIVE = [] include Aws::Structure end |