Class: Aws::LexModelsV2::Types::UpdateBotResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateBotResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot that was updated.
-
#bot_members ⇒ Array<Types::BotMember>
The list of bot members in the network that was updated.
-
#bot_name ⇒ String
The name of the bot after the update.
-
#bot_status ⇒ String
Shows the current status of the bot.
-
#bot_type ⇒ String
The type of the bot that was updated.
-
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot was created.
-
#data_privacy ⇒ Types::DataPrivacy
The data privacy settings for the bot after the update.
-
#description ⇒ String
The description of the bot after the update.
-
#error_log_settings ⇒ Types::ErrorLogSettings
Settings for managing error logs within the response of an update bot operation.
-
#idle_session_ttl_in_seconds ⇒ Integer
The session timeout, in seconds, for the bot after the update.
-
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot was last updated.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the bot after the update.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot that was updated.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#bot_members ⇒ Array<Types::BotMember>
The list of bot members in the network that was updated.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#bot_name ⇒ String
The name of the bot after the update.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#bot_status ⇒ String
Shows the current status of the bot. The bot is first in the Creating status. Once the bot is read for use, it changes to the Available status. After the bot is created, you can use the DRAFT version of the bot.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#bot_type ⇒ String
The type of the bot that was updated.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of the date and time that the bot was created.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#data_privacy ⇒ Types::DataPrivacy
The data privacy settings for the bot after the update.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the bot after the update.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#error_log_settings ⇒ Types::ErrorLogSettings
Settings for managing error logs within the response of an update bot operation.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#idle_session_ttl_in_seconds ⇒ Integer
The session timeout, in seconds, for the bot after the update.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the date and time that the bot was last updated.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the bot after the update.
15435 15436 15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15435 class UpdateBotResponse < Struct.new( :bot_id, :bot_name, :description, :role_arn, :data_privacy, :idle_session_ttl_in_seconds, :bot_status, :creation_date_time, :last_updated_date_time, :bot_type, :bot_members, :error_log_settings) SENSITIVE = [] include Aws::Structure end |