Class: Aws::LexModelsV2::Types::UpdateIntentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateIntentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot that contains the intent.
-
#bot_version ⇒ String
The version of the bot that contains the intent.
-
#description ⇒ String
The new description of the intent.
-
#dialog_code_hook ⇒ Types::DialogCodeHookSettings
The new Lambda function to use between each turn of the conversation with the bot.
-
#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings
The new Lambda function to call when all of the intents required slots are provided and the intent is ready for fulfillment.
-
#initial_response_setting ⇒ Types::InitialResponseSetting
Configuration settings for a response sent to the user before Amazon Lex starts eliciting slots.
-
#input_contexts ⇒ Array<Types::InputContext>
A new list of contexts that must be active in order for Amazon Lex to consider the intent.
-
#intent_closing_setting ⇒ Types::IntentClosingSetting
The new response that Amazon Lex sends the user when the intent is closed.
-
#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting
New prompts that Amazon Lex sends to the user to confirm the completion of an intent.
-
#intent_display_name ⇒ String
The new display name for the intent.
-
#intent_id ⇒ String
The unique identifier of the intent to update.
-
#intent_name ⇒ String
The new name for the intent.
-
#kendra_configuration ⇒ Types::KendraConfiguration
New configuration settings for connecting to an Amazon Kendra index.
-
#locale_id ⇒ String
The identifier of the language and locale where this intent is used.
-
#output_contexts ⇒ Array<Types::OutputContext>
A new list of contexts that Amazon Lex activates when the intent is fulfilled.
-
#parent_intent_signature ⇒ String
The signature of the new built-in intent to use as the parent of this intent.
-
#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration
Qinconnect intent configuration details for the update intent request.
-
#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration
Specifies the configuration of the built-in
Amazon.QnAIntent. -
#sample_utterances ⇒ Array<Types::SampleUtterance>
New utterances used to invoke the intent.
-
#slot_priorities ⇒ Array<Types::SlotPriority>
A new list of slots and their priorities that are contained by the intent.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot that contains the intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the intent. Must be DRAFT.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description of the intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#dialog_code_hook ⇒ Types::DialogCodeHookSettings
The new Lambda function to use between each turn of the conversation with the bot.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings
The new Lambda function to call when all of the intents required slots are provided and the intent is ready for fulfillment.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#initial_response_setting ⇒ Types::InitialResponseSetting
Configuration settings for a response sent to the user before Amazon Lex starts eliciting slots.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#input_contexts ⇒ Array<Types::InputContext>
A new list of contexts that must be active in order for Amazon Lex to consider the intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_closing_setting ⇒ Types::IntentClosingSetting
The new response that Amazon Lex sends the user when the intent is closed.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting
New prompts that Amazon Lex sends to the user to confirm the completion of an intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_display_name ⇒ String
The new display name for the intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The unique identifier of the intent to update.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_name ⇒ String
The new name for the intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#kendra_configuration ⇒ Types::KendraConfiguration
New configuration settings for connecting to an Amazon Kendra index.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale where this intent is used. The string must match one of the supported locales. For more information, see [Supported languages].
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#output_contexts ⇒ Array<Types::OutputContext>
A new list of contexts that Amazon Lex activates when the intent is fulfilled.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#parent_intent_signature ⇒ String
The signature of the new built-in intent to use as the parent of this intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration
Qinconnect intent configuration details for the update intent request.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration
Specifies the configuration of the built-in Amazon.QnAIntent. The AMAZON.QnAIntent intent is called when Amazon Lex can’t determine another intent to invoke. If you specify this field, you can’t specify the kendraConfiguration field.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#sample_utterances ⇒ Array<Types::SampleUtterance>
New utterances used to invoke the intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#slot_priorities ⇒ Array<Types::SlotPriority>
A new list of slots and their priorities that are contained by the intent.
15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 15623 15624 15625 15626 15627 15628 15629 15630 15631 15632 15633 15634 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15611 class UpdateIntentRequest < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |