Class: Aws::LexModelsV2::Types::UpdateIntentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateIntentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot that contains the intent.
-
#bot_version ⇒ String
The version of the bot that contains the intent.
-
#creation_date_time ⇒ Time
A timestamp of when the intent was created.
-
#description ⇒ String
The updated description of the intent.
-
#dialog_code_hook ⇒ Types::DialogCodeHookSettings
The updated Lambda function called during each turn of the conversation with the user.
-
#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings
The updated Lambda function called when the intent is ready for fulfillment.
-
#initial_response_setting ⇒ Types::InitialResponseSetting
Configuration settings for a response sent to the user before Amazon Lex starts eliciting slots.
-
#input_contexts ⇒ Array<Types::InputContext>
The updated list of contexts that must be active for the intent to be considered by Amazon Lex.
-
#intent_closing_setting ⇒ Types::IntentClosingSetting
The updated response that Amazon Lex sends the user when the intent is closed.
-
#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting
The updated prompts that Amazon Lex sends to the user to confirm the completion of an intent.
-
#intent_display_name ⇒ String
The updated display name of the intent.
-
#intent_id ⇒ String
The identifier of the intent that was updated.
-
#intent_name ⇒ String
The updated name of the intent.
-
#kendra_configuration ⇒ Types::KendraConfiguration
The updated configuration for connecting to an Amazon Kendra index with the
AMAZON.KendraSearchIntentintent. -
#last_updated_date_time ⇒ Time
A timestamp of the last time that the intent was modified.
-
#locale_id ⇒ String
The updated language and locale of the intent.
-
#output_contexts ⇒ Array<Types::OutputContext>
The updated list of contexts that Amazon Lex activates when the intent is fulfilled.
-
#parent_intent_signature ⇒ String
The updated built-in intent that is the parent of this intent.
-
#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration
Qinconnect intent configuration details for the update intent response.
-
#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration
Details about the configuration of the built-in
Amazon.QnAIntent. -
#sample_utterances ⇒ Array<Types::SampleUtterance>
The updated list of sample utterances for the intent.
-
#slot_priorities ⇒ Array<Types::SlotPriority>
The updated list of slots and their priorities that are elicited from the user for the intent.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot that contains the intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the intent. Will always be DRAFT.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
A timestamp of when the intent was created.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description of the intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#dialog_code_hook ⇒ Types::DialogCodeHookSettings
The updated Lambda function called during each turn of the conversation with the user.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#fulfillment_code_hook ⇒ Types::FulfillmentCodeHookSettings
The updated Lambda function called when the intent is ready for fulfillment.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#initial_response_setting ⇒ Types::InitialResponseSetting
Configuration settings for a response sent to the user before Amazon Lex starts eliciting slots.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#input_contexts ⇒ Array<Types::InputContext>
The updated list of contexts that must be active for the intent to be considered by Amazon Lex.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_closing_setting ⇒ Types::IntentClosingSetting
The updated response that Amazon Lex sends the user when the intent is closed.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_confirmation_setting ⇒ Types::IntentConfirmationSetting
The updated prompts that Amazon Lex sends to the user to confirm the completion of an intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_display_name ⇒ String
The updated display name of the intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The identifier of the intent that was updated.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#intent_name ⇒ String
The updated name of the intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#kendra_configuration ⇒ Types::KendraConfiguration
The updated configuration for connecting to an Amazon Kendra index with the AMAZON.KendraSearchIntent intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
A timestamp of the last time that the intent was modified.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The updated language and locale of the intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#output_contexts ⇒ Array<Types::OutputContext>
The updated list of contexts that Amazon Lex activates when the intent is fulfilled.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#parent_intent_signature ⇒ String
The updated built-in intent that is the parent of this intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#q_in_connect_intent_configuration ⇒ Types::QInConnectIntentConfiguration
Qinconnect intent configuration details for the update intent response.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#qn_a_intent_configuration ⇒ Types::QnAIntentConfiguration
Details about the configuration of the built-in Amazon.QnAIntent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#sample_utterances ⇒ Array<Types::SampleUtterance>
The updated list of sample utterances for the intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |
#slot_priorities ⇒ Array<Types::SlotPriority>
The updated list of slots and their priorities that are elicited from the user for the intent.
15737 15738 15739 15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 15752 15753 15754 15755 15756 15757 15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 15737 class UpdateIntentResponse < Struct.new( :intent_id, :intent_name, :intent_display_name, :description, :parent_intent_signature, :sample_utterances, :dialog_code_hook, :fulfillment_code_hook, :slot_priorities, :intent_confirmation_setting, :intent_closing_setting, :input_contexts, :output_contexts, :kendra_configuration, :bot_id, :bot_version, :locale_id, :creation_date_time, :last_updated_date_time, :initial_response_setting, :qn_a_intent_configuration, :q_in_connect_intent_configuration) SENSITIVE = [] include Aws::Structure end |