Class: Aws::LexModelsV2::Types::UpdateSlotResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateSlotResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot that contains the slot.
-
#bot_version ⇒ String
The version of the bot that contains the slot.
-
#creation_date_time ⇒ Time
The timestamp of the date and time that the slot was created.
-
#description ⇒ String
The updated description of the bot.
-
#intent_id ⇒ String
The intent that contains the slot.
-
#last_updated_date_time ⇒ Time
The timestamp of the date and time that the slot was last updated.
-
#locale_id ⇒ String
The locale that contains the slot.
-
#multiple_values_setting ⇒ Types::MultipleValuesSetting
Indicates whether the slot accepts multiple values in one response.
-
#obfuscation_setting ⇒ Types::ObfuscationSetting
The updated setting that determines whether the slot value is obfuscated in the Amazon CloudWatch logs.
-
#slot_id ⇒ String
The unique identifier of the slot that was updated.
-
#slot_name ⇒ String
The updated name of the slot.
-
#slot_type_id ⇒ String
The updated identifier of the slot type that provides values for the slot.
-
#sub_slot_setting ⇒ Types::SubSlotSetting
Specifications for the constituent sub slots and the expression for the composite slot.
-
#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting
The updated prompts that Amazon Lex sends to the user to elicit a response that provides a value for the slot.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot that contains the slot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the slot. Will always be ‘DRAFT`.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The timestamp of the date and time that the slot was created.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description of the bot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#intent_id ⇒ String
The intent that contains the slot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The timestamp of the date and time that the slot was last updated.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The locale that contains the slot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#multiple_values_setting ⇒ Types::MultipleValuesSetting
Indicates whether the slot accepts multiple values in one response.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#obfuscation_setting ⇒ Types::ObfuscationSetting
The updated setting that determines whether the slot value is obfuscated in the Amazon CloudWatch logs.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_id ⇒ String
The unique identifier of the slot that was updated.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_name ⇒ String
The updated name of the slot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_id ⇒ String
The updated identifier of the slot type that provides values for the slot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#sub_slot_setting ⇒ Types::SubSlotSetting
Specifications for the constituent sub slots and the expression for the composite slot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |
#value_elicitation_setting ⇒ Types::SlotValueElicitationSetting
The updated prompts that Amazon Lex sends to the user to elicit a response that provides a value for the slot.
16061 16062 16063 16064 16065 16066 16067 16068 16069 16070 16071 16072 16073 16074 16075 16076 16077 16078 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16061 class UpdateSlotResponse < Struct.new( :slot_id, :slot_name, :description, :slot_type_id, :value_elicitation_setting, :obfuscation_setting, :bot_id, :bot_version, :locale_id, :intent_id, :creation_date_time, :last_updated_date_time, :multiple_values_setting, :sub_slot_setting) SENSITIVE = [] include Aws::Structure end |