Class: Aws::LexModelsV2::Types::UpdateSlotTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateSlotTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The identifier of the bot that contains the slot type.
-
#bot_version ⇒ String
The version of the bot that contains the slot type.
-
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
-
#description ⇒ String
The new description of the slot type.
-
#external_source_setting ⇒ Types::ExternalSourceSetting
Provides information about the external source of the slot type's definition.
-
#locale_id ⇒ String
The identifier of the language and locale that contains the slot type.
-
#parent_slot_type_signature ⇒ String
The new built-in slot type that should be used as the parent of this slot type.
-
#slot_type_id ⇒ String
The unique identifier of the slot type to update.
-
#slot_type_name ⇒ String
The new name of the slot type.
-
#slot_type_values ⇒ Array<Types::SlotTypeValue>
A new list of values and their optional synonyms that define the values that the slot type can take.
-
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
The strategy that Amazon Lex should use when deciding on a value from the list of slot type values.
Instance Attribute Details
#bot_id ⇒ String
The identifier of the bot that contains the slot type.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#bot_version ⇒ String
The version of the bot that contains the slot type. Must be DRAFT.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#composite_slot_type_setting ⇒ Types::CompositeSlotTypeSetting
Specifications for a composite slot type.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description of the slot type.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#external_source_setting ⇒ Types::ExternalSourceSetting
Provides information about the external source of the slot type's definition.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#locale_id ⇒ String
The identifier of the language and locale that contains the slot type. The string must match one of the supported locales. For more information, see Supported languages.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#parent_slot_type_signature ⇒ String
The new built-in slot type that should be used as the parent of this slot type.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_id ⇒ String
The unique identifier of the slot type to update.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_name ⇒ String
The new name of the slot type.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#slot_type_values ⇒ Array<Types::SlotTypeValue>
A new list of values and their optional synonyms that define the values that the slot type can take.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |
#value_selection_setting ⇒ Types::SlotValueSelectionSetting
The strategy that Amazon Lex should use when deciding on a value from the list of slot type values.
16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16193 class UpdateSlotTypeRequest < Struct.new( :slot_type_id, :slot_type_name, :description, :slot_type_values, :value_selection_setting, :parent_slot_type_signature, :bot_id, :bot_version, :locale_id, :external_source_setting, :composite_slot_type_setting) SENSITIVE = [] include Aws::Structure end |