Class: Aws::LexModelsV2::Types::UpdateSlotTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_idString

The identifier of the bot that contains the slot type.

Returns:

  • (String)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that contains the slot type. This is always ‘DRAFT`.

Returns:

  • (String)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#composite_slot_type_settingTypes::CompositeSlotTypeSetting

Specifications for a composite slot type.



16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The timestamp of the date and time that the slot type was created.

Returns:

  • (Time)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The updated description of the slot type.

Returns:

  • (String)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#external_source_settingTypes::ExternalSourceSetting

Provides information about the external source of the slot type’s definition.



16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

A timestamp of the date and time that the slot type was last updated.

Returns:

  • (Time)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The language and locale of the updated slot type.

Returns:

  • (String)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#parent_slot_type_signatureString

The updated signature of the built-in slot type that is the parent of this slot type.

Returns:

  • (String)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_idString

The unique identifier of the updated slot type.

Returns:

  • (String)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_nameString

The updated name of the slot type.

Returns:

  • (String)


16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_valuesArray<Types::SlotTypeValue>

The updated values that the slot type provides.

Returns:



16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end

#value_selection_settingTypes::SlotValueSelectionSetting

The updated strategy that Amazon Lex uses to determine which value to select from the slot type.



16211
16212
16213
16214
16215
16216
16217
16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16211

class UpdateSlotTypeResponse < Struct.new(
  :slot_type_id,
  :slot_type_name,
  :description,
  :slot_type_values,
  :value_selection_setting,
  :parent_slot_type_signature,
  :bot_id,
  :bot_version,
  :locale_id,
  :creation_date_time,
  :last_updated_date_time,
  :external_source_setting,
  :composite_slot_type_setting)
  SENSITIVE = []
  include Aws::Structure
end