Class: Aws::LexModelsV2::Types::UpdateTestSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateTestSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The creation date and time for the updated test set.
-
#description ⇒ String
The test set description for the updated test set.
-
#last_updated_date_time ⇒ Time
The date and time of the last update for the updated test set.
-
#modality ⇒ String
Indicates whether audio or text is used for the updated test set.
-
#num_turns ⇒ Integer
The number of conversation turns from the updated test set.
-
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
-
#status ⇒ String
The status for the updated test set.
-
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the updated test set.
-
#test_set_id ⇒ String
The test set Id for which update test operation to be performed.
-
#test_set_name ⇒ String
The test set name for the updated test set.
Instance Attribute Details
#creation_date_time ⇒ Time
The creation date and time for the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The test set description for the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The date and time of the last update for the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#modality ⇒ String
Indicates whether audio or text is used for the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#num_turns ⇒ Integer
The number of conversation turns from the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status for the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_id ⇒ String
The test set Id for which update test operation to be performed.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_name ⇒ String
The test set name for the updated test set.
16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16294 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |