Class: Aws::LexModelsV2::Types::UpdateTestSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UpdateTestSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_time ⇒ Time
The creation date and time for the updated test set.
-
#description ⇒ String
The test set description for the updated test set.
-
#last_updated_date_time ⇒ Time
The date and time of the last update for the updated test set.
-
#modality ⇒ String
Indicates whether audio or text is used for the updated test set.
-
#num_turns ⇒ Integer
The number of conversation turns from the updated test set.
-
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
-
#status ⇒ String
The status for the updated test set.
-
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the updated test set.
-
#test_set_id ⇒ String
The test set Id for which update test operation to be performed.
-
#test_set_name ⇒ String
The test set name for the updated test set.
Instance Attribute Details
#creation_date_time ⇒ Time
The creation date and time for the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The test set description for the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ Time
The date and time of the last update for the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#modality ⇒ String
Indicates whether audio or text is used for the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#num_turns ⇒ Integer
The number of conversation turns from the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The roleARN used for any operation in the test set to access resources in the Amazon Web Services account.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status for the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#storage_location ⇒ Types::TestSetStorageLocation
The Amazon S3 storage location for the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_id ⇒ String
The test set Id for which update test operation to be performed.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |
#test_set_name ⇒ String
The test set name for the updated test set.
16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16204 class UpdateTestSetResponse < Struct.new( :test_set_id, :test_set_name, :description, :modality, :status, :role_arn, :num_turns, :storage_location, :creation_date_time, :last_updated_date_time) SENSITIVE = [] include Aws::Structure end |