Class: Aws::LexModelsV2::Types::UserTurnOutputSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelsV2::Types::UserTurnOutputSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelsv2/types.rb
Overview
Contains results that are output for the user turn by the test execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_contexts ⇒ Array<Types::ActiveContext>
The contexts that are active in the turn.
-
#intent ⇒ Types::UserTurnIntentOutput
Contains information about the intent.
-
#transcript ⇒ String
The transcript that is output for the user turn by the test execution.
Instance Attribute Details
#active_contexts ⇒ Array<Types::ActiveContext>
The contexts that are active in the turn.
16371 16372 16373 16374 16375 16376 16377 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16371 class UserTurnOutputSpecification < Struct.new( :intent, :active_contexts, :transcript) SENSITIVE = [] include Aws::Structure end |
#intent ⇒ Types::UserTurnIntentOutput
Contains information about the intent.
16371 16372 16373 16374 16375 16376 16377 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16371 class UserTurnOutputSpecification < Struct.new( :intent, :active_contexts, :transcript) SENSITIVE = [] include Aws::Structure end |
#transcript ⇒ String
The transcript that is output for the user turn by the test execution.
16371 16372 16373 16374 16375 16376 16377 |
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16371 class UserTurnOutputSpecification < Struct.new( :intent, :active_contexts, :transcript) SENSITIVE = [] include Aws::Structure end |