Class: Aws::LexModelsV2::Types::UtteranceSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

An object containing information about a specific utterance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_intent_nameString

The name of the intent that the utterance is associated to.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#associated_slot_nameString

The name of the slot that the utterance is associated to.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#audio_voice_duration_millisInteger

The duration in milliseconds of the audio associated with the utterance.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_alias_idString

The identifier of the alias of the bot that the utterance was made to.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_response_audio_voice_idString

The identifier for the audio of the bot response.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_responsesArray<Types::UtteranceBotResponse>

A list of objects containing information about the bot response to the utterance.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#bot_versionString

The version of the bot that the utterance was made to.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#channelString

The channel that is integrated with the bot that the utterance was made to.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_end_timeTime

The date and time when the conversation in which the utterance took place ended. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_start_timeTime

The date and time when the conversation in which the utterance took place began. A conversation is defined as a unique combination of a sessionId and an originatingRequestId.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#dialog_action_typeString

The type of dialog action that the utterance is associated to. See the type field in [DialogAction] for more information.

[1]: docs.aws.amazon.com/lexv2/latest/APIReference/API_runtime_DialogAction.html



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#input_typeString

The input type of the utterance. The possible values are as follows:

  • PCM format: audio data must be in little-endian byte order.

    • ‘audio/l16; rate=16000; channels=1`

    • ‘audio/x-l16; sample-rate=16000; channel-count=1`

    • ‘audio/lpcm; sample-rate=8000; sample-size-bits=16; channel-count=1; is-big-endian=false`

  • Opus format

    • ‘audio/x-cbr-opus-with-preamble;preamble-size=0;bit-rate=256000;frame-size-milliseconds=4`

    ^

  • Text format

    • ‘text/plain; charset=utf-8`

    ^



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#intent_stateString

The state of the intent that the utterance is associated to.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#locale_idString

The locale of the bot that the utterance was made to.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

The mode of the session. The possible values are as follows:

  • Speech – The session consisted of spoken dialogue.

  • Text – The session consisted of written dialogue.

  • DTMF – The session consisted of touch-tone keypad (Dual Tone Multi-Frequency) key presses.

  • MultiMode – The session consisted of multiple modes.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#output_typeString

The output type of the utterance. The possible values are as follows:

  • audio/mpeg

  • audio/ogg

  • ‘audio/pcm (16 KHz)`

  • audio/ (defaults to mpeg)

  • ‘text/plain; charset=utf-8`



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The identifier of the session that the utterance was made in.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#slots_filled_in_sessionString

The slots that have been filled in the session by the time of the utterance.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utteranceString

The text of the utterance.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_request_idString

The identifier of the request associated with the utterance.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_timestampTime

The date and time when the utterance took place.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end

#utterance_understoodBoolean

Specifies whether the bot understood the utterance or not.



16317
16318
16319
16320
16321
16322
16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
16334
16335
16336
16337
16338
16339
16340
16341
16342
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16317

class UtteranceSpecification < Struct.new(
  :bot_alias_id,
  :bot_version,
  :locale_id,
  :session_id,
  :channel,
  :mode,
  :conversation_start_time,
  :conversation_end_time,
  :utterance,
  :utterance_timestamp,
  :audio_voice_duration_millis,
  :utterance_understood,
  :input_type,
  :output_type,
  :associated_intent_name,
  :associated_slot_name,
  :intent_state,
  :dialog_action_type,
  :bot_response_audio_voice_id,
  :slots_filled_in_session,
  :utterance_request_id,
  :bot_responses)
  SENSITIVE = []
  include Aws::Structure
end