Class: Aws::LexModelsV2::Types::VoiceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelsv2/types.rb

Overview

Defines settings for using an Amazon Polly voice to communicate with a user.

Valid values include:

  • standard

  • neural

  • long-form

  • generative

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#engineString

Indicates the type of Amazon Polly voice that Amazon Lex should use for voice interaction with the user. For more information, see the [ engine parameter of the SynthesizeSpeech operation] in the *Amazon Polly developer guide*.

If you do not specify a value, the default is standard.

[1]: docs.aws.amazon.com/polly/latest/dg/API_SynthesizeSpeech.html#polly-SynthesizeSpeech-request-Engine

Returns:

  • (String)


16390
16391
16392
16393
16394
16395
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16390

class VoiceSettings < Struct.new(
  :engine,
  :voice_id)
  SENSITIVE = []
  include Aws::Structure
end

#voice_idString

The identifier of the Amazon Polly voice to use.

Returns:

  • (String)


16390
16391
16392
16393
16394
16395
# File 'lib/aws-sdk-lexmodelsv2/types.rb', line 16390

class VoiceSettings < Struct.new(
  :engine,
  :voice_id)
  SENSITIVE = []
  include Aws::Structure
end