Class: Aws::LexModelsV2::Waiters::BotAliasAvailable
- Inherits:
-
Object
- Object
- Aws::LexModelsV2::Waiters::BotAliasAvailable
- Defined in:
- lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs
Overview
Wait until a bot alias is available
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ BotAliasAvailable
constructor
A new instance of BotAliasAvailable.
-
#wait(params = {}) ⇒ Types::DescribeBotAliasResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ BotAliasAvailable
Returns a new instance of BotAliasAvailable.
92 93 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 92
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
130 131 132 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 130 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeBotAliasResponse
Returns a response object which responds to the following methods:
- #bot_alias_id => String
- #bot_alias_name => String
- #description => String
- #bot_version => String
- #bot_alias_locale_settings => Hash<String,Types::BotAliasLocaleSettings>
- #conversation_log_settings => Types::ConversationLogSettings
- #sentiment_analysis_settings => Types::SentimentAnalysisSettings
- #bot_alias_history_events => Array<Types::BotAliasHistoryEvent>
- #bot_alias_status => String
- #bot_id => String
- #creation_date_time => Time
- #last_updated_date_time => Time
- #parent_bot_networks => Array<Types::ParentBotNetwork>
125 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 125
def wait: (
|