Class: Aws::LexModelsV2::Waiters::BotVersionAvailable
- Inherits:
-
Object
- Object
- Aws::LexModelsV2::Waiters::BotVersionAvailable
- Defined in:
- lib/aws-sdk-lexmodelsv2/waiters.rb,
sig/waiters.rbs
Overview
Wait until a bot version is available
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ BotVersionAvailable
constructor
A new instance of BotVersionAvailable.
-
#wait(params = {}) ⇒ Types::DescribeBotVersionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ BotVersionAvailable
Returns a new instance of BotVersionAvailable.
485 486 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 485
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
528 529 530 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 528 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeBotVersionResponse
Returns a response object which responds to the following methods:
- #bot_id => String
- #bot_name => String
- #bot_version => String
- #description => String
- #role_arn => String
- #data_privacy => Types::DataPrivacy
- #idle_session_ttl_in_seconds => Integer
- #bot_status => String
- #failure_reasons => Array<String>
- #creation_date_time => Time
- #parent_bot_networks => Array<Types::ParentBotNetwork>
- #bot_type => String
- #bot_members => Array<Types::BotMember>
523 |
# File 'lib/aws-sdk-lexmodelsv2/waiters.rb', line 523
def wait: (
|